@@ -42,14 +42,16 @@ my $cn_split = C4::ClassSplitRoutine::LCC::split_callnumber($cn_item);
 
 sub split_callnumber {
     my ($cn_item) = @_;
+
     # lccn examples: 'HE8700.7 .P6T44 1983', 'BS2545.E8 H39 1996';
     my @lines = Library::CallNumber::LC->new($cn_item)->components();
-    unless (scalar @lines && defined $lines[0])  {
+    unless ( scalar @lines && defined $lines[0] ) {
         Koha::Logger->get->debug( sprintf( 'regexp failed to match string: %s', $cn_item // q{} ) );
-        @lines = $cn_item;     # if no match, just use the whole string.
+        @lines = $cn_item;    # if no match, just use the whole string.
     }
     my $LastPiece = pop @lines;
-    push @lines, split /\s+/, $LastPiece if $LastPiece;   # split the last piece into an arbitrary number of pieces at spaces
+    push @lines, split /\s+/, $LastPiece
+        if $LastPiece;        # split the last piece into an arbitrary number of pieces at spaces
     return @lines;
 }
 
