@@ -31,14 +31,15 @@ use Koha::Libraries;
 use Koha::Logger;
 use Koha::Patrons;
 
-use List::Util qw( shuffle );
-use List::MoreUtils qw( any );
+use List::Util         qw( shuffle );
+use List::MoreUtils    qw( any );
 use Algorithm::Munkres qw();
 
-our (@ISA, @EXPORT_OK);
+our ( @ISA, @EXPORT_OK );
+
 BEGIN {
     require Exporter;
-    @ISA = qw(Exporter);
+    @ISA       = qw(Exporter);
     @EXPORT_OK = qw(
         CreateQueue
         GetHoldsQueueItems
@@ -48,10 +49,9 @@ BEGIN {
         GetPendingHoldRequestsForBib
         load_branches_to_pull_from
         update_queue_for_biblio
-     );
+    );
 }
 
-
 =head1 FUNCTIONS
 
 =head2 TransportCostMatrix
@@ -63,10 +63,10 @@ Returns Transport Cost Matrix as a hashref <to branch code> => <from branch code
 =cut
 
 sub TransportCostMatrix {
-    my ( $params ) = @_;
+    my ($params) = @_;
 
-    my $dbh   = C4::Context->dbh;
-    my $transport_costs = $dbh->selectall_arrayref("SELECT * FROM transport_cost",{ Slice => {} });
+    my $dbh             = C4::Context->dbh;
+    my $transport_costs = $dbh->selectall_arrayref( "SELECT * FROM transport_cost", { Slice => {} } );
 
     my $today = dt_from_string();
     my %transport_cost_matrix;
@@ -95,20 +95,20 @@ Records: { frombranch => <code>, tobranch => <code>, cost => <figure>, disable_t
 
 sub UpdateTransportCostMatrix {
     my ($records) = @_;
-    my $dbh   = C4::Context->dbh;
+    my $dbh = C4::Context->dbh;
 
-    my $sth = $dbh->prepare("INSERT INTO transport_cost (frombranch, tobranch, cost, disable_transfer) VALUES (?, ?, ?, ?)");
+    my $sth =
+        $dbh->prepare("INSERT INTO transport_cost (frombranch, tobranch, cost, disable_transfer) VALUES (?, ?, ?, ?)");
 
     $dbh->do("DELETE FROM transport_cost");
     foreach (@$records) {
         my $cost = $_->{cost};
         my $from = $_->{frombranch};
-        my $to = $_->{tobranch};
-        if ($_->{disable_transfer}) {
+        my $to   = $_->{tobranch};
+        if ( $_->{disable_transfer} ) {
             $cost ||= 0;
-        }
-        elsif ( !defined ($cost) || ($cost !~ m/(0|[1-9][0-9]*)(\.[0-9]*)?/o) ) {
-            warn  "Invalid $from -> $to cost $cost - must be a number >= 0, disabling";
+        } elsif ( !defined($cost) || ( $cost !~ m/(0|[1-9][0-9]*)(\.[0-9]*)?/o ) ) {
+            warn "Invalid $from -> $to cost $cost - must be a number >= 0, disabling";
             $cost = 0;
             $_->{disable_transfer} = 1;
         }
@@ -126,13 +126,13 @@ Returns hold queue for a holding branch. If branch is omitted, then whole queue
 
 sub GetHoldsQueueItems {
     my $params = shift;
-    my $dbh   = C4::Context->dbh;
+    my $dbh    = C4::Context->dbh;
 
     my $search_params;
-    $search_params->{'me.holdingbranch'} = $params->{branchlimit} if $params->{branchlimit};
-    $search_params->{'itype'} = $params->{itemtypeslimit} if $params->{itemtypeslimit};
-    $search_params->{'ccode'} = $params->{ccodeslimit} if $params->{ccodeslimit};
-    $search_params->{'location'} = $params->{locationslimit} if $params->{locationslimit};
+    $search_params->{'me.holdingbranch'} = $params->{branchlimit}    if $params->{branchlimit};
+    $search_params->{'itype'}            = $params->{itemtypeslimit} if $params->{itemtypeslimit};
+    $search_params->{'ccode'}            = $params->{ccodeslimit}    if $params->{ccodeslimit};
+    $search_params->{'location'}         = $params->{locationslimit} if $params->{locationslimit};
 
     my $results = Koha::Hold::HoldsQueueItems->search(
         $search_params,
@@ -143,11 +143,7 @@ sub GetHoldsQueueItems {
             prefetch => [
                 'biblio',
                 'biblioitem',
-                {
-                    'item' => {
-                        'item_group_item' => 'item_group'
-                    }
-                }
+                { 'item' => { 'item_group_item' => 'item_group' } }
             ],
             order_by => [
                 'ccode',        'location',   'item.cn_sort', 'author',
@@ -242,7 +238,6 @@ sub CreateQueue {
     }
 }
 
-
 =head2 GetBibsWithPendingHoldRequests
 
   my $biblionumber_aref = GetBibsWithPendingHoldRequests();
@@ -313,7 +308,7 @@ sub GetPendingHoldRequestsForBib {
     my $sth = $dbh->prepare($request_query);
     $sth->execute($biblionumber);
 
-    my $requests = $sth->fetchall_arrayref({});
+    my $requests = $sth->fetchall_arrayref( {} );
     return $requests;
 
 }
@@ -337,9 +332,9 @@ to fill a hold request if and only if:
 =cut
 
 sub GetItemsAvailableToFillHoldRequestsForBib {
-    my ($biblionumber, $branches_to_use) = @_;
+    my ( $biblionumber, $branches_to_use ) = @_;
 
-    my $dbh = C4::Context->dbh;
+    my $dbh         = C4::Context->dbh;
     my $items_query = "SELECT items.itemnumber, homebranch, holdingbranch, itemtypes.itemtype AS itype
                        FROM items ";
 
@@ -375,20 +370,22 @@ sub GetItemsAvailableToFillHoldRequestsForBib {
                        AND items.biblionumber = ?
                        AND branchtransfers.itemnumber IS NULL";
 
-    my @params = ($biblionumber, $biblionumber, $biblionumber);
-    if ($branches_to_use && @$branches_to_use) {
-        $items_query .= " AND holdingbranch IN (" . join (",", map { "?" } @$branches_to_use) . ")";
+    my @params = ( $biblionumber, $biblionumber, $biblionumber );
+    if ( $branches_to_use && @$branches_to_use ) {
+        $items_query .= " AND holdingbranch IN (" . join( ",", map { "?" } @$branches_to_use ) . ")";
         push @params, @$branches_to_use;
     }
     my $sth = $dbh->prepare($items_query);
     $sth->execute(@params);
 
-    my $itm = $sth->fetchall_arrayref({});
-    return [ grep {
-        my $rule = C4::Circulation::GetBranchItemRule($_->{homebranch}, $_->{itype});
-        $_->{holdallowed} = $rule->{holdallowed};
-        $_->{hold_fulfillment_policy} = $rule->{hold_fulfillment_policy};
-    } @{$itm} ];
+    my $itm = $sth->fetchall_arrayref( {} );
+    return [
+        grep {
+            my $rule = C4::Circulation::GetBranchItemRule( $_->{homebranch}, $_->{itype} );
+            $_->{holdallowed}             = $rule->{holdallowed};
+            $_->{hold_fulfillment_policy} = $rule->{hold_fulfillment_policy};
+        } @{$itm}
+    ];
 }
 
 =head2 _checkHoldPolicy
@@ -599,10 +596,11 @@ RETRY:
         # end.
         $inf = $max * $num_tasks + 1;
 
-        my @m0 = map {[(undef) x  $num_tasks]} (1..$num_agents);
+        my @m0 = map { [ (undef) x $num_tasks ] } ( 1 .. $num_agents );
         for ( my $i = 0 ; $i < $num_agents ; $i++ ) {
             for ( my $j = 0 ; $j < $num_tasks ; $j++ ) {
                 if ( $m[$i][$j] < 0 ) {
+
                     # Bias towards not allocating items to holds closer to
                     # the end of the queue in the queue if not all holds
                     # can be filled by representing infinity with
@@ -712,15 +710,15 @@ RETRY:
 =cut
 
 sub MapItemsToHoldRequests {
-    my ($hold_requests, $available_items, $branches_to_use, $transport_cost_matrix) = @_;
+    my ( $hold_requests, $available_items, $branches_to_use, $transport_cost_matrix ) = @_;
 
-    # handle trival cases
+    # handle trivial cases
     return unless scalar(@$hold_requests) > 0;
     return unless scalar(@$available_items) > 0;
 
     map { $_->{_object} = Koha::Items->find( $_->{itemnumber} ) } @$available_items;
     my $libraries = {};
-    map { $libraries->{$_->id} = $_ } Koha::Libraries->search->as_list;
+    map { $libraries->{ $_->id } = $_ } Koha::Libraries->search->as_list;
 
     # group available items by itemnumber
     my %items_by_itemnumber = map { $_->{itemnumber} => $_ } @$available_items;
@@ -735,58 +733,104 @@ sub MapItemsToHoldRequests {
     my $num_items_remaining = scalar(@$available_items);
 
     # Look for Local Holds Priority matches first
-    if ( C4::Context->preference('LocalHoldsPriority') ) {
-        my $LocalHoldsPriorityPatronControl =
-          C4::Context->preference('LocalHoldsPriorityPatronControl');
-        my $LocalHoldsPriorityItemControl =
-          C4::Context->preference('LocalHoldsPriorityItemControl');
 
+    my $LocalHoldsPriority = C4::Context->preference('LocalHoldsPriority');
+    if ( $LocalHoldsPriority ne 'None' ) {
+        my $LocalHoldsPriorityPatronControl = C4::Context->preference('LocalHoldsPriorityPatronControl');
+        my $LocalHoldsPriorityItemControl   = C4::Context->preference('LocalHoldsPriorityItemControl');
         foreach my $request (@$hold_requests) {
             last if $num_items_remaining == 0;
-            my $patron = Koha::Patrons->find($request->{borrowernumber});
+            my $patron = Koha::Patrons->find( $request->{borrowernumber} );
             next if $patron->category->exclude_from_local_holds_priority;
+            if ( $LocalHoldsPriority eq 'GiveLibrary' || $LocalHoldsPriority eq 'GiveLibraryAndGroup' ) {
+                my $local_hold_match;
+                foreach my $item (@$available_items) {
+                    next if $item->{_object}->exclude_from_local_holds_priority;
 
-            my $local_hold_match;
-            foreach my $item (@$available_items) {
-                next if $item->{_object}->exclude_from_local_holds_priority;
+                    next unless _can_item_fill_request( $item, $request, $libraries );
 
-                next unless _can_item_fill_request( $item, $request, $libraries );
+                    next if $request->{itemnumber} && $request->{itemnumber} != $item->{itemnumber};
 
-                next if $request->{itemnumber} && $request->{itemnumber} != $item->{itemnumber};
+                    my $local_holds_priority_item_branchcode = $item->{$LocalHoldsPriorityItemControl};
 
-                my $local_holds_priority_item_branchcode =
-                  $item->{$LocalHoldsPriorityItemControl};
+                    my $local_holds_priority_patron_branchcode =
+                          ( $LocalHoldsPriorityPatronControl eq 'PickupLibrary' ) ? $request->{branchcode}
+                        : ( $LocalHoldsPriorityPatronControl eq 'HomeLibrary' )   ? $request->{borrowerbranch}
+                        :                                                           undef;
 
-                my $local_holds_priority_patron_branchcode =
-                  ( $LocalHoldsPriorityPatronControl eq 'PickupLibrary' )
-                  ? $request->{branchcode}
-                  : ( $LocalHoldsPriorityPatronControl eq 'HomeLibrary' )
-                  ? $request->{borrowerbranch}
-                  : undef;
+                    $local_hold_match =
+                        $local_holds_priority_item_branchcode eq $local_holds_priority_patron_branchcode;
 
-                $local_hold_match =
-                  $local_holds_priority_item_branchcode eq
-                  $local_holds_priority_patron_branchcode;
+                    if ($local_hold_match) {
+                        if (    exists $items_by_itemnumber{ $item->{itemnumber} }
+                            and not exists $allocated_items{ $item->{itemnumber} }
+                            and not $request->{allocated} )
+                        {
+                            $item_map{ $item->{itemnumber} } = {
+                                borrowernumber => $request->{borrowernumber},
+                                biblionumber   => $request->{biblionumber},
+                                holdingbranch  => $item->{holdingbranch},
+                                pickup_branch  => $request->{branchcode}
+                                    || $request->{borrowerbranch},
+                                reserve_id   => $request->{reserve_id},
+                                item_level   => $request->{item_level_hold},
+                                reservedate  => $request->{reservedate},
+                                reservenotes => $request->{reservenotes},
+                            };
+                            $allocated_items{ $item->{itemnumber} }++;
+                            $request->{allocated} = 1;
+                            $num_items_remaining--;
+                        }
+                    }
+                }
+            }
+        }
 
-                if ($local_hold_match) {
-                    if ( exists $items_by_itemnumber{ $item->{itemnumber} }
-                        and not exists $allocated_items{ $item->{itemnumber} }
-                        and not $request->{allocated})
-                    {
-                        $item_map{ $item->{itemnumber} } = {
-                            borrowernumber => $request->{borrowernumber},
-                            biblionumber   => $request->{biblionumber},
-                            holdingbranch  => $item->{holdingbranch},
-                            pickup_branch  => $request->{branchcode}
-                              || $request->{borrowerbranch},
-                            reserve_id   => $request->{reserve_id},
-                            item_level   => $request->{item_level_hold},
-                            reservedate  => $request->{reservedate},
-                            reservenotes => $request->{reservenotes},
-                        };
-                        $allocated_items{ $item->{itemnumber} }++;
-                        $request->{allocated} = 1;
-                        $num_items_remaining--;
+        # Look for local group matches if no library matches were found
+        if ( $LocalHoldsPriority eq 'GiveLibraryGroup' || $LocalHoldsPriority eq 'GiveLibraryAndGroup' ) {
+            my $local_hold_group_match;
+            foreach my $request (@$hold_requests) {
+                last if $num_items_remaining == 0;
+                my $patron = Koha::Patrons->find( $request->{borrowernumber} );
+                next if $patron->category->exclude_from_local_holds_priority;
+                foreach my $item (@$available_items) {
+                    next if $item->{_object}->exclude_from_local_holds_priority;
+
+                    next unless _can_item_fill_request( $item, $request, $libraries );
+
+                    next if $request->{itemnumber} && $request->{itemnumber} != $item->{itemnumber};
+
+                    my $local_holds_priority_item_branchcode = $item->{$LocalHoldsPriorityItemControl};
+
+                    my $local_holds_priority_patron_branchcode =
+                          ( $LocalHoldsPriorityPatronControl eq 'PickupLibrary' ) ? $request->{branchcode}
+                        : ( $LocalHoldsPriorityPatronControl eq 'HomeLibrary' )   ? $request->{borrowerbranch}
+                        :                                                           undef;
+
+                    $local_hold_group_match =
+                        Koha::Libraries->find( { branchcode => $local_holds_priority_item_branchcode } )
+                        ->validate_hold_sibling( { branchcode => $local_holds_priority_patron_branchcode } );
+
+                    if ($local_hold_group_match) {
+                        if (    exists $items_by_itemnumber{ $item->{itemnumber} }
+                            and not exists $allocated_items{ $item->{itemnumber} }
+                            and not $request->{allocated} )
+                        {
+                            $item_map{ $item->{itemnumber} } = {
+                                borrowernumber => $request->{borrowernumber},
+                                biblionumber   => $request->{biblionumber},
+                                holdingbranch  => $item->{holdingbranch},
+                                pickup_branch  => $request->{branchcode}
+                                    || $request->{borrowerbranch},
+                                reserve_id   => $request->{reserve_id},
+                                item_level   => $request->{item_level_hold},
+                                reservedate  => $request->{reservedate},
+                                reservenotes => $request->{reservenotes},
+                            };
+                            $allocated_items{ $item->{itemnumber} }++;
+                            $request->{allocated} = 1;
+                            $num_items_remaining--;
+                        }
                     }
                 }
             }
@@ -802,7 +846,8 @@ sub MapItemsToHoldRequests {
         next if $request->{allocated};
 
         # is this an item-level request?
-        if (defined($request->{itemnumber})) {
+        if ( defined( $request->{itemnumber} ) ) {
+
             # fill it if possible; if not skip it
             if (    exists $items_by_itemnumber{ $request->{itemnumber} }
                 and not exists $allocated_items{ $request->{itemnumber} }
@@ -823,6 +868,7 @@ sub MapItemsToHoldRequests {
                 $num_items_remaining--;
             }
         } else {
+
             # it's title-level request that will take up one item
             $num_items_remaining--;
         }
@@ -846,17 +892,17 @@ sub MapItemsToHoldRequests {
         next unless $item->{holdallowed} ne 'not_allowed';
 
         push @{ $items_by_branch{ $item->{holdingbranch} } }, $item
-          unless exists $allocated_items{ $item->{itemnumber} };
+            unless exists $allocated_items{ $item->{itemnumber} };
     }
     return \%item_map unless keys %items_by_branch;
 
     # now handle the title-level requests
-    $num_items_remaining = scalar(@$available_items) - scalar(keys %allocated_items);
+    $num_items_remaining = scalar(@$available_items) - scalar( keys %allocated_items );
     my $pull_branches;
     foreach my $request (@$hold_requests) {
         last if $num_items_remaining == 0;
         next if $request->{allocated};
-        next if defined($request->{itemnumber}); # already handled these
+        next if defined( $request->{itemnumber} );    # already handled these
 
         # HoldsQueuePrioritizeBranch check
         # ********************************
@@ -881,20 +927,20 @@ sub MapItemsToHoldRequests {
                 last;
             }
         }
+
         # End HoldsQueuePrioritizeBranch check
         # ********************************
 
-
         # Not found yet, fall back to basics
         unless ($itemnumber) {
             if ($branches_to_use) {
                 $pull_branches = $branches_to_use;
             } else {
-                $pull_branches = [keys %items_by_branch];
+                $pull_branches = [ keys %items_by_branch ];
             }
             $holdingbranch ||= $pull_branches->[0];    # We set this as the first from the list of pull branches
-                 # unless we set it above to the pickupbranch or the least cost branch
-                 # FIXME: The intention is to follow StaticHoldsQueueWeight, but we don't check that pref
+                # unless we set it above to the pickupbranch or the least cost branch
+                # FIXME: The intention is to follow StaticHoldsQueueWeight, but we don't check that pref
 
             # Try picking items where the home and pickup branch match first
             foreach my $branch (@$pull_branches) {
@@ -914,24 +960,24 @@ sub MapItemsToHoldRequests {
             }
 
             # Now try items from the least cost branch based on the transport cost matrix or StaticHoldsQueueWeight
-            unless ( $itemnumber || !$holdingbranch) {
+            unless ( $itemnumber || !$holdingbranch ) {
                 foreach my $current_item ( @{ $items_by_branch{$holdingbranch} } ) {
                     next unless _can_item_fill_request( $current_item, $request, $libraries );
 
                     $itemnumber = $current_item->{itemnumber};
-                    last; # quit this loop as soon as we have a suitable item
+                    last;    # quit this loop as soon as we have a suitable item
                 }
             }
 
             # Now try for items for any item that can fill this hold
-            unless ( $itemnumber ) {
+            unless ($itemnumber) {
                 foreach my $branch (@$pull_branches) {
                     my $holding_branch_items = $items_by_branch{$branch}
-                      or next;
+                        or next;
 
                     foreach my $item (@$holding_branch_items) {
-                        if( _can_item_fill_request( $item, $request, $libraries ) ){
-                            $itemnumber = $item->{itemnumber};
+                        if ( _can_item_fill_request( $item, $request, $libraries ) ) {
+                            $itemnumber    = $item->{itemnumber};
                             $holdingbranch = $branch;
                             last;
                         }
@@ -943,19 +989,19 @@ sub MapItemsToHoldRequests {
 
         if ($itemnumber) {
             my $holding_branch_items = $items_by_branch{$holdingbranch}
-              or die "Have $itemnumber, $holdingbranch, but no items!";
+                or die "Have $itemnumber, $holdingbranch, but no items!";
             @$holding_branch_items = grep { $_->{itemnumber} != $itemnumber } @$holding_branch_items;
             delete $items_by_branch{$holdingbranch} unless @$holding_branch_items;
 
             $item_map{$itemnumber} = {
                 borrowernumber => $request->{borrowernumber},
-                biblionumber => $request->{biblionumber},
-                holdingbranch => $holdingbranch,
-                pickup_branch => $pickup_branch,
-                reserve_id => $request->{reserve_id},
-                item_level => $request->{item_level_hold},
-                reservedate => $request->{reservedate},
-                reservenotes => $request->{reservenotes},
+                biblionumber   => $request->{biblionumber},
+                holdingbranch  => $holdingbranch,
+                pickup_branch  => $pickup_branch,
+                reserve_id     => $request->{reserve_id},
+                item_level     => $request->{item_level_hold},
+                reservedate    => $request->{reservedate},
+                reservenotes   => $request->{reservenotes},
             };
             $num_items_remaining--;
         }
@@ -963,7 +1009,6 @@ sub MapItemsToHoldRequests {
     return \%item_map;
 }
 
-
 =head2 _can_item_fill_request
 
   my $bool = _can_item_fill_request( $item, $request, $libraries );
@@ -997,50 +1042,56 @@ sub _can_item_fill_request {
     return 1;
 }
 
-
-
 =head2 CreatePickListFromItemMap
 
 =cut
 
+=head2 CreatePicklistFromItemMap
+
+Missing POD for CreatePicklistFromItemMap.
+
+=cut
+
 sub CreatePicklistFromItemMap {
     my $item_map = shift;
 
     my $dbh = C4::Context->dbh;
 
-    my $sth_load=$dbh->prepare("
+    my $sth_load = $dbh->prepare( "
         INSERT INTO tmp_holdsqueue (biblionumber,itemnumber,barcode,surname,firstname,phone,borrowernumber,
                                     cardnumber,reservedate,title, itemcallnumber,
                                     holdingbranch,pickbranch,notes, item_level_request)
         VALUES (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)
-    ");
+    " );
 
-    foreach my $itemnumber  (sort keys %$item_map) {
-        my $mapped_item = $item_map->{$itemnumber};
-        my $biblionumber = $mapped_item->{biblionumber};
+    foreach my $itemnumber ( sort keys %$item_map ) {
+        my $mapped_item    = $item_map->{$itemnumber};
+        my $biblionumber   = $mapped_item->{biblionumber};
         my $borrowernumber = $mapped_item->{borrowernumber};
-        my $pickbranch = $mapped_item->{pickup_branch};
-        my $holdingbranch = $mapped_item->{holdingbranch};
-        my $reservedate = $mapped_item->{reservedate};
-        my $reservenotes = $mapped_item->{reservenotes};
-        my $item_level = $mapped_item->{item_level};
+        my $pickbranch     = $mapped_item->{pickup_branch};
+        my $holdingbranch  = $mapped_item->{holdingbranch};
+        my $reservedate    = $mapped_item->{reservedate};
+        my $reservenotes   = $mapped_item->{reservenotes};
+        my $item_level     = $mapped_item->{item_level};
 
-        my $item = Koha::Items->find($itemnumber);
-        my $barcode = $item->barcode;
+        my $item           = Koha::Items->find($itemnumber);
+        my $barcode        = $item->barcode;
         my $itemcallnumber = $item->itemcallnumber;
 
-        my $patron = Koha::Patrons->find( $borrowernumber );
+        my $patron     = Koha::Patrons->find($borrowernumber);
         my $cardnumber = $patron->cardnumber;
-        my $surname = $patron->surname;
-        my $firstname = $patron->firstname;
-        my $phone = $patron->phone;
+        my $surname    = $patron->surname;
+        my $firstname  = $patron->firstname;
+        my $phone      = $patron->phone;
 
-        my $biblio = Koha::Biblios->find( $biblionumber );
-        my $title = $biblio->title;
+        my $biblio = Koha::Biblios->find($biblionumber);
+        my $title  = $biblio->title;
 
-        $sth_load->execute($biblionumber, $itemnumber, $barcode, $surname, $firstname, $phone, $borrowernumber,
-                           $cardnumber, $reservedate, $title, $itemcallnumber,
-                           $holdingbranch, $pickbranch, $reservenotes, $item_level);
+        $sth_load->execute(
+            $biblionumber,  $itemnumber,  $barcode,      $surname, $firstname, $phone, $borrowernumber,
+            $cardnumber,    $reservedate, $title,        $itemcallnumber,
+            $holdingbranch, $pickbranch,  $reservenotes, $item_level
+        );
     }
 }
 
@@ -1082,58 +1133,65 @@ sub _trim {
     $_[0];
 }
 
+=head2 load_branches_to_pull_from
+
+Missing POD for load_branches_to_pull_from.
+
+=cut
+
 sub load_branches_to_pull_from {
     my $use_transport_cost_matrix = shift;
 
     my @branches_to_use;
 
-    unless ( $use_transport_cost_matrix ) {
+    unless ($use_transport_cost_matrix) {
         my $static_branch_list = C4::Context->preference("StaticHoldsQueueWeight");
         @branches_to_use = map { _trim($_) } split( /,/, $static_branch_list )
-          if $static_branch_list;
+            if $static_branch_list;
     }
 
-    @branches_to_use =
-      Koha::Database->new()->schema()->resultset('Branch')
-      ->get_column('branchcode')->all()
-      unless (@branches_to_use);
+    @branches_to_use = Koha::Database->new()->schema()->resultset('Branch')->get_column('branchcode')->all()
+        unless (@branches_to_use);
 
     @branches_to_use = shuffle(@branches_to_use)
-      if C4::Context->preference("RandomizeHoldsQueueWeight");
+        if C4::Context->preference("RandomizeHoldsQueueWeight");
 
     my $today = dt_from_string();
     if ( C4::Context->preference('HoldsQueueSkipClosed') ) {
-        @branches_to_use = grep {
-            !Koha::Calendar->new( branchcode => $_ )
-              ->is_holiday( $today )
-        } @branches_to_use;
+        @branches_to_use = grep { !Koha::Calendar->new( branchcode => $_ )->is_holiday($today) } @branches_to_use;
     }
 
     return \@branches_to_use;
 }
 
+=head2 least_cost_branch
+
+Missing POD for least_cost_branch.
+
+=cut
+
 sub least_cost_branch {
 
     #$from - arrayref
-    my ($to, $from, $transport_cost_matrix) = @_;
+    my ( $to, $from, $transport_cost_matrix ) = @_;
 
     # Nothing really spectacular: supply to branch, a list of potential from branches
     # and find the minimum from - to value from the transport_cost_matrix
-    return $from->[0] if ( @$from == 1 && $transport_cost_matrix->{$to}{$from->[0]}->{disable_transfer} != 1 );
+    return $from->[0] if ( @$from == 1 && $transport_cost_matrix->{$to}{ $from->[0] }->{disable_transfer} != 1 );
 
     # If the pickup library is in the list of libraries to pull from,
     # return that library right away, it is obviously the least costly
     return ($to) if any { $_ eq $to } @$from;
 
-    my ($least_cost, @branch);
+    my ( $least_cost, @branch );
     foreach (@$from) {
         my $cell = $transport_cost_matrix->{$to}{$_};
         next if $cell->{disable_transfer};
 
         my $cost = $cell->{cost};
-        next unless defined $cost; # XXX should this be reported?
+        next unless defined $cost;    # XXX should this be reported?
 
-        unless (defined $least_cost) {
+        unless ( defined $least_cost ) {
             $least_cost = $cost;
             push @branch, $_;
             next;
@@ -1141,12 +1199,12 @@ sub least_cost_branch {
 
         next if $cost > $least_cost;
 
-        if ($cost == $least_cost) {
+        if ( $cost == $least_cost ) {
             push @branch, $_;
             next;
         }
 
-        @branch = ($_);
+        @branch     = ($_);
         $least_cost = $cost;
     }
 
@@ -1218,16 +1276,20 @@ sub update_queue_for_biblio {
         $dbh->do("DELETE FROM hold_fill_targets WHERE biblionumber=$biblio_id");
     }
 
-    my $hold_requests   = GetPendingHoldRequestsForBib({ biblionumber => $biblio_id, unallocated => $args->{unallocated} });
+    my $hold_requests =
+        GetPendingHoldRequestsForBib( { biblionumber => $biblio_id, unallocated => $args->{unallocated} } );
     $result->{requests} = scalar( @{$hold_requests} );
+
     # No need to check anything else if there are no holds to fill
     return $result unless $result->{requests};
 
-    my $branches_to_use = $args->{branches_to_use} // load_branches_to_pull_from( C4::Context->preference('UseTransportCostMatrix') );
+    my $branches_to_use = $args->{branches_to_use}
+        // load_branches_to_pull_from( C4::Context->preference('UseTransportCostMatrix') );
     my $transport_cost_matrix;
 
     if ( !exists $args->{transport_cost_matrix}
-        && C4::Context->preference('UseTransportCostMatrix') ) {
+        && C4::Context->preference('UseTransportCostMatrix') )
+    {
         $transport_cost_matrix = TransportCostMatrix();
     } else {
         $transport_cost_matrix = $args->{transport_cost_matrix};
@@ -1235,7 +1297,7 @@ sub update_queue_for_biblio {
 
     my $available_items = GetItemsAvailableToFillHoldRequestsForBib( $biblio_id, $branches_to_use );
 
-    $result->{available_items}  = scalar( @{$available_items} );
+    $result->{available_items} = scalar( @{$available_items} );
 
     my $item_map = MapItemsToHoldRequests( $hold_requests, $available_items, $branches_to_use, $transport_cost_matrix );
     $result->{mapped_items} = scalar( keys %{$item_map} );
