@@ -21,7 +21,6 @@ package C4::Output;
 # You should have received a copy of the GNU General Public License
 # along with Koha; if not, see <http://www.gnu.org/licenses>.
 
-
 # NOTE: I'm pretty sure this module is deprecated in favor of
 # templates.
 
@@ -35,12 +34,12 @@ use C4::Auth qw( get_template_and_user );
 use C4::Context;
 use C4::Templates;
 
-our (@ISA, @EXPORT_OK);
+our ( @ISA, @EXPORT_OK );
 
 BEGIN {
     require Exporter;
 
-    @ISA    = qw(Exporter);
+    @ISA       = qw(Exporter);
     @EXPORT_OK = qw(
         is_ajax
         ajax_fail
@@ -78,10 +77,10 @@ This function returns HTML, without any language dependency.
 =cut
 
 sub pagination_bar {
-    my $base_url = (@_ ? shift : return);
-    my $nb_pages       = (@_) ? shift : 1;
-    my $current_page   = (@_) ? shift : undef;	# delay default until later
-    my $startfrom_name = (@_) ? shift : 'page';
+    my $base_url              = ( @_ ? shift : return );
+    my $nb_pages              = (@_) ? shift : 1;
+    my $current_page          = (@_) ? shift : undef;    # delay default until later
+    my $startfrom_name        = (@_) ? shift : 'page';
     my $additional_parameters = shift || {};
 
     $base_url = HTML::Entities::encode($base_url);
@@ -92,16 +91,16 @@ sub pagination_bar {
     # how many pages to show before and after the current page?
     my $pages_around = 2;
 
-	my $delim = qr/\&(?:amp;)?|;/;		# "non memory" cluster: no backreference
-	$base_url =~ s/$delim*\b$startfrom_name=(\d+)//g; # remove previous pagination var
-    unless (defined $current_page and $current_page > 0 and $current_page <= $nb_pages) {
-        $current_page = ($1) ? $1 : 1;	# pull current page from param in URL, else default to 1
+    my $delim = qr/\&(?:amp;)?|;/;                       # "non memory" cluster: no backreference
+    $base_url =~ s/$delim*\b$startfrom_name=(\d+)//g;    # remove previous pagination var
+    unless ( defined $current_page and $current_page > 0 and $current_page <= $nb_pages ) {
+        $current_page = ($1) ? $1 : 1;                   # pull current page from param in URL, else default to 1
     }
-	$base_url =~ s/($delim)+/$1/g;	# compress duplicate delims
-	$base_url =~ s/$delim;//g;		# remove empties
-	$base_url =~ s/$delim$//;		# remove trailing delim
+    $base_url =~ s/($delim)+/$1/g;                       # compress duplicate delims
+    $base_url =~ s/$delim;//g;                           # remove empties
+    $base_url =~ s/$delim$//;                            # remove trailing delim
 
-    my $url = $base_url . (($base_url =~ m/$delim/ or $base_url =~ m/\?/) ? '&amp;' : '?' ) . $startfrom_name . '=';
+    my $url = $base_url . ( ( $base_url =~ m/$delim/ or $base_url =~ m/\?/ ) ? '&amp;' : '?' ) . $startfrom_name . '=';
     my $url_suffix = '';
     while ( my ( $k, $v ) = each %$additional_parameters ) {
         $url_suffix .= '&amp;' . URI::Escape::uri_escape_utf8($k) . '=' . URI::Escape::uri_escape_utf8($v);
@@ -110,21 +109,19 @@ sub pagination_bar {
 
     # navigation bar useful only if more than one page to display !
     if ( $nb_pages > 1 ) {
+        $pagination_bar = '<ul class="pagination output">';
 
         # link to first page?
         if ( $current_page > 1 ) {
             $pagination_bar .=
-                "\n" . '&nbsp;'
-              . '<a href="'
-              . $url
-              . '1'
-              . $url_suffix
-              . '"rel="start">'
-              . '&lt;&lt;' . '</a>';
-        }
-        else {
-            $pagination_bar .=
-              "\n" . '&nbsp;<span class="inactive">&lt;&lt;</span>';
+                  "\n"
+                . ''
+                . '<li class="page-item"><a class="page-link output first" href="'
+                . $url . '1'
+                . $url_suffix
+                . '"rel="start">'
+                . '<i class="fa fa-fw fa-angle-double-left"></i> '
+                . '</a></li>';
         }
 
         # link on previous page ?
@@ -132,16 +129,15 @@ sub pagination_bar {
             my $previous = $current_page - 1;
 
             $pagination_bar .=
-                "\n" . '&nbsp;'
-              . '<a href="'
-              . $url
-              . $previous
-              . $url_suffix
-              . '" rel="prev">' . '&lt;' . '</a>';
-        }
-        else {
-            $pagination_bar .=
-              "\n" . '&nbsp;<span class="inactive">&lt;</span>';
+                  "\n"
+                . ''
+                . '<li class="page-item"><a class="page-link output previous" href="'
+                . $url
+                . $previous
+                . $url_suffix
+                . '" rel="prev">'
+                . '<i class="fa fa-fw fa-angle-left"></i> '
+                . '</a></li>';
         }
 
         my $min_to_display      = $current_page - $pages_around;
@@ -154,31 +150,31 @@ sub pagination_bar {
                 or $page_number == $nb_pages
                 or (    $page_number >= $min_to_display
                     and $page_number <= $max_to_display )
-              )
+                )
             {
                 if ( defined $last_displayed_page
                     and $last_displayed_page != $page_number - 1 )
                 {
-                    $pagination_bar .=
-                      "\n" . '&nbsp;<span class="inactive">...</span>';
+                    $pagination_bar .= "\n" . '<li class="page-item disabled"><a class="page-link">...</a></li>';
                 }
 
                 if ( $page_number == $current_page ) {
                     $pagination_bar .=
-                        "\n" . '&nbsp;'
-                      . '<span class="currentPage">'
-                      . $page_number
-                      . '</span>';
-                }
-                else {
+                          "\n"
+                        . ''
+                        . '<li class="page-item active" aria-current="page"><a class="page-link" href="#">'
+                        . $page_number
+                        . '</a></li>';
+                } else {
                     $pagination_bar .=
-                        "\n" . '&nbsp;'
-                      . '<a href="'
-                      . $url
-                      . $page_number
-                      . $url_suffix
-                      . '">'
-                      . $page_number . '</a>';
+                          "\n"
+                        . ''
+                        . '<li class="page-item"><a class="page-link" href="'
+                        . $url
+                        . $page_number
+                        . $url_suffix . '">'
+                        . $page_number
+                        . '</a></li>';
                 }
                 $last_displayed_page = $page_number;
             }
@@ -189,31 +185,25 @@ sub pagination_bar {
             my $next = $current_page + 1;
 
             $pagination_bar .= "\n"
-              . '&nbsp;<a href="'
-              . $url
-              . $next
-              . $url_suffix
-              . '" rel="next">' . '&gt;' . '</a>';
-        }
-        else {
-            $pagination_bar .=
-              "\n" . '&nbsp;<span class="inactive">&gt;</span>';
+                . '<li class="page-item"><a class="page-link output next" href="'
+                . $url
+                . $next
+                . $url_suffix
+                . '" rel="next"><i class="fa fa-fw fa-angle-right"></i></a></li>';
         }
 
         # link to last page?
         if ( $current_page != $nb_pages ) {
             $pagination_bar .= "\n"
-              . '&nbsp;<a href="'
-              . $url
-              . $nb_pages
-              . $url_suffix
-              . '" rel="last">'
-              . '&gt;&gt;' . '</a>';
-        }
-        else {
-            $pagination_bar .=
-              "\n" . '&nbsp;<span class="inactive">&gt;&gt;</span>';
+                . '<li class="page-item"><a class="page-link output last" href="'
+                . $url
+                . $nb_pages
+                . $url_suffix
+                . '" rel="last">'
+                . ' <i class="fa fa-fw fa-angle-double-right"></i></a></li>';
         }
+
+        $pagination_bar .= "\n" . '</ul>';
     }
 
     return $pagination_bar;
@@ -250,10 +240,11 @@ sub output_with_http_headers {
         'js'   => 'text/javascript',
         'json' => 'application/json',
         'xml'  => 'text/xml',
+
         # NOTE: not using application/atom+xml or application/rss+xml because of
         # Internet Explorer 6; see bug 2078.
-        'rss'  => 'text/xml',
-        'atom' => 'text/xml',
+        'rss'                   => 'text/xml',
+        'atom'                  => 'text/xml',
         'opensearchdescription' => 'application/opensearchdescription+xml',
     );
 
@@ -268,28 +259,39 @@ sub output_with_http_headers {
         'Cache-Control'   => $cache_policy,
         'X-Frame-Options' => 'SAMEORIGIN',
     };
-    $options->{expires} = 'now' if $extra_options->{force_no_caching};
+    $options->{expires}                       = 'now' if $extra_options->{force_no_caching};
     $options->{'Access-Control-Allow-Origin'} = C4::Context->preference('AccessControlAllowOrigin')
         if C4::Context->preference('AccessControlAllowOrigin');
 
     $options->{cookie} = $cookie if $cookie;
-    if ($content_type eq 'html') {  # guaranteed to be one of the content_type_map keys, else we'd have died
-        $options->{'Content-Style-Type' } = 'text/css';
+    if ( $content_type eq 'html' ) {    # guaranteed to be one of the content_type_map keys, else we'd have died
+        $options->{'Content-Style-Type'}  = 'text/css';
         $options->{'Content-Script-Type'} = 'text/javascript';
     }
 
-# We can't encode here, that will double encode our templates, and xslt
-# We need to fix the encoding as it comes out of the database, or when we pass the variables to templates
+    # We can't encode here, that will double encode our templates, and xslt
+    # We need to fix the encoding as it comes out of the database, or when we pass the variables to templates
 
     $data =~ s/\&amp\;amp\; /\&amp\; /g;
     print $query->header($options), $data;
 }
 
+=item output_html_with_http_headers
+
+Missing POD for output_html_with_http_headers.
+
+=cut
+
 sub output_html_with_http_headers {
     my ( $query, $cookie, $data, $status, $extra_options ) = @_;
     output_with_http_headers( $query, $cookie, $data, 'html', $status, $extra_options );
 }
 
+=item output_ajax_with_http_headers
+
+Missing POD for output_ajax_with_http_headers.
+
+=cut
 
 sub output_ajax_with_http_headers {
     my ( $query, $js ) = @_;
@@ -302,6 +304,12 @@ sub output_ajax_with_http_headers {
     ), $js;
 }
 
+=item is_ajax
+
+Missing POD for is_ajax.
+
+=cut
+
 sub is_ajax {
     my $x_req = $ENV{HTTP_X_REQUESTED_WITH};
     return ( $x_req and $x_req =~ /XMLHttpRequest/i ) ? 1 : 0;
@@ -339,27 +347,24 @@ sub output_and_exit_if_error {
             my $current_patron = $params->{current_patron};
             if ( not $current_patron ) {
                 $error = 'unknown_patron';
-            }
-            elsif ( not $logged_in_user->can_see_patron_infos($current_patron) )
-            {
+            } elsif ( not $logged_in_user->can_see_patron_infos($current_patron) ) {
                 $error = 'cannot_see_patron_infos';
             }
-        }
-        elsif ( $params->{module} eq 'cataloguing' ) {
+        } elsif ( $params->{module} eq 'cataloguing' ) {
+
             # We are testing the record to avoid additem to fetch the Koha::Biblio
             # But in the long term we will want to get a biblio in parameter
             $error = 'unknown_biblio' unless $params->{record};
         }
-    }
-    elsif ( $params and exists $params->{check} ) {
+    } elsif ( $params and exists $params->{check} ) {
         if ( $params->{check} eq 'csrf_token' ) {
             $error = 'wrong_csrf_token'
-              unless Koha::Token->new->check_csrf(
+                unless Koha::Token->new->check_csrf(
                 {
                     session_id => scalar $query->cookie('CGISESSID'),
                     token      => scalar $query->param('csrf_token'),
                 }
-              );
+                );
         }
     }
     output_and_exit( $query, $cookie, $template, $error ) if $error;
@@ -378,10 +383,16 @@ sub output_and_exit_if_error {
 sub output_and_exit {
     my ( $query, $cookie, $template, $error ) = @_;
     $template->param( blocking_error => $error );
-    output_html_with_http_headers ( $query, $cookie, $template->output );
+    output_html_with_http_headers( $query, $cookie, $template->output );
     exit;
 }
 
+=item output_error
+
+Missing POD for output_error.
+
+=cut
+
 sub output_error {
     my ( $query, $error ) = @_;
     my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
@@ -393,26 +404,32 @@ sub output_error {
         }
     );
     my $admin = C4::Context->preference('KohaAdminEmailAddress');
-    $template->param (
+    $template->param(
         admin => $admin,
         errno => $error,
     );
     output_with_http_headers $query, $cookie, $template->output, 'html', '404 Not Found';
 }
 
+=item parametrized_url
+
+Missing POD for parametrized_url.
+
+=cut
+
 sub parametrized_url {
-    my $url = shift || ''; # ie page.pl?ln={LANG}
-    my $vars = shift || {}; # ie { LANG => en }
-    my $ret = $url;
-    while ( my ($key,$val) = each %$vars) {
+    my $url  = shift || '';    # ie page.pl?ln={LANG}
+    my $vars = shift || {};    # ie { LANG => en }
+    my $ret  = $url;
+    while ( my ( $key, $val ) = each %$vars ) {
         my $val_url = URI::Escape::uri_escape_utf8( $val // q{} );
         $ret =~ s/\{$key\}/$val_url/g;
     }
-    $ret =~ s/\{[^\{]*\}//g; # remove remaining vars
+    $ret =~ s/\{[^\{]*\}//g;    # remove remaining vars
     return $ret;
 }
 
-END { }    # module clean-up code here (global destructor)
+END { }                         # module clean-up code here (global destructor)
 
 1;
 __END__
