@@ -1,6 +1,5 @@
 package C4::Overdues;
 
-
 # Copyright 2000-2002 Katipo Communications
 # copyright 2010 BibLibre
 #
@@ -20,12 +19,12 @@ package C4::Overdues;
 # along with Koha; if not, see <http://www.gnu.org/licenses>.
 
 use Modern::Perl;
-use Date::Calc qw( Today );
-use Date::Manip qw( UnixDate );
-use List::MoreUtils qw( uniq );
-use POSIX qw( ceil floor );
+use Date::Calc                    qw( Today );
+use Date::Manip                   qw( UnixDate );
+use List::MoreUtils               qw( uniq );
+use POSIX                         qw( ceil floor );
 use Locale::Currency::Format 1.28 qw( currency_format FMT_SYMBOL );
-use Carp qw( carp );
+use Carp                          qw( carp );
 
 use C4::Accounts;
 use C4::Context;
@@ -37,24 +36,25 @@ use Koha::Recalls;
 use Koha::Logger;
 use Koha::Patrons;
 
-our (@ISA, @EXPORT_OK);
+our ( @ISA, @EXPORT_OK );
+
 BEGIN {
     require Exporter;
     @ISA = qw(Exporter);
 
     # subs to rename (and maybe merge some...)
     @EXPORT_OK = qw(
-      CalcFine
-      Getoverdues
-      checkoverdues
-      UpdateFine
-      GetFine
-      GetBranchcodesWithOverdueRules
-      get_chargeable_units
-      GetOverduesForBranch
-      GetOverdueMessageTransportTypes
-      parse_overdues_letter
-      GetIssuesIteminfo
+        CalcFine
+        Getoverdues
+        checkoverdues
+        UpdateFine
+        GetFine
+        GetBranchcodesWithOverdueRules
+        get_chargeable_units
+        GetOverduesForBranch
+        GetOverdueMessageTransportTypes
+        parse_overdues_letter
+        GetIssuesIteminfo
     );
 }
 
@@ -88,7 +88,7 @@ Koha database.
 #'
 sub Getoverdues {
     my $params = shift;
-    my $dbh = C4::Context->dbh;
+    my $dbh    = C4::Context->dbh;
     my $statement;
     if ( C4::Context->preference('item-level_itypes') ) {
         $statement = "
@@ -119,12 +119,11 @@ LEFT JOIN biblioitems USING (biblioitemnumber)
         push @bind_parameters, $params->{'maximumdays'};
     }
     $statement .= 'ORDER BY borrowernumber';
-    my $sth = $dbh->prepare( $statement );
-    $sth->execute( @bind_parameters );
-    return $sth->fetchall_arrayref({});
+    my $sth = $dbh->prepare($statement);
+    $sth->execute(@bind_parameters);
+    return $sth->fetchall_arrayref( {} );
 }
 
-
 =head2 checkoverdues
 
     ($count, $overdueitems) = checkoverdues($borrowernumber);
@@ -135,7 +134,7 @@ Returns a count and a list of overdueitems for a given borrowernumber
 
 sub checkoverdues {
     my $borrowernumber = shift or return;
-    my $sth = C4::Context->dbh->prepare(
+    my $sth            = C4::Context->dbh->prepare(
         "SELECT biblio.*, items.*, issues.*,
                 biblioitems.volume,
                 biblioitems.number,
@@ -172,8 +171,8 @@ sub checkoverdues {
             AND   issues.date_due < NOW()"
     );
     $sth->execute($borrowernumber);
-    my $results = $sth->fetchall_arrayref({});
-    return ( scalar(@$results), $results);  # returning the count and the results is silly
+    my $results = $sth->fetchall_arrayref( {} );
+    return ( scalar(@$results), $results );    # returning the count and the results is silly
 }
 
 =head2 CalcFine
@@ -218,10 +217,10 @@ or "Final Notice".  But CalcFine never defined any value.
 =cut
 
 sub CalcFine {
-    my ( $item, $bortype, $branchcode, $due_dt, $end_date  ) = @_;
+    my ( $item, $bortype, $branchcode, $due_dt, $end_date ) = @_;
 
     # Skip calculations if item is not overdue
-    return ( 0, 0, 0 ) unless (DateTime->compare( $due_dt, $end_date ) == -1);
+    return ( 0, 0, 0 ) unless ( DateTime->compare( $due_dt, $end_date ) == -1 );
 
     # Call the plugin hook overwrite_calc_fine of all plugins and return
     # the first defined fine.
@@ -241,14 +240,15 @@ sub CalcFine {
         if scalar @fines;
 
     my $start_date = $due_dt->clone();
+
     # get issuingrules (fines part will be used)
-    my $itemtype = $item->{itemtype} || $item->{itype};
+    my $itemtype     = $item->{itemtype} || $item->{itype};
     my $issuing_rule = Koha::CirculationRules->get_effective_rules(
         {
             categorycode => $bortype,
             itemtype     => $itemtype,
             branchcode   => $branchcode,
-            rules => [
+            rules        => [
                 'lengthunit',
                 'firstremind',
                 'chargeperiod',
@@ -263,41 +263,48 @@ sub CalcFine {
 
     $itemtype = Koha::ItemTypes->find($itemtype);
 
-    return unless $issuing_rule; # If not rule exist, there is no fine
+    return unless $issuing_rule;    # If not rule exist, there is no fine
 
     my $fine_unit = $issuing_rule->{lengthunit} || 'days';
 
-    my $chargeable_units = get_chargeable_units($fine_unit, $start_date, $end_date, $branchcode);
-    my $units_minus_grace = $chargeable_units - ($issuing_rule->{firstremind} || 0);
-    my $amount = 0;
+    my $chargeable_units  = get_chargeable_units( $fine_unit, $start_date, $end_date, $branchcode );
+    my $units_minus_grace = $chargeable_units - ( $issuing_rule->{firstremind} || 0 );
+    my $amount            = 0;
     if ( $issuing_rule->{chargeperiod} && ( $units_minus_grace > 0 ) ) {
         my $units = C4::Context->preference('FinesIncludeGracePeriod') ? $chargeable_units : $units_minus_grace;
         my $charge_periods = $units / $issuing_rule->{chargeperiod};
+
         # If chargeperiod_charge_at = 1, we charge a fine at the start of each charge period
         # if chargeperiod_charge_at = 0, we charge at the end of each charge period
-        $charge_periods = defined $issuing_rule->{chargeperiod_charge_at} && $issuing_rule->{chargeperiod_charge_at} == 1 ? ceil($charge_periods) : floor($charge_periods);
+        $charge_periods = defined $issuing_rule->{chargeperiod_charge_at}
+            && $issuing_rule->{chargeperiod_charge_at} == 1 ? ceil($charge_periods) : floor($charge_periods);
 
         # check if item has been recalled. recall should have been marked Overdue by cronjob, so only look at overdue recalls
         # only charge using recall_overdue_fine if there is an item-level recall for this particular item, OR a biblio-level recall
-        my @recalls = Koha::Recalls->search({ biblio_id => $item->{biblionumber}, status => 'overdue' })->as_list;
+        my @recalls = Koha::Recalls->search( { biblio_id => $item->{biblionumber}, status => 'overdue' } )->as_list;
         my $bib_level_recall = 0;
         $bib_level_recall = 1 if scalar @recalls > 0;
-        foreach my $recall ( @recalls ) {
-            if ( $recall->item_level and $recall->item_id == $item->{itemnumber} and $issuing_rule->{recall_overdue_fine} ) {
+        foreach my $recall (@recalls) {
+            if (    $recall->item_level
+                and $recall->item_id == $item->{itemnumber}
+                and $issuing_rule->{recall_overdue_fine} )
+            {
                 $bib_level_recall = 0;
-                $amount = $charge_periods * $issuing_rule->{recall_overdue_fine};
+                $amount           = $charge_periods * $issuing_rule->{recall_overdue_fine};
                 last;
             }
         }
         if ( $bib_level_recall and $issuing_rule->{recall_overdue_fine} ) {
+
             # biblio-level recall
             $amount = $charge_periods * $issuing_rule->{recall_overdue_fine};
         }
-        if ( scalar @recalls == 0 && $issuing_rule->{fine}) {
+        if ( scalar @recalls == 0 && $issuing_rule->{fine} ) {
+
             # no recall, use normal fine amount
             $amount = $charge_periods * $issuing_rule->{fine};
         }
-    } # else { # a zero (or null) chargeperiod or negative units_minus_grace value means no charge. }
+    }    # else { # a zero (or null) chargeperiod or negative units_minus_grace value means no charge. }
 
     $amount = $issuing_rule->{overduefinescap}
         if $issuing_rule->{overduefinescap}
@@ -312,12 +319,14 @@ sub CalcFine {
         $item->{replacementprice} = $itemtype->defaultreplacecost;
     }
 
-    $amount = $item->{replacementprice} if ( $issuing_rule->{cap_fine_to_replacement_price} && $item->{replacementprice} && $amount > $item->{replacementprice} );
+    $amount = $item->{replacementprice}
+        if ( $issuing_rule->{cap_fine_to_replacement_price}
+        && $item->{replacementprice}
+        && $amount > $item->{replacementprice} );
 
-    return ($amount, $units_minus_grace, $chargeable_units);
+    return ( $amount, $units_minus_grace, $chargeable_units );
 }
 
-
 =head2 get_chargeable_units
 
     get_chargeable_units($unit, $start_date_ $end_date, $branchcode);
@@ -333,37 +342,35 @@ C<$branchcode> is the branch whose calendar to use for finding holidays.
 =cut
 
 sub get_chargeable_units {
-    my ($unit, $date_due, $date_returned, $branchcode) = @_;
+    my ( $unit, $date_due, $date_returned, $branchcode ) = @_;
 
     # If the due date is later than the return date
     return 0 unless ( $date_returned > $date_due );
 
     my $charge_units = 0;
     my $charge_duration;
-    if ($unit eq 'hours') {
-        if(C4::Context->preference('finesCalendar') eq 'noFinesWhenClosed') {
+    if ( $unit eq 'hours' ) {
+        if ( C4::Context->preference('finesCalendar') eq 'noFinesWhenClosed' ) {
             my $calendar = Koha::Calendar->new( branchcode => $branchcode );
             $charge_duration = $calendar->hours_between( $date_due, $date_returned );
         } else {
-            $charge_duration = $date_returned->delta_ms( $date_due );
+            $charge_duration = $date_returned->delta_ms($date_due);
         }
-        if($charge_duration->in_units('hours') == 0 && $charge_duration->in_units('seconds') > 0){
+        if ( $charge_duration->in_units('hours') == 0 && $charge_duration->in_units('seconds') > 0 ) {
             return 1;
         }
         return $charge_duration->in_units('hours');
-    }
-    else { # days
-        if(C4::Context->preference('finesCalendar') eq 'noFinesWhenClosed') {
+    } else {    # days
+        if ( C4::Context->preference('finesCalendar') eq 'noFinesWhenClosed' ) {
             my $calendar = Koha::Calendar->new( branchcode => $branchcode );
             $charge_duration = $calendar->days_between( $date_due, $date_returned );
         } else {
-            $charge_duration = $date_returned->delta_days( $date_due );
+            $charge_duration = $date_returned->delta_days($date_due);
         }
         return $charge_duration->in_units('days');
     }
 }
 
-
 =head2 GetSpecialHolidays
 
     &GetSpecialHolidays($date_dues,$itemnumber);
@@ -386,9 +393,8 @@ sub GetSpecialHolidays {
     my $iteminfo = GetIssuesIteminfo($itemnumber);
 
     # use sql request to find all date between date_due and today
-    my $dbh = C4::Context->dbh;
-    my $query =
-      qq|SELECT DATE_FORMAT(concat(year,'-',month,'-',day),'%Y-%m-%d') as date
+    my $dbh   = C4::Context->dbh;
+    my $query = qq|SELECT DATE_FORMAT(concat(year,'-',month,'-',day),'%Y-%m-%d') as date
 FROM `special_holidays`
 WHERE DATE_FORMAT(concat(year,'-',month,'-',day),'%Y-%m-%d') >= ?
 AND   DATE_FORMAT(concat(year,'-',month,'-',day),'%Y-%m-%d') <= ?
@@ -400,7 +406,7 @@ AND branchcode=?
     my $dateinsec;
     my $sth = $dbh->prepare($query);
     $sth->execute( $date_dues, $today, $iteminfo->{'branchcode'} )
-      ;    # FIXME: just use NOW() in SQL instead of passing in $today
+        ;    # FIXME: just use NOW() in SQL instead of passing in $today
 
     while ( my $special_date = $sth->fetchrow_hashref ) {
         push( @result_date, $special_date );
@@ -410,8 +416,7 @@ AND branchcode=?
 
     for ( my $i = 0 ; $i < scalar(@result_date) ; $i++ ) {
         $dateinsec = UnixDate( $result_date[$i]->{'date'}, "%o" );
-        ( undef, undef, undef, undef, undef, undef, $wday, undef, undef ) =
-          localtime($dateinsec);
+        ( undef, undef, undef, undef, undef, undef, $wday, undef, undef ) = localtime($dateinsec);
         for ( my $j = 0 ; $j < scalar(@result) ; $j++ ) {
             if ( $wday == ( $result[$j]->{'weekday'} ) ) {
                 $specialdaycount--;
@@ -439,8 +444,7 @@ C<$difference> numbers of between day date of the day and date due
 sub GetRepeatableHolidays {
     my ( $date_dues, $itemnumber, $difference ) = @_;
     my $dateinsec = UnixDate( $date_dues, "%o" );
-    my ( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst ) =
-      localtime($dateinsec);
+    my ( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst ) = localtime($dateinsec);
     my @result = GetWdayFromItemnumber($itemnumber);
     my @dayclosedcount;
     my $j;
@@ -459,7 +463,6 @@ sub GetRepeatableHolidays {
     return scalar(@dayclosedcount);
 }
 
-
 =head2 GetWayFromItemnumber
 
     &Getwdayfromitemnumber($itemnumber);
@@ -470,6 +473,12 @@ C<$itemnumber> is  item number.
 
 =cut
 
+=head2 GetWdayFromItemnumber
+
+Missing POD for GetWdayFromItemnumber.
+
+=cut
+
 sub GetWdayFromItemnumber {
     my ($itemnumber) = @_;
     my $iteminfo = GetIssuesIteminfo($itemnumber);
@@ -487,7 +496,6 @@ sub GetWdayFromItemnumber {
     return @result;
 }
 
-
 =head2 GetIssuesIteminfo
 
     &GetIssuesIteminfo($itemnumber);
@@ -511,7 +519,6 @@ sub GetIssuesIteminfo {
     return $issuesinfo;
 }
 
-
 =head2 UpdateFine
 
     &UpdateFine(
@@ -560,32 +567,36 @@ sub UpdateFine {
     my $amount         = $params->{amount};
     my $due            = $params->{due} // q{};
 
-    unless ( $issue_id ) {
+    unless ($issue_id) {
         carp("No issue_id passed in!");
         return;
     }
 
-    my $dbh = C4::Context->dbh;
+    my $dbh      = C4::Context->dbh;
     my $overdues = Koha::Account::Lines->search(
         {
-            borrowernumber    => $borrowernumber,
-            debit_type_code   => 'OVERDUE'
+            borrowernumber  => $borrowernumber,
+            debit_type_code => 'OVERDUE'
         }
     );
 
     my $accountline;
     my $total_amount_other = 0.00;
+
     # Cycle through the fines and
     # - find line that relates to the requested $itemnum
     # - accumulate fines for other items
     # so we can update $itemnum fine taking in account fine caps
-    while (my $overdue = $overdues->next) {
-        if ( defined $overdue->checkout && $overdue->checkout->issue_id == $issue_id && $overdue->status eq 'UNRETURNED' ) {
+    while ( my $overdue = $overdues->next ) {
+        if (   defined $overdue->checkout
+            && $overdue->checkout->issue_id == $issue_id
+            && $overdue->status eq 'UNRETURNED' )
+        {
             if ($accountline) {
-                Koha::Logger->get->debug("Not a unique accountlines record for issue_id $issue_id"); # FIXME Do we really need to log that?
-                #FIXME Should we still count this one in total_amount ??
-            }
-            else {
+                Koha::Logger->get->debug("Not a unique accountlines record for issue_id $issue_id")
+                    ;    # FIXME Do we really need to log that?
+                         #FIXME Should we still count this one in total_amount ??
+            } else {
                 $accountline = $overdue;
             }
         }
@@ -598,18 +609,21 @@ sub UpdateFine {
         if ($accountline) {
             if ( ( $amount - $accountline->amount ) > $maxIncrease ) {
                 my $new_amount = $accountline->amount + $maxIncrease;
-                Koha::Logger->get->debug("Reducing fine for item $itemnum borrower $borrowernumber from $amount to $new_amount - MaxFine reached");
+                Koha::Logger->get->debug(
+                    "Reducing fine for item $itemnum borrower $borrowernumber from $amount to $new_amount - MaxFine reached"
+                );
                 $amount = $new_amount;
             }
-        }
-        elsif ( $amount > $maxIncrease ) {
-            Koha::Logger->get->debug("Reducing fine for item $itemnum borrower $borrowernumber from $amount to $maxIncrease - MaxFine reached");
+        } elsif ( $amount > $maxIncrease ) {
+            Koha::Logger->get->debug(
+                "Reducing fine for item $itemnum borrower $borrowernumber from $amount to $maxIncrease - MaxFine reached"
+            );
             $amount = $maxIncrease;
         }
     }
 
-    if ( $accountline ) {
-        if ( Koha::Number::Price->new($accountline->amount)->round != Koha::Number::Price->new($amount)->round ) {
+    if ($accountline) {
+        if ( Koha::Number::Price->new( $accountline->amount )->round != Koha::Number::Price->new($amount)->round ) {
             $accountline->adjust(
                 {
                     amount    => $amount,
@@ -619,22 +633,24 @@ sub UpdateFine {
             );
         }
     } else {
-        if ( $amount ) { # Don't add new fines with an amount of 0
-            my $patron = Koha::Patrons->find( $borrowernumber );
-            my $letter = eval { C4::Letters::GetPreparedLetter(
-                module                 => 'circulation',
-                letter_code            => 'OVERDUE_FINE_DESC',
-                message_transport_type => 'print',
-                lang                   => $patron->lang,
-                tables                 => {
-                    issues    => $itemnum,
-                    borrowers => $borrowernumber,
-                    items     => $itemnum,
-                },
-            ) };
-            my $desc = $letter ? $letter->{content} : sprintf("Item %s - due %s", $itemnum, output_pref($due) );
+        if ($amount) {    # Don't add new fines with an amount of 0
+            my $patron = Koha::Patrons->find($borrowernumber);
+            my $letter = eval {
+                C4::Letters::GetPreparedLetter(
+                    module                 => 'circulation',
+                    letter_code            => 'OVERDUE_FINE_DESC',
+                    message_transport_type => 'print',
+                    lang                   => $patron->lang,
+                    tables                 => {
+                        issues    => $itemnum,
+                        borrowers => $borrowernumber,
+                        items     => $itemnum,
+                    },
+                );
+            };
+            my $desc = $letter ? $letter->{content} : sprintf( "Item %s - due %s", $itemnum, output_pref($due) );
 
-            my $account = Koha::Account->new({ patron_id => $borrowernumber });
+            my $account = Koha::Account->new( { patron_id => $borrowernumber } );
             $accountline = $account->add_debit(
                 {
                     amount      => $amount,
@@ -642,7 +658,7 @@ sub UpdateFine {
                     note        => undef,
                     user_id     => undef,
                     interface   => C4::Context->interface,
-                    library_id  => undef, #FIXME: Should we grab the checkout or circ-control branch here perhaps?
+                    library_id  => undef,       #FIXME: Should we grab the checkout or circ-control branch here perhaps?
                     type        => 'OVERDUE',
                     item_id     => $itemnum,
                     issue_id    => $issue_id,
@@ -672,15 +688,14 @@ sub GetFine {
   AND amountoutstanding > 0 AND borrowernumber=?|;
     my @query_param;
     push @query_param, $borrowernumber;
-    if (defined $itemnum )
-    {
+    if ( defined $itemnum ) {
         $query .= " AND itemnumber=?";
         push @query_param, $itemnum;
     }
     my $sth = $dbh->prepare($query);
-    $sth->execute( @query_param );
+    $sth->execute(@query_param);
     my $fine = $sth->fetchrow_hashref();
-    if ($fine->{fineamount}) {
+    if ( $fine->{fineamount} ) {
         return $fine->{fineamount};
     }
     return 0;
@@ -695,16 +710,19 @@ returns a list of branch codes for branches with overdue rules defined.
 =cut
 
 sub GetBranchcodesWithOverdueRules {
-    my $dbh               = C4::Context->dbh;
-    my $branchcodes = $dbh->selectcol_arrayref(q|
+    my $dbh         = C4::Context->dbh;
+    my $branchcodes = $dbh->selectcol_arrayref(
+        q|
         SELECT DISTINCT(branchcode)
         FROM overduerules
         WHERE delay1 IS NOT NULL
         ORDER BY branchcode
-    |);
+    |
+    );
     if ( defined $branchcodes->[0] && $branchcodes->[0] eq '' ) {
+
         # If a default rule exists, all branches should be returned
-        return Koha::Libraries->search({}, { order_by => 'branchname' })->get_column('branchcode');
+        return Koha::Libraries->search( {}, { order_by => 'branchname' } )->get_column('branchcode');
     }
     return @$branchcodes;
 }
@@ -720,10 +738,10 @@ FIXME: This function should be renamed.
 =cut
 
 sub GetOverduesForBranch {
-    my ( $branch, $location) = @_;
-	my $itype_link =  (C4::Context->preference('item-level_itypes')) ?  " items.itype " :  " biblioitems.itemtype ";
-    my $dbh = C4::Context->dbh;
-    my $select = "
+    my ( $branch, $location ) = @_;
+    my $itype_link = ( C4::Context->preference('item-level_itypes') ) ? " items.itype " : " biblioitems.itemtype ";
+    my $dbh        = C4::Context->dbh;
+    my $select     = "
     SELECT
             borrowers.cardnumber,
             borrowers.borrowernumber,
@@ -766,10 +784,10 @@ sub GetOverduesForBranch {
     ";
     if ($location) {
         my $q = "$select AND items.location = ? ORDER BY borrowers.surname, borrowers.firstname";
-        return @{ $dbh->selectall_arrayref($q, { Slice => {} }, $branch, $location ) };
+        return @{ $dbh->selectall_arrayref( $q, { Slice => {} }, $branch, $location ) };
     } else {
         my $q = "$select ORDER BY borrowers.surname, borrowers.firstname";
-        return @{ $dbh->selectall_arrayref($q, { Slice => {} }, $branch ) };
+        return @{ $dbh->selectall_arrayref( $q, { Slice => {} }, $branch ) };
     }
 }
 
@@ -785,13 +803,13 @@ sub GetOverdueMessageTransportTypes {
     my ( $branchcode, $categorycode, $letternumber ) = @_;
     return unless $categorycode and $letternumber;
     my $dbh = C4::Context->dbh;
-    my $sth = $dbh->prepare("
+    my $sth = $dbh->prepare( "
         SELECT message_transport_type
         FROM overduerules odr LEFT JOIN overduerules_transport_types ott USING (overduerules_id)
         WHERE branchcode = ?
           AND categorycode = ?
           AND letternumber = ?
-    ");
+    " );
     $sth->execute( $branchcode, $categorycode, $letternumber );
     my @mtts;
     while ( my $mtt = $sth->fetchrow ) {
@@ -845,31 +863,32 @@ sub parse_overdues_letter {
     my @item_tables;
     if ( my $i = $params->{'items'} ) {
         foreach my $item (@$i) {
-            my $fine = GetFine($item->{'itemnumber'}, $params->{'borrowernumber'});
-            $item->{'fine'} = currency_format($currency_format, "$fine", FMT_SYMBOL);
+            my $fine = GetFine( $item->{'itemnumber'}, $params->{'borrowernumber'} );
+            $item->{'fine'} = currency_format( $currency_format, "$fine", FMT_SYMBOL );
+
             # if active currency isn't correct ISO code fallback to sprintf
-            $item->{'fine'} = sprintf('%.2f', $fine) unless $item->{'fine'};
+            $item->{'fine'} = sprintf( '%.2f', $fine ) unless $item->{'fine'};
 
             push @item_tables, {
-                'biblio' => $item->{'biblionumber'},
+                'biblio'      => $item->{'biblionumber'},
                 'biblioitems' => $item->{'biblionumber'},
-                'items' => $item,
-                'issues' => $item->{'itemnumber'},
+                'items'       => $item,
+                'issues'      => $item->{'itemnumber'},
             };
         }
     }
 
-    return C4::Letters::GetPreparedLetter (
-        module => 'circulation',
+    return C4::Letters::GetPreparedLetter(
+        module      => 'circulation',
         letter_code => $params->{'letter_code'},
-        branchcode => $params->{'branchcode'},
-        lang => $patron->lang,
-        tables => \%tables,
-        loops => {
+        branchcode  => $params->{'branchcode'},
+        lang        => $patron->lang,
+        tables      => \%tables,
+        loops       => {
             overdues => [ map { $_->{items}->{itemnumber} } @item_tables ],
         },
-        substitute => $substitute,
-        repeat => { item => \@item_tables },
+        substitute             => $substitute,
+        repeat                 => { item => \@item_tables },
         message_transport_type => $params->{message_transport_type},
     );
 }
