@@ -11,14 +11,14 @@ use strict;
 use warnings;
 use Exporter;
 use Encode;
-use POSIX qw(strftime);
+use POSIX  qw(strftime);
 use Socket qw(:crlf);
 use IO::Handle;
 use List::Util qw(any);
 
 use C4::SIP::Sip::Constants qw(SIP_DATETIME FID_SCREEN_MSG);
-use C4::SIP::Sip::Checksum qw(checksum);
-use C4::SIP::Logger qw( get_logger );
+use C4::SIP::Sip::Checksum  qw(checksum);
+use C4::SIP::Logger         qw( get_logger );
 
 use base qw(Exporter);
 
@@ -28,14 +28,17 @@ our @EXPORT_OK = qw(y_or_n timestamp add_field maybe_add add_count
     $last_response siplog);
 
 our %EXPORT_TAGS = (
-    all => [qw(y_or_n timestamp add_field maybe_add
-        add_count denied sipbool boolspace write_msg
-        $error_detection $protocol_version
-        $field_delimiter $last_response siplog)]);
+    all => [
+        qw(y_or_n timestamp add_field maybe_add
+            add_count denied sipbool boolspace write_msg
+            $error_detection $protocol_version
+            $field_delimiter $last_response siplog)
+    ]
+);
 
-our $error_detection = 0;
+our $error_detection  = 0;
 our $protocol_version = 1;
-our $field_delimiter = '|'; # Protocol Default
+our $field_delimiter  = '|';    # Protocol Default
 
 # We need to keep a copy of the last message we sent to the SC,
 # in case there's a transmission error and the SC sends us a
@@ -45,31 +48,53 @@ our $field_delimiter = '|'; # Protocol Default
 
 our $last_response = '';
 
+=head2 y_or_n
+
+Missing POD for y_or_n.
+
+=cut
+
+=head2 timestamp
+
+Missing POD for timestamp.
+
+=cut
+
 sub timestamp {
     my $time = $_[0] || time();
-    if ( ref $time eq 'DateTime') {
+    if ( ref $time eq 'DateTime' ) {
         return $time->strftime(SIP_DATETIME);
-    } elsif ($time=~m/^(\d{4})\-(\d{2})\-(\d{2})/) {
+    } elsif ( $time =~ m/^(\d{4})\-(\d{2})\-(\d{2})/ ) {
+
         # passing a db returned date as is + bogus time
-        return sprintf( '%04d%02d%02d    235900', $1, $2, $3);
+        return sprintf( '%04d%02d%02d    235900', $1, $2, $3 );
     }
-    return strftime(SIP_DATETIME, localtime($time));
+    return strftime( SIP_DATETIME, localtime($time) );
 }
 
 #
 # add_field(field_id, value)
 #    return constructed field value
 #
+
+=head2 add_field
+
+Missing POD for add_field.
+
+=cut
+
 sub add_field {
-    my ($field_id, $value, $server) = @_;
+    my ( $field_id, $value, $server ) = @_;
 
     return q{} if should_hide( $field_id, $value, $server );
 
-    my ($i, $ent);
+    my ( $i, $ent );
 
-    if (!defined($value)) {
-    siplog("LOG_DEBUG", "add_field: Undefined value being added to '%s'",
-           $field_id);
+    if ( !defined($value) ) {
+        siplog(
+            "LOG_DEBUG", "add_field: Undefined value being added to '%s'",
+            $field_id
+        );
         $value = '';
     }
     $value =~ s/\r\n|\r|\n/ /g;    # CR or LF terminates a sip message
@@ -77,10 +102,10 @@ sub add_field {
 
     # Replace any occurrences of the field delimiter in the
     # field value with the HTML character entity
-    $ent = sprintf("&#%d;", ord($field_delimiter));
+    $ent = sprintf( "&#%d;", ord($field_delimiter) );
 
-    while (($i = index($value, $field_delimiter)) != ($[-1)) {
-        substr($value, $i, 1) = $ent;
+    while ( ( $i = index( $value, $field_delimiter ) ) != ( $[ - 1 ) ) {
+        substr( $value, $i, 1 ) = $ent;
     }
 
     return $field_id . $value . $field_delimiter;
@@ -91,26 +116,40 @@ sub add_field {
 #    constructed field value, otherwise return the empty string.
 #    NOTE: if zero is a valid value for your field, don't use maybe_add!
 #
+
+=head2 maybe_add
+
+Missing POD for maybe_add.
+
+=cut
+
 sub maybe_add {
-    my ($fid, $value, $server) = @_;
+    my ( $fid, $value, $server ) = @_;
 
     return q{} if should_hide( $fid, $value, $server );
 
-    if ( $fid eq FID_SCREEN_MSG && $server->{account}->{screen_msg_regex} && defined($value)) {
+    if ( $fid eq FID_SCREEN_MSG && $server->{account}->{screen_msg_regex} && defined($value) ) {
         foreach my $regex (
             ref $server->{account}->{screen_msg_regex} eq "ARRAY"
             ? @{ $server->{account}->{screen_msg_regex} }
-            : $server->{account}->{screen_msg_regex} )
+            : $server->{account}->{screen_msg_regex}
+            )
         {
             $value =~ s/$regex->{find}/$regex->{replace}/g;
         }
     }
 
     return ( defined($value) && length($value) )
-      ? add_field( $fid, $value )
-      : '';
+        ? add_field( $fid, $value )
+        : '';
 }
 
+=head2 should_hide
+
+Missing POD for should_hide.
+
+=cut
+
 sub should_hide {
     my ( $field_id, $value, $server ) = @_;
 
@@ -134,19 +173,28 @@ sub should_hide {
 # or a string of four spaces if the count is invalid for some
 # reason
 #
+
+=head2 add_count
+
+Missing POD for add_count.
+
+=cut
+
 sub add_count {
-    my ($label, $count) = @_;
+    my ( $label, $count ) = @_;
 
     # If the field is unsupported, it will be undef, return blanks
     # as per the spec.
-    if (!defined($count)) {
+    if ( !defined($count) ) {
         return ' ' x 4;
     }
 
-    $count = sprintf("%04d", $count);
-    if (length($count) != 4) {
-        siplog("LOG_WARNING", "handle_patron_info: %s wrong size: '%s'",
-           $label, $count);
+    $count = sprintf( "%04d", $count );
+    if ( length($count) != 4 ) {
+        siplog(
+            "LOG_WARNING", "handle_patron_info: %s wrong size: '%s'",
+            $label,        $count
+        );
         $count = ' ' x 4;
     }
     return $count;
@@ -160,11 +208,24 @@ sub add_count {
 # that the user's not permitted to renew.  I assume that the ILS has
 # real positive tests.
 #
+
+=head2 denied
+
+Missing POD for denied.
+
+=cut
+
 sub denied {
     my $bool = shift;
-    return boolspace(!$bool);
+    return boolspace( !$bool );
 }
 
+=head2 sipbool
+
+Missing POD for sipbool.
+
+=cut
+
 sub sipbool {
     my $bool = shift;
     return $bool ? 'Y' : 'N';
@@ -173,6 +234,13 @@ sub sipbool {
 #
 # boolspace: ' ' is false, 'Y' is true. (don't ask)
 #
+
+=head2 boolspace
+
+Missing POD for boolspace.
+
+=cut
+
 sub boolspace {
     my $bool = shift;
     return $bool ? 'Y' : ' ';
@@ -189,6 +257,12 @@ sub boolspace {
 # just write to the default destination.
 #
 
+=head2 write_msg
+
+Missing POD for write_msg.
+
+=cut
+
 sub write_msg {
     my ( $self, $msg, $server ) = @_;
     my $terminator = $server->{account}->{terminator};
@@ -221,15 +295,21 @@ sub write_msg {
     $last_response = $msg;
 }
 
+=head2 siplog
+
+Missing POD for siplog.
+
+=cut
+
 sub siplog {
     my ( $level, $mask, @args ) = @_;
 
     my $method =
-        $level eq 'LOG_ERR'     ? 'error'
-      : $level eq 'LOG_DEBUG'   ? 'debug'
-      : $level eq 'LOG_INFO'    ? 'info'
-      : $level eq 'LOG_WARNING' ? 'warn'
-      :                           'error';
+          $level eq 'LOG_ERR'     ? 'error'
+        : $level eq 'LOG_DEBUG'   ? 'debug'
+        : $level eq 'LOG_INFO'    ? 'info'
+        : $level eq 'LOG_WARNING' ? 'warn'
+        :                           'error';
 
     my $message;
     if (@args) {
