@@ -24,7 +24,7 @@ package C4::XSLT;
 use Modern::Perl;
 
 use C4::Context;
-use C4::Koha qw( xml_escape );
+use C4::Koha   qw( xml_escape );
 use C4::Biblio qw( GetAuthorisedValueDesc GetFrameworkCode GetMarcStructure );
 use Koha::AuthorisedValues;
 use Koha::ItemTypes;
@@ -33,17 +33,18 @@ use Koha::XSLT::Base;
 use Koha::Libraries;
 use Koha::Recalls;
 
-my $engine; #XSLT Handler object
+my $engine;    #XSLT Handler object
+
+our ( @ISA, @EXPORT_OK );
 
-our (@ISA, @EXPORT_OK);
 BEGIN {
     require Exporter;
-    @ISA = qw(Exporter);
+    @ISA       = qw(Exporter);
     @EXPORT_OK = qw(
         buildKohaItemsNamespace
         XSLTParse4Display
     );
-    $engine=Koha::XSLT::Base->new( { do_not_return_source => 1 } );
+    $engine = Koha::XSLT::Base->new( { do_not_return_source => 1 } );
 }
 
 =head1 NAME
@@ -65,25 +66,31 @@ The helper function _get_best_default_xslt_filename is used in a unit test.
 =cut
 
 sub _get_best_default_xslt_filename {
-    my ($htdocs, $theme, $lang, $base_xslfile) = @_;
+    my ( $htdocs, $theme, $lang, $base_xslfile ) = @_;
 
     my @candidates = (
-        "$htdocs/$theme/$lang/xslt/${base_xslfile}", # exact match
-        "$htdocs/$theme/en/xslt/${base_xslfile}",    # if not, preferred theme in English
-        "$htdocs/prog/$lang/xslt/${base_xslfile}",   # if not, 'prog' theme in preferred language
-        "$htdocs/prog/en/xslt/${base_xslfile}",      # otherwise, prog theme in English; should always
-                                                     # exist
+        "$htdocs/$theme/$lang/xslt/${base_xslfile}",    # exact match
+        "$htdocs/$theme/en/xslt/${base_xslfile}",       # if not, preferred theme in English
+        "$htdocs/prog/$lang/xslt/${base_xslfile}",      # if not, 'prog' theme in preferred language
+        "$htdocs/prog/en/xslt/${base_xslfile}",         # otherwise, prog theme in English; should always
+                                                        # exist
     );
     my $xslfilename;
     foreach my $filename (@candidates) {
         $xslfilename = $filename;
-        if (-f $filename) {
-            last; # we have a winner!
+        if ( -f $filename ) {
+            last;                                       # we have a winner!
         }
     }
     return $xslfilename;
 }
 
+=head2 get_xslt_sysprefs
+
+Missing POD for get_xslt_sysprefs.
+
+=cut
+
 sub get_xslt_sysprefs {
     my $sysxml = "<sysprefs>\n";
     foreach my $syspref (
@@ -117,10 +124,16 @@ sub get_xslt_sysprefs {
     return $sysxml;
 }
 
-sub get_xsl_filename {
-    my ( $xslsyspref ) = @_;
+=head2 get_xsl_filename
 
-    my $lang   = C4::Languages::getlanguage();
+Missing POD for get_xsl_filename.
+
+=cut
+
+sub get_xsl_filename {
+    my ($xslsyspref) = @_;
+
+    my $lang = C4::Languages::getlanguage();
 
     my $xslfilename = C4::Context->preference($xslsyspref) || "default";
 
@@ -128,40 +141,36 @@ sub get_xsl_filename {
 
         my ( $htdocs, $theme, $xslfile );
 
-        if ($xslsyspref eq "XSLTDetailsDisplay") {
+        if ( $xslsyspref eq "XSLTDetailsDisplay" ) {
             $htdocs  = C4::Context->config('intrahtdocs');
             $theme   = C4::Context->preference("template");
-            $xslfile = C4::Context->preference('marcflavour') .
-                       "slim2intranetDetail.xsl";
-        } elsif ($xslsyspref eq "XSLTResultsDisplay") {
+            $xslfile = C4::Context->preference('marcflavour') . "slim2intranetDetail.xsl";
+        } elsif ( $xslsyspref eq "XSLTResultsDisplay" ) {
             $htdocs  = C4::Context->config('intrahtdocs');
             $theme   = C4::Context->preference("template");
-            $xslfile = C4::Context->preference('marcflavour') .
-                        "slim2intranetResults.xsl";
-        } elsif ($xslsyspref eq "OPACXSLTDetailsDisplay") {
+            $xslfile = C4::Context->preference('marcflavour') . "slim2intranetResults.xsl";
+        } elsif ( $xslsyspref eq "OPACXSLTDetailsDisplay" ) {
             $htdocs  = C4::Context->config('opachtdocs');
             $theme   = C4::Context->preference("opacthemes");
-            $xslfile = C4::Context->preference('marcflavour') .
-                       "slim2OPACDetail.xsl";
-        } elsif ($xslsyspref eq "OPACXSLTResultsDisplay") {
+            $xslfile = C4::Context->preference('marcflavour') . "slim2OPACDetail.xsl";
+        } elsif ( $xslsyspref eq "OPACXSLTResultsDisplay" ) {
             $htdocs  = C4::Context->config('opachtdocs');
             $theme   = C4::Context->preference("opacthemes");
-            $xslfile = C4::Context->preference('marcflavour') .
-                       "slim2OPACResults.xsl";
-        } elsif ($xslsyspref eq 'XSLTListsDisplay') {
+            $xslfile = C4::Context->preference('marcflavour') . "slim2OPACResults.xsl";
+        } elsif ( $xslsyspref eq 'XSLTListsDisplay' ) {
+
             # Lists default to *Results.xslt
             $htdocs  = C4::Context->config('intrahtdocs');
             $theme   = C4::Context->preference("template");
-            $xslfile = C4::Context->preference('marcflavour') .
-                        "slim2intranetResults.xsl";
-        } elsif ($xslsyspref eq 'OPACXSLTListsDisplay') {
+            $xslfile = C4::Context->preference('marcflavour') . "slim2intranetResults.xsl";
+        } elsif ( $xslsyspref eq 'OPACXSLTListsDisplay' ) {
+
             # Lists default to *Results.xslt
             $htdocs  = C4::Context->config('opachtdocs');
             $theme   = C4::Context->preference("opacthemes");
-            $xslfile = C4::Context->preference('marcflavour') .
-                       "slim2OPACResults.xsl";
+            $xslfile = C4::Context->preference('marcflavour') . "slim2OPACResults.xsl";
         }
-        $xslfilename = _get_best_default_xslt_filename($htdocs, $theme, $lang, $xslfile);
+        $xslfilename = _get_best_default_xslt_filename( $htdocs, $theme, $lang, $xslfile );
     }
 
     if ( $xslfilename =~ m/\{langcode\}/ ) {
@@ -172,7 +181,7 @@ sub get_xsl_filename {
 }
 
 sub XSLTParse4Display {
-    my ( $params ) = @_;
+    my ($params) = @_;
 
     my $biblionumber = $params->{biblionumber};
     my $record       = $params->{record};
@@ -186,12 +195,12 @@ sub XSLTParse4Display {
     die "Mandatory \$params->{xsl_syspref} was not provided, called with biblionumber $params->{biblionumber}"
         if not defined $params->{xsl_syspref};
 
-    my $xslfilename = get_xsl_filename( $xslsyspref);
+    my $xslfilename = get_xsl_filename($xslsyspref);
 
-    my $frameworkcode = GetFrameworkCode($biblionumber) || '';
+    my $frameworkcode    = GetFrameworkCode($biblionumber) || '';
     my $record_processor = Koha::RecordProcessor->new(
         {
-            filters => [ 'ExpandCodedFields' ],
+            filters => ['ExpandCodedFields'],
             options => {
                 interface     => $interface,
                 frameworkcode => $frameworkcode
@@ -202,24 +211,27 @@ sub XSLTParse4Display {
 
     # grab the XML, run it through our stylesheet, push it out to the browser
     my $itemsxml;
-    if ( $xslsyspref eq "OPACXSLTDetailsDisplay" || $xslsyspref eq "XSLTDetailsDisplay" || $xslsyspref eq "XSLTResultsDisplay" ) {
-        $itemsxml = ""; #We don't use XSLT for items display on these pages
+    if (   $xslsyspref eq "OPACXSLTDetailsDisplay"
+        || $xslsyspref eq "XSLTDetailsDisplay"
+        || $xslsyspref eq "XSLTResultsDisplay" )
+    {
+        $itemsxml = "";    #We don't use XSLT for items display on these pages
     } else {
-        $itemsxml = buildKohaItemsNamespace($biblionumber, $hidden_items, $items_rs);
+        $itemsxml = buildKohaItemsNamespace( $biblionumber, $hidden_items, $items_rs );
     }
-    my $xmlrecord = $record->as_xml(C4::Context->preference('marcflavour'));
+    my $xmlrecord = $record->as_xml( C4::Context->preference('marcflavour') );
 
     $variables ||= {};
     my $biblio;
-    if ( $interface eq 'opac' && C4::Context->preference('OPACShowOpenURL')) {
+    if ( $interface eq 'opac' && C4::Context->preference('OPACShowOpenURL') ) {
         my @biblio_itemtypes;
         $biblio //= Koha::Biblios->find($biblionumber);
-        if (C4::Context->preference('item-level_itypes')) {
+        if ( C4::Context->preference('item-level_itypes') ) {
             @biblio_itemtypes = $biblio->items->get_column("itype");
         } else {
             push @biblio_itemtypes, $biblio->itemtype;
         }
-        my @itypes = split( /\s/, C4::Context->preference('OPACOpenURLItemTypes') );
+        my @itypes   = split( /\s/, C4::Context->preference('OPACOpenURLItemTypes') );
         my %original = ();
         map { $original{$_} = 1 } @biblio_itemtypes;
         if ( grep { $original{$_} } @itypes ) {
@@ -229,7 +241,7 @@ sub XSLTParse4Display {
 
     # embed variables
     my $varxml = "<variables>\n";
-    while (my ($key, $value) = each %$variables) {
+    while ( my ( $key, $value ) = each %$variables ) {
         $value //= q{};
         $varxml .= "<variable name=\"$key\">$value</variable>\n";
     }
@@ -237,7 +249,7 @@ sub XSLTParse4Display {
 
     my $sysxml = get_xslt_sysprefs();
     $xmlrecord =~ s/\<\/record\>/$itemsxml$sysxml$varxml\<\/record\>/;
-    if ($fixamps) { # We need to correct the ampersand entities that Zebra outputs
+    if ($fixamps) {    # We need to correct the ampersand entities that Zebra outputs
         $xmlrecord =~ s/\&amp;amp;/\&amp;/g;
         $xmlrecord =~ s/\&amp\;lt\;/\&lt\;/g;
         $xmlrecord =~ s/\&amp\;gt\;/\&gt\;/g;
@@ -248,7 +260,7 @@ sub XSLTParse4Display {
     #If the xslt should fail, we will return undef (old behavior was
     #raw MARC)
     #Note that we did set do_not_return_source at object construction
-    return $engine->transform($xmlrecord, $xslfilename ); #file or URL
+    return $engine->transform( $xmlrecord, $xslfilename );    #file or URL
 }
 
 =head2 buildKohaItemsNamespace
@@ -267,13 +279,13 @@ Is only used in this module currently.
 =cut
 
 sub buildKohaItemsNamespace {
-    my ($biblionumber, $hidden_items, $items_rs) = @_;
+    my ( $biblionumber, $hidden_items, $items_rs ) = @_;
 
     $hidden_items ||= [];
 
     my $query = {};
     $query = { 'me.itemnumber' => { not_in => $hidden_items } }
-      if $hidden_items;
+        if $hidden_items;
 
     unless ( $items_rs && ref($items_rs) eq 'Koha::Items' ) {
         $query->{'me.biblionumber'} = $biblionumber;
@@ -282,17 +294,27 @@ sub buildKohaItemsNamespace {
 
     my $items = $items_rs->search( $query, { prefetch => [ 'branchtransfers', 'reserves' ] } );
 
-    my $shelflocations =
-      { map { $_->{authorised_value} => $_->{opac_description} } Koha::AuthorisedValues->get_descriptions_by_koha_field( { frameworkcode => "", kohafield => 'items.location' } ) };
-    my $ccodes =
-      { map { $_->{authorised_value} => $_->{opac_description} } Koha::AuthorisedValues->get_descriptions_by_koha_field( { frameworkcode => "", kohafield => 'items.ccode' } ) };
+    my $shelflocations = {
+        map { $_->{authorised_value} => $_->{opac_description} }
+            Koha::AuthorisedValues->get_descriptions_by_koha_field(
+            { frameworkcode => "", kohafield => 'items.location' }
+            )
+    };
+    my $ccodes = {
+        map { $_->{authorised_value} => $_->{opac_description} }
+            Koha::AuthorisedValues->get_descriptions_by_koha_field(
+            { frameworkcode => "", kohafield => 'items.ccode' }
+            )
+    };
 
-    my %branches = map { $_->branchcode => $_->branchname } Koha::Libraries->search({}, { order_by => 'branchname' })->as_list;
+    my %branches =
+        map { $_->branchcode => $_->branchname } Koha::Libraries->search( {}, { order_by => 'branchname' } )->as_list;
 
     my $itemtypes = { map { $_->{itemtype} => $_ } @{ Koha::ItemTypes->search->unblessed } };
-    my $xml = '';
-    my %descs = map { $_->{authorised_value} => $_ } Koha::AuthorisedValues->get_descriptions_by_koha_field( { kohafield => 'items.notforloan' } );
-    my $ref_status = C4::Context->preference('Reference_NFL_Statuses') // q{}; # fallback to 1|2 removed
+    my $xml       = '';
+    my %descs     = map { $_->{authorised_value} => $_ }
+        Koha::AuthorisedValues->get_descriptions_by_koha_field( { kohafield => 'items.notforloan' } );
+    my $ref_status = C4::Context->preference('Reference_NFL_Statuses') // q{};    # fallback to 1|2 removed
 
     while ( my $item = $items->next ) {
         my $status;
@@ -300,81 +322,82 @@ sub buildKohaItemsNamespace {
         my $recalls_count;
 
         if ( C4::Context->preference('UseRecalls') ) {
-            $recalls_count = Koha::Recalls->search({ item_id => $item->itemnumber, status => 'waiting' })->count;
+            $recalls_count = Koha::Recalls->search( { item_id => $item->itemnumber, status => 'waiting' } )->count;
         }
 
         if ($recalls_count) {
+
             # recalls take priority over holds
-            $status = 'other';
+            $status    = 'other';
             $substatus = 'Recall waiting';
-        }
-        elsif ( $item->has_pending_hold ) {
-            $status = 'other';
+        } elsif ( $item->has_pending_hold ) {
+            $status    = 'other';
             $substatus = 'Pending hold';
-        }
-        elsif ( $item->holds->waiting->count ) {
-            $status = 'other';
+        } elsif ( $item->holds->waiting->count ) {
+            $status    = 'other';
             $substatus = 'Hold waiting';
-        }
-        elsif ($item->get_transfer) {
-            $status = 'other';
+        } elsif ( $item->get_transfer ) {
+            $status    = 'other';
             $substatus = 'In transit';
-        }
-        elsif ( $item->damaged && !C4::Context->preference('AllowHoldsOnDamagedItems') ) {
+        } elsif ( $item->damaged && !C4::Context->preference('AllowHoldsOnDamagedItems') ) {
             $status    = 'other';
             $substatus = 'Damaged';
-        }
-        elsif ($item->itemlost) {
-            $status = 'other';
+        } elsif ( $item->itemlost ) {
+            $status    = 'other';
             $substatus = "Lost";
-        }
-        elsif ( $item->withdrawn) {
-            $status = 'other';
+        } elsif ( $item->withdrawn ) {
+            $status    = 'other';
             $substatus = "Withdrawn";
-        }
-        elsif ($item->onloan) {
-            $status = 'other';
+        } elsif ( $item->onloan ) {
+            $status    = 'other';
             $substatus = "Checked out";
-        }
-        elsif ( $item->notforloan ) {
-            $status = $item->notforloan =~ /^($ref_status)$/
+        } elsif ( $item->notforloan ) {
+            $status =
+                $item->notforloan =~ /^($ref_status)$/
                 ? "reference"
                 : "reallynotforloan";
-            $substatus = exists $descs{$item->notforloan} ? $descs{$item->notforloan}->{opac_description} : "Not for loan";
-        }
-        elsif ( exists $itemtypes->{ $item->effective_itemtype }
+            $substatus =
+                exists $descs{ $item->notforloan } ? $descs{ $item->notforloan }->{opac_description} : "Not for loan";
+        } elsif ( exists $itemtypes->{ $item->effective_itemtype }
             && $itemtypes->{ $item->effective_itemtype }->{notforloan}
             && $itemtypes->{ $item->effective_itemtype }->{notforloan} == 1 )
         {
-            $status = "1" =~ /^($ref_status)$/
+            $status =
+                  "1" =~ /^($ref_status)$/
                 ? "reference"
                 : "reallynotforloan";
             $substatus = "Not for loan";
-        }
-        else {
+        } else {
             $status = "available";
         }
-        my $homebranch     = C4::Koha::xml_escape($branches{$item->homebranch});
-        my $holdingbranch  = C4::Koha::xml_escape($branches{$item->holdingbranch});
-        my $resultbranch   = C4::Context->preference('OPACResultsLibrary') eq 'homebranch' ? $homebranch : $holdingbranch;
-        my $location       = C4::Koha::xml_escape($item->location && exists $shelflocations->{$item->location} ? $shelflocations->{$item->location} : $item->location);
-        my $ccode          = C4::Koha::xml_escape($item->ccode    && exists $ccodes->{$item->ccode}            ? $ccodes->{$item->ccode}            : $item->ccode);
-        my $itemcallnumber = C4::Koha::xml_escape($item->itemcallnumber);
-        my $stocknumber    = C4::Koha::xml_escape($item->stocknumber);
+        my $homebranch    = C4::Koha::xml_escape( $branches{ $item->homebranch } );
+        my $holdingbranch = C4::Koha::xml_escape( $branches{ $item->holdingbranch } );
+        my $resultbranch = C4::Context->preference('OPACResultsLibrary') eq 'homebranch' ? $homebranch : $holdingbranch;
+        my $location     = C4::Koha::xml_escape(
+              $item->location && exists $shelflocations->{ $item->location }
+            ? $shelflocations->{ $item->location }
+            : $item->location
+        );
+        my $ccode = C4::Koha::xml_escape( $item->ccode
+                && exists $ccodes->{ $item->ccode } ? $ccodes->{ $item->ccode } : $item->ccode );
+        my $itemcallnumber = C4::Koha::xml_escape( $item->itemcallnumber );
+        my $stocknumber    = C4::Koha::xml_escape( $item->stocknumber );
         $xml .=
-            "<item>"
-          . "<homebranch>$homebranch</homebranch>"
-          . "<holdingbranch>$holdingbranch</holdingbranch>"
-          . "<resultbranch>$resultbranch</resultbranch>"
-          . "<location>$location</location>"
-          . "<ccode>$ccode</ccode>"
-          . "<status>".( $status // q{} )."</status>"
-          . "<substatus>$substatus</substatus>"
-          . "<itemcallnumber>$itemcallnumber</itemcallnumber>"
-          . "<stocknumber>$stocknumber</stocknumber>"
-          . "</item>";
+              "<item>"
+            . "<homebranch>$homebranch</homebranch>"
+            . "<holdingbranch>$holdingbranch</holdingbranch>"
+            . "<resultbranch>$resultbranch</resultbranch>"
+            . "<location>$location</location>"
+            . "<ccode>$ccode</ccode>"
+            . "<status>"
+            . ( $status // q{} )
+            . "</status>"
+            . "<substatus>$substatus</substatus>"
+            . "<itemcallnumber>$itemcallnumber</itemcallnumber>"
+            . "<stocknumber>$stocknumber</stocknumber>"
+            . "</item>";
     }
-    $xml = "<items xmlns=\"http://www.koha-community.org/items\">".$xml."</items>";
+    $xml = "<items xmlns=\"http://www.koha-community.org/items\">" . $xml . "</items>";
     return $xml;
 }
 
