@@ -22,7 +22,7 @@ use Modern::Perl;
 use Koha::Database;
 use Koha::Exceptions;
 
-use base qw(Koha::Object Koha::Object::Limit::Library);
+use base qw(Koha::Object::Mixin::AdditionalFields Koha::Object Koha::Object::Limit::Library);
 
 =head1 NAME
 
