@@ -17,7 +17,6 @@ package Koha::Acquisition::Currencies;
 
 use Modern::Perl;
 
-
 use Koha::Database;
 
 use Koha::Acquisition::Currency;
@@ -39,7 +38,7 @@ Koha::Acquisition::Currencies - Koha Acquisition Currency Object set class
 =cut
 
 sub get_active {
-    my ( $self ) = @_;
+    my ($self) = @_;
     return $self->SUPER::search( { active => 1 } )->next;
 }
 
@@ -51,6 +50,12 @@ sub _type {
     return 'Currency';
 }
 
+=head2 object_class
+
+Missing POD for object_class.
+
+=cut
+
 sub object_class {
     return 'Koha::Acquisition::Currency';
 }
