@@ -21,18 +21,17 @@ use Modern::Perl;
 
 use Mojo::Base 'Mojolicious';
 
+use CGI::Compile;    # This module needs to be loaded early; do not remove
+
 use Koha::Caches;
 use Koha::Cache::Memory::Lite;
 
 sub startup {
     my ($self) = @_;
 
-    push @{$self->plugins->namespaces}, 'Koha::App::Plugin';
-    push @{$self->static->paths}, $self->home->rel_file('koha-tmpl');
-
-    # Create route for all CGI scripts, need to be loaded first because of
-    # CGI::Compile
-    $self->plugin('CGIBinKoha', opac => 1);
+    push @{ $self->plugins->namespaces }, 'Koha::App::Plugin';
+    push @{ $self->static->paths },       $self->home->rel_file('koha-tmpl');
+    $self->routes->namespaces( ['Koha::App::Controller'] );
 
     # Create routes for API
     $self->plugin('RESTV1');
@@ -40,12 +39,14 @@ sub startup {
     $self->plugin('CSRF');
     $self->plugin('Language');
 
-    $self->hook(before_dispatch => \&_before_dispatch);
-    $self->hook(around_action => \&_around_action);
+    $self->hook( before_dispatch => \&_before_dispatch );
+    $self->hook( around_action   => \&_around_action );
 
     my $r = $self->routes;
 
-    $r->any('/')->to(cb => sub { shift->redirect_to('/cgi-bin/koha/opac-main.pl') });
+    $r->any('/cgi-bin/koha/*script')->to('CGI#opac')->name('cgi');
+
+    $r->any('/')->to( cb => sub { shift->redirect_to('/cgi-bin/koha/opac-main.pl') } );
 }
 
 sub _before_dispatch {
@@ -60,7 +61,7 @@ sub _before_dispatch {
 }
 
 sub _around_action {
-    my ($next, $c, $action, $last) = @_;
+    my ( $next, $c, $action, $last ) = @_;
 
     # Flush memory caches before every request
     Koha::Caches->flush_L1_caches();
