@@ -17,7 +17,6 @@ package Koha::AuthorisedValueCategories;
 
 use Modern::Perl;
 
-
 use Koha::Database;
 use Koha::Exceptions;
 
@@ -62,6 +61,12 @@ sub _type {
     return 'AuthorisedValueCategory';
 }
 
+=head2 object_class
+
+Missing POD for object_class.
+
+=cut
+
 sub object_class {
     return 'Koha::AuthorisedValueCategory';
 }
