@@ -19,7 +19,6 @@ package Koha::AuthorisedValues;
 
 use Modern::Perl;
 
-
 use Koha::Database;
 
 use Koha::AuthorisedValue;
@@ -38,6 +37,12 @@ Koha::AuthorisedValues - Koha Authorised value Object set class
 
 =cut
 
+=head2 search_by_marc_field
+
+Missing POD for search_by_marc_field.
+
+=cut
+
 sub search_by_marc_field {
     my ( $self, $params ) = @_;
     my $frameworkcode = $params->{frameworkcode} || '';
@@ -47,37 +52,52 @@ sub search_by_marc_field {
     return unless $tagfield or $tagsubfield;
 
     return $self->SUPER::search(
-        {   'marc_subfield_structures.frameworkcode' => $frameworkcode,
+        {
+            'marc_subfield_structures.frameworkcode' => $frameworkcode,
             ( defined $tagfield    ? ( 'marc_subfield_structures.tagfield'    => $tagfield )    : () ),
             ( defined $tagsubfield ? ( 'marc_subfield_structures.tagsubfield' => $tagsubfield ) : () ),
         },
         {
-            join => { category => 'marc_subfield_structures' },
+            join     => { category => 'marc_subfield_structures' },
             order_by => [ 'category', 'lib', 'lib_opac' ],
         }
     );
 }
 
+=head2 search_by_koha_field
+
+Missing POD for search_by_koha_field.
+
+=cut
+
 sub search_by_koha_field {
     my ( $self, $params ) = @_;
-    my $frameworkcode    = $params->{frameworkcode} || '';
-    my $kohafield        = $params->{kohafield};
-    my $category         = $params->{category};
+    my $frameworkcode = $params->{frameworkcode} || '';
+    my $kohafield     = $params->{kohafield};
+    my $category      = $params->{category};
 
     return unless $kohafield;
 
     return $self->SUPER::search(
-        {   'marc_subfield_structures.frameworkcode' => $frameworkcode,
+        {
+            'marc_subfield_structures.frameworkcode' => $frameworkcode,
             'marc_subfield_structures.kohafield'     => $kohafield,
-            ( defined $category ? ( category_name    => $category )         : () ),
+            ( defined $category ? ( category_name => $category ) : () ),
         },
-        {   join     => { category => 'marc_subfield_structures' },
+        {
+            join     => { category => 'marc_subfield_structures' },
             distinct => 1,
             order_by => [ 'category', 'lib', 'lib_opac' ],
         }
     );
 }
 
+=head2 find_by_koha_field
+
+Missing POD for find_by_koha_field.
+
+=cut
+
 sub find_by_koha_field {
     my ( $self, $params ) = @_;
     my $frameworkcode    = $params->{frameworkcode} || '';
@@ -85,17 +105,25 @@ sub find_by_koha_field {
     my $authorised_value = $params->{authorised_value};
 
     my $av = $self->SUPER::search(
-        {   'marc_subfield_structures.frameworkcode' => $frameworkcode,
+        {
+            'marc_subfield_structures.frameworkcode' => $frameworkcode,
             'marc_subfield_structures.kohafield'     => $kohafield,
             'me.authorised_value'                    => $authorised_value,
         },
-        {   join     => { category => 'marc_subfield_structures' },
+        {
+            join     => { category => 'marc_subfield_structures' },
             distinct => 1,
         }
     );
     return $av->count ? $av->next : undef;
 }
 
+=head2 get_description_by_koha_field
+
+Missing POD for get_description_by_koha_field.
+
+=cut
+
 sub get_description_by_koha_field {
     my ( $self, $params ) = @_;
     my $frameworkcode    = $params->{frameworkcode} || '';
@@ -110,7 +138,7 @@ sub get_description_by_koha_field {
     return $cached if $cached;
 
     my $av = $self->find_by_koha_field($params);
-    if ( ! defined $av ){
+    if ( !defined $av ) {
         $memory_cache->set_in_cache( $cache_key, {} );
         return {};
     }
@@ -119,10 +147,16 @@ sub get_description_by_koha_field {
     return $descriptions;
 }
 
+=head2 get_descriptions_by_koha_field
+
+Missing POD for get_descriptions_by_koha_field.
+
+=cut
+
 sub get_descriptions_by_koha_field {
     my ( $self, $params ) = @_;
     my $frameworkcode = $params->{frameworkcode} || '';
-    my $kohafield = $params->{kohafield};
+    my $kohafield     = $params->{kohafield};
 
     my $memory_cache = Koha::Cache::Memory::Lite->get_instance;
     my $cache_key    = "AV_descriptions:$frameworkcode:$kohafield";
@@ -173,12 +207,18 @@ sub get_descriptions_by_marc_field {
     return $descriptions;
 }
 
+=head2 categories
+
+Missing POD for categories.
+
+=cut
+
 sub categories {
-    my ( $self ) = @_;
+    my ($self) = @_;
     my $rs = $self->_resultset->search(
         undef,
         {
-            select => ['category'],
+            select   => ['category'],
             distinct => 1,
             order_by => 'category',
         },
@@ -194,6 +234,12 @@ sub _type {
     return 'AuthorisedValue';
 }
 
+=head2 object_class
+
+Missing POD for object_class.
+
+=cut
+
 sub object_class {
     return 'Koha::AuthorisedValue';
 }
