@@ -17,7 +17,6 @@ package Koha::Authority::Type;
 
 use Modern::Perl;
 
-
 use Koha::Database;
 
 use base qw(Koha::Object);
@@ -32,8 +31,14 @@ Koha::Authority::Type - Koha Authority Type Object class
 
 =cut
 
+=head2 auth_tag_structures
+
+Missing POD for auth_tag_structures.
+
+=cut
+
 sub auth_tag_structures {
-    my ( $self ) = @_;
+    my ($self) = @_;
     return $self->_result->auth_tag_structures;
 }
 
