@@ -17,7 +17,6 @@ package Koha::Biblio::Metadatas;
 
 use Modern::Perl;
 
-
 use Koha::Database;
 
 use Koha::Biblio::Metadata;
@@ -42,6 +41,12 @@ sub _type {
     return 'BiblioMetadata';
 }
 
+=head2 object_class
+
+Missing POD for object_class.
+
+=cut
+
 sub object_class {
     return 'Koha::Biblio::Metadata';
 }
