@@ -36,13 +36,18 @@ Koha::Bookings - Koha Booking object set class
 
     $bookings->filter_by_active;
 
-Will return the bookings that have not ended.
+Will return the bookings that have not ended, were cancelled or are completed.
 
 =cut
 
 sub filter_by_active {
     my ($self) = @_;
-    return $self->search( { end_date => { '>=' => \'NOW()' } } );
+    return $self->search(
+        {
+            end_date => { '>='      => \'NOW()' },
+            status   => { '-not_in' => [ 'cancelled', 'completed' ] }
+        }
+    );
 }
 
 =head2 Internal Methods
