@@ -19,7 +19,6 @@ package Koha::Club::Enrollments;
 
 use Modern::Perl;
 
-
 use Koha::Database;
 
 use Koha::Club::Enrollment;
@@ -46,6 +45,12 @@ sub _type {
     return 'ClubEnrollment';
 }
 
+=head2 object_class
+
+Missing POD for object_class.
+
+=cut
+
 sub object_class {
     return 'Koha::Club::Enrollment';
 }
