@@ -183,6 +183,7 @@ sub columns {
             "password"                    => __("Password"),
             "phone"                       => __("Primary phone"),
             "phonepro"                    => __("Secondary phone"),
+            "preferred_name"              => __("Preferred name"),
             "primary_contact_method"      => __("Primary contact method"),
             "privacy_guarantor_checkouts" => __("Show checkouts to guarantor"),
             "privacy_guarantor_fines"     => __("Show fines to guarantor"),
@@ -301,7 +302,7 @@ sub columns {
             "publishercode"         => __("Publisher"),
             "size"                  => __("Size"),
             "timestamp"             => __("Modification date"),
-            "totalissues"           => __("Koha issues (borrowed), all copies"),
+            "totalissues"           => __("Total checkouts, all items"),
             "url"                   => __("URL"),
             "volume"                => __("Volume number"),
             "volumedate"            => __("Volume date"),
