@@ -17,7 +17,6 @@ package Koha::ERM::EHoldings::Packages;
 
 use Modern::Perl;
 
-
 use Koha::Database;
 
 use Koha::ERM::EHoldings::Package;
@@ -42,6 +41,12 @@ sub _type {
     return 'ErmEholdingsPackage';
 }
 
+=head2 object_class
+
+Missing POD for object_class.
+
+=cut
+
 sub object_class {
     return 'Koha::ERM::EHoldings::Package';
 }
