@@ -17,8 +17,10 @@ package Koha::Item::Transfer;
 
 use Modern::Perl;
 
+use JSON qw(to_json);
 
 use C4::Items qw( CartToShelf ModDateLastSeen );
+use C4::Log   qw( logaction );
 
 use Koha::Database;
 use Koha::DateUtils qw( dt_from_string );
@@ -32,10 +34,39 @@ Koha::Item::Transfer - Koha Item Transfer Object class
 
 =head1 API
 
-=head2 Class Methods
+=head2 Class methods
+
+=head3 store
+
+Overloaded I<store> method.
 
 =cut
 
+sub store {
+    my ($self) = @_;
+
+    $self->_result->result_source->schema->txn_do(
+        sub {
+            my $action = $self->in_storage ? 'UPDATE' : 'CREATE';
+
+            $self = $self->SUPER::store;
+            $self->discard_changes;
+
+            logaction(
+                "TRANSFERS",
+                $action,
+                $self->itemnumber,
+                to_json(
+                    $self->TO_JSON,
+                    { utf8 => 1, pretty => 1, canonical => 1, }
+                )
+            ) if C4::Context->preference("TransfersLog");
+        }
+    );
+
+    return $self;
+}
+
 =head3 item
 
   my $item = $transfer->item;
@@ -92,16 +123,16 @@ reindex.
 =cut
 
 sub transit {
-    my ($self, $params) = @_;
+    my ( $self, $params ) = @_;
 
     # Throw exception if item is still checked out
     Koha::Exceptions::Item::Transfer::OnLoan->throw() if ( $self->item->checkout );
 
     # Remove the 'shelving cart' location status if it is being used (Bug 3701)
     CartToShelf( $self->item->itemnumber )
-      if $self->item->location
-      && $self->item->location eq 'CART'
-      && (!$self->item->permanent_location
+        if $self->item->location
+        && $self->item->location eq 'CART'
+        && ( !$self->item->permanent_location
         || $self->item->permanent_location ne 'CART' );
 
     # Update the transit state
@@ -126,9 +157,7 @@ Boolean returning whether the transfer is in transit or waiting
 sub in_transit {
     my ($self) = @_;
 
-    return ( defined( $self->datesent )
-          && !defined( $self->datearrived )
-          && !defined( $self->datecancelled ) );
+    return ( defined( $self->datesent ) && !defined( $self->datearrived ) && !defined( $self->datecancelled ) );
 }
 
 =head3 receive
@@ -141,10 +170,10 @@ sub receive {
     my ($self) = @_;
 
     # Throw exception if item is checked out
-    Koha::Exceptions::Item::Transfer::OnLoan->throw() if ($self->item->checkout);
+    Koha::Exceptions::Item::Transfer::OnLoan->throw() if ( $self->item->checkout );
 
     # Update the arrived date
-    $self->set({ datearrived => dt_from_string })->store;
+    $self->set( { datearrived => dt_from_string } )->store;
 
     ModDateLastSeen( $self->item->itemnumber );
     return $self;
@@ -161,22 +190,18 @@ Cancel the transfer by setting the datecancelled time and recording the reason.
 sub cancel {
     my ( $self, $params ) = @_;
 
-    Koha::Exceptions::MissingParameter->throw(
-        error => "The 'reason' parameter is mandatory" )
-      unless defined($params->{reason});
+    Koha::Exceptions::MissingParameter->throw( error => "The 'reason' parameter is mandatory" )
+        unless defined( $params->{reason} );
 
     # Throw exception if item is in transit already
     Koha::Exceptions::Item::Transfer::InTransit->throw() if ( !$params->{force} && $self->in_transit );
 
     # Update the cancelled date
-    $self->set(
-        { datecancelled => dt_from_string, cancellation_reason => $params->{reason} } )
-      ->store;
+    $self->set( { datecancelled => dt_from_string, cancellation_reason => $params->{reason} } )->store;
 
     return $self;
 }
 
-
 =head3 strings_map
 
 Returns a map of column name to string representations including the string.
