@@ -38,9 +38,9 @@ sub _get_help_version {
     my $help_version = C4::Context->preference("Version");
     if ( $help_version =~ m|^(\d+)\.(\d{2}).*$| ) {
         my $version = $1;
-        my $major = $2;
-        unless ( $major % 2 ) { $major-- };
-        $major = sprintf("%02d", $major);
+        my $major   = $2;
+        unless ( $major % 2 ) { $major-- }
+        $major        = sprintf( "%02d", $major );
         $help_version = "$version.$major";
     }
     return $help_version;
@@ -55,18 +55,18 @@ Use system preferences 'KohaManualLanguage' and 'KohaManualBaseURL' to properly
 =cut
 
 sub _get_base_url {
-    my ( $preferred_language ) = @_;
+    my ($preferred_language) = @_;
 
     my @available_languages = qw( en ar cs es fr it pt_BR tz zh_TW );
 
-    my ( $language ) = grep {
+    my ($language) = grep {
         my $preferred_short = substr $preferred_language, 0, 2;
-        my $avail_short = substr $_, 0, 2;
+        my $avail_short     = substr $_,                  0, 2;
         $preferred_short eq $avail_short ? $_ : ()
     } @available_languages;
 
     my $KohaManualLanguage = $language || C4::Context->preference('KohaManualLanguage') || 'en';
-    my $KohaManualBaseURL = C4::Context->preference('KohaManualBaseURL') || 'https://koha-community.org/manual';
+    my $KohaManualBaseURL  = C4::Context->preference('KohaManualBaseURL') || 'https://koha-community.org/manual';
     if ( $KohaManualBaseURL =~ m|^/| ) {
         $KohaManualBaseURL = C4::Context->preference('staffClientBaseURL') . $KohaManualBaseURL;
     }
@@ -97,9 +97,12 @@ our $mapping = {
     'acqui/orderreceive'                       => '/acquisitions.html#receiving-orders',
     'acqui/parcel'                             => '/acquisitions.html#receiving-orders',
     'acqui/parcels'                            => '/acquisitions.html#receiving-orders',
-    'acqui/supplier'                           => '/acquisitions.html#vendors',
     'acqui/uncertainprice'                     => '/acquisitions.html#create-a-basket',
     'acqui/z3950_search'                       => '/acquisitions.html#create-a-basket',
+    'acquisition/vendors'                      => '/acquisitions.html#vendors',
+    'acquisition/vendors/'                     => '/acquisitions.html#vendors',
+    'acquisition/vendors/add'                  => '/acquisitions.html#vendors',
+    'acquisition/vendors/edit/'                => '/acquisitions.html#vendors',
     'admin/additional-fields'                  => '/administration.html#additional-fields',
     'admin/admin-home'                         => '/administration.html',
     'admin/aqbudgetperiods'                    => '/administration.html#budgets',
@@ -332,21 +335,21 @@ our $mapping = {
     'tools/holidays'                           => '/tools.html#calendar',
     'tools/import_borrowers'                   => '/tools.html#patron-import',
     'tools/inventory'                          => '/cataloging.html#inventory',
-    'tools/additional-contents'                => '/tools.html#news', # FIXME Needs a change to the manual
-    'tools/letter'                             => '/tools.html#notices-slips',
-    'tools/manage-marc-import'                 => '/cataloging.html#managing-staged-records',
-    'tools/marc_modification_templates'        => '/cataloging.html#marc-modification-templates',
-    'tools/modborrowers'                       => '/tools.html#batch-patron-modification',
-    'tools/overduerules'                       => '/tools.html#overdue-notice-status-triggers',
-    'tools/picture-upload'                     => '/tools.html#upload-patron-images',
-    'tools/quotes-upload'                      => '/tools.html#import-quotes',
-    'tools/quotes'                             => '/tools.html#quote-of-the-day-(qotd)-editor',
-    'tools/scheduler'                          => '/tools.html#task-scheduler',
-    'tools/stage-marc-import'                  => '/cataloging.html#staging-records-for-import',
-    'tools/tools-home'                         => '/tools.html',
-    'tools/upload-cover-image'                 => '/cataloging.html#adding-cover-images',
-    'tools/viewlog'                            => '/tools.html#log-viewer',
-    'virtualshelves/shelves'                   => '/lists.html#lists',
+    'tools/additional-contents' => '/tools.html#news',                           # FIXME Needs a change to the manual
+    'tools/letter'              => '/tools.html#notices-slips',
+    'tools/manage-marc-import'  => '/cataloging.html#managing-staged-records',
+    'tools/marc_modification_templates' => '/cataloging.html#marc-modification-templates',
+    'tools/modborrowers'                => '/tools.html#batch-patron-modification',
+    'tools/overduerules'                => '/tools.html#overdue-notice-status-triggers',
+    'tools/picture-upload'              => '/tools.html#upload-patron-images',
+    'tools/quotes-upload'               => '/tools.html#import-quotes',
+    'tools/quotes'                      => '/tools.html#quote-of-the-day-(qotd)-editor',
+    'tools/scheduler'                   => '/tools.html#task-scheduler',
+    'tools/stage-marc-import'           => '/cataloging.html#staging-records-for-import',
+    'tools/tools-home'                  => '/tools.html',
+    'tools/upload-cover-image'          => '/cataloging.html#adding-cover-images',
+    'tools/viewlog'                     => '/tools.html#log-viewer',
+    'virtualshelves/shelves'            => '/lists.html#lists',
 };
 
 =head3 get_url
@@ -362,7 +365,8 @@ sub get_url {
     my $file;
     if (   $url =~ /koha\/(.*)\.pl/
         || $url =~ '/koha/(erm[^?]*)'
-        || $url =~ '/koha/(preservation[^?]*)' )
+        || $url =~ '/koha/(preservation[^?]*)'
+        || $url =~ '/koha/(acquisition/vendors[^?]*)' )
     {
         $file = $1;
     } else {
@@ -370,7 +374,7 @@ sub get_url {
     }
     $file =~ s/[^a-zA-Z0-9_\-\/]*//g;
 
-    if ( $file =~ m|^erm| || $file =~ m|^preservation| ) {
+    if ( $file =~ m|^erm| || $file =~ m|^preservation| || $file =~ m|^acquisition/vendors| ) {
         $file =~ s|\d*+||g;
     }
 
