@@ -21,10 +21,11 @@ use Modern::Perl;
 
 use Array::Utils qw( array_minus );
 use Class::Inspector;
-use List::MoreUtils qw( any );
+use List::MoreUtils           qw( any none );
 use Module::Load::Conditional qw( can_load );
 use Module::Load;
-use Module::Pluggable search_path => ['Koha::Plugin'], except => qr/::Edifact(|::Line|::Message|::Order|::Segment|::Transport)$/;
+use Module::Pluggable search_path => ['Koha::Plugin'],
+    except                        => qr/::Edifact(|::Line|::Message|::Order|::Segment|::Transport)$/;
 use Try::Tiny;
 use POSIX qw(getpid);
 
@@ -32,6 +33,7 @@ use C4::Context;
 use C4::Output;
 
 use Koha::Cache::Memory::Lite;
+use Koha::Exceptions;
 use Koha::Exceptions::Plugin;
 use Koha::Plugins::Datas;
 use Koha::Plugins::Methods;
@@ -41,7 +43,7 @@ use constant ENABLED_PLUGINS_CACHE_KEY => 'enabled_plugins';
 BEGIN {
     my $pluginsdir = C4::Context->config("pluginsdir");
     my @pluginsdir = ref($pluginsdir) eq 'ARRAY' ? @$pluginsdir : $pluginsdir;
-    push @INC, array_minus(@pluginsdir, @INC) ;
+    push @INC, array_minus( @pluginsdir, @INC );
     pop @INC if $INC[-1] eq '.';
 }
 
@@ -77,7 +79,7 @@ updated by preceding plugins, provided that these plugins support that.
 =cut
 
 sub call {
-    my ($class, $method, @args) = @_;
+    my ( $class, $method, @args ) = @_;
 
     return unless C4::Context->config('enable_plugins');
 
@@ -86,13 +88,14 @@ sub call {
     @plugins = grep { $_->can($method) } @plugins;
 
     # TODO: Remove warn when after_hold_create is removed from the codebase
-    warn "after_hold_create is deprecated and will be removed soon. Contact the following plugin's authors: " . join( ', ', map {$_->{metadata}->{name}} @plugins)
+    warn "after_hold_create is deprecated and will be removed soon. Contact the following plugin's authors: "
+        . join( ', ', map { $_->{metadata}->{name} } @plugins )
         if $method eq 'after_hold_create' and @plugins;
 
     foreach my $plugin (@plugins) {
         my $response = eval { $plugin->$method(@args) };
         if ($@) {
-            warn sprintf("Plugin error (%s): %s", $plugin->get_metadata->{name}, $@);
+            warn sprintf( "Plugin error (%s): %s", $plugin->get_metadata->{name}, $@ );
             next;
         }
 
@@ -122,7 +125,7 @@ sub get_enabled_plugins {
 
         my @plugin_classes;
         try {
-            my $rs = Koha::Plugins::Datas->search({ plugin_key => '__ENABLED__', plugin_value => 1 });
+            my $rs = Koha::Plugins::Datas->search( { plugin_key => '__ENABLED__', plugin_value => 1 } );
             @plugin_classes = $rs->get_column('plugin_class');
         } catch {
             warn "$_";
@@ -132,14 +135,14 @@ sub get_enabled_plugins {
             next unless can_load( modules => { $plugin_class => undef }, verbose => $verbose, nocache => 1 );
 
             my $plugin = eval { $plugin_class->new() };
-            if ($@ || !$plugin) {
+            if ( $@ || !$plugin ) {
                 warn "Failed to instantiate plugin $plugin_class: $@";
                 next;
             }
 
             push @$enabled_plugins, $plugin;
         }
-        Koha::Cache::Memory::Lite->set_in_cache(ENABLED_PLUGINS_CACHE_KEY, $enabled_plugins);
+        Koha::Cache::Memory::Lite->set_in_cache( ENABLED_PLUGINS_CACHE_KEY, $enabled_plugins );
     }
 
     return @$enabled_plugins;
@@ -147,6 +150,7 @@ sub get_enabled_plugins {
 
 sub _verbose {
     my $class = shift;
+
     # Return false when running unit tests
     return exists $ENV{_} && $ENV{_} =~ /\/prove(\s|$)|\/koha-qa\.pl$|\.t$/ ? 0 : 1;
 }
@@ -206,18 +210,18 @@ sub GetPlugins {
     my $errors       = $params->{errors};
 
     # By default dont warn here unless asked to do so.
-    my $verbose      = $params->{verbose} // 0;
+    my $verbose = $params->{verbose} // 0;
 
-    my $filter = ( $method ) ? { plugin_method => $method } : undef;
+    my $filter = ($method) ? { plugin_method => $method } : undef;
 
     my $plugin_classes = Koha::Plugins::Methods->search(
         $filter,
-        {   columns  => 'plugin_class',
+        {
+            columns  => 'plugin_class',
             distinct => 1
         }
     )->_resultset->get_column('plugin_class');
 
-
     # Loop through all plugins that implement at least a method
     my ( @plugins, @failing );
     while ( my $plugin_class = $plugin_classes->next ) {
@@ -227,31 +231,35 @@ sub GetPlugins {
             my $failed_instantiation;
 
             try {
-                $plugin = $plugin_class->new({
-                    enable_plugins => $self->{'enable_plugins'}
-                        # loads even if plugins are disabled
-                        # FIXME: is this for testing without bothering to mock config?
-                });
-            }
-            catch {
+                $plugin = $plugin_class->new(
+                    {
+                        enable_plugins => $self->{'enable_plugins'}
+
+                            # loads even if plugins are disabled
+                            # FIXME: is this for testing without bothering to mock config?
+                    }
+                );
+            } catch {
                 warn "$_";
                 $failed_instantiation = 1;
             };
 
             next if $failed_instantiation;
 
-            next unless $plugin->is_enabled or
-                        defined($params->{all}) && $params->{all};
+            next
+                unless $plugin->is_enabled
+                or defined( $params->{all} ) && $params->{all};
 
             # filter the plugin out by metadata
             my $plugin_metadata = $plugin->get_metadata;
             next
                 if $plugin_metadata
                 and %$req_metadata
-                and any { !$plugin_metadata->{$_} || $plugin_metadata->{$_} ne $req_metadata->{$_} } keys %$req_metadata;
+                and any { !$plugin_metadata->{$_} || $plugin_metadata->{$_} ne $req_metadata->{$_} }
+                keys %$req_metadata;
 
             push @plugins, $plugin;
-        } elsif( $errors ) {
+        } elsif ($errors) {
             push @failing, { error => 1, name => $plugin_class };
         }
     }
@@ -261,12 +269,31 @@ sub GetPlugins {
 
 =head2 InstallPlugins
 
-Koha::Plugins::InstallPlugins( [ verbose => 1 ] )
+    my $plugins = Koha::Plugins->new();
+    $plugins->InstallPlugins(
+        {
+          [ verbose => 1,
+            include => ( 'Koha::Plugin::A', ... ),
+            exclude => ( 'Koha::Plugin::X', ... ), ]
+        }
+    );
 
 This method iterates through all plugins physically present on a system.
 For each plugin module found, it will test that the plugin can be loaded,
 and if it can, will store its available methods in the plugin_methods table.
 
+Parameters:
+
+=over 4
+
+=item B<exclude>: A list of class names to exclude from the process.
+
+=item B<include>: A list of class names to limit the process to.
+
+=item B<verbose>: Print useful information.
+
+=back
+
 NOTE: We reload all plugins here as a protective measure in case someone
 has removed a plugin directly from the system without using the UI
 
@@ -279,6 +306,36 @@ sub InstallPlugins {
     my @plugin_classes = $self->plugins();
     my @plugins;
 
+    Koha::Exceptions::BadParameter->throw("Only one of 'include' and 'exclude' can be passed")
+        if ( $params->{exclude} && $params->{include} );
+
+    if ( defined( $params->{include} ) || defined( $params->{exclude} ) ) {
+        my @classes_filters =
+            defined( $params->{include} )
+            ? @{ $params->{include} }
+            : @{ $params->{exclude} };
+
+        # Warn user if the specified classes doesn't exist and return nothing
+        foreach my $class_name (@classes_filters) {
+            unless ( any { $class_name eq $_ } @plugin_classes ) {
+                Koha::Exceptions::BadParameter->throw("$class_name has not been found, try a different name");
+            }
+        }
+
+        # filter things
+        if ( $params->{include} ) {
+            @plugin_classes = grep {
+                my $plugin_class = $_;
+                any { $plugin_class eq $_ } @classes_filters
+            } @plugin_classes;
+        } else {    # exclude
+            @plugin_classes = grep {
+                my $plugin_class = $_;
+                none { $plugin_class eq $_ } @classes_filters
+            } @plugin_classes;
+        }
+    }
+
     foreach my $plugin_class (@plugin_classes) {
         if ( can_load( modules => { $plugin_class => undef }, verbose => $verbose, nocache => 1 ) ) {
             next unless $plugin_class->isa('Koha::Plugins::Base');
@@ -287,16 +344,15 @@ sub InstallPlugins {
             my $failed_instantiation;
 
             try {
-                $plugin = $plugin_class->new({ enable_plugins => $self->{'enable_plugins'} });
-            }
-            catch {
+                $plugin = $plugin_class->new( { enable_plugins => $self->{'enable_plugins'} } );
+            } catch {
                 warn "$_";
                 $failed_instantiation = 1;
             };
 
             next if $failed_instantiation;
 
-            Koha::Plugins::Methods->search({ plugin_class => $plugin_class })->delete();
+            Koha::Plugins::Methods->search( { plugin_class => $plugin_class } )->delete();
 
             foreach my $method ( @{ Class::Inspector->methods( $plugin_class, 'public' ) } ) {
                 Koha::Plugins::Method->new(
