@@ -43,7 +43,13 @@ Koha::REST::Plugin::Exceptions
     }
 
 Provides a generic and reusable way to throw unhandled exceptions. This way we
-can centralize the behaviour control (e.g. production vs. development environmet)
+can centralize the behaviour control (e.g. production vs. development environment)
+
+=cut
+
+=head2 register
+
+Missing POD for register.
 
 =cut
 
@@ -57,7 +63,7 @@ sub register {
             my $req    = $c->req;
             my $method = $req->method;
             my $path   = $req->url->to_abs->path;
-            my $type = "";
+            my $type   = "";
 
             if ( blessed $exception && ref($exception) eq 'Koha::Exceptions::REST::Query::InvalidOperator' ) {
                 return $c->render(
@@ -67,8 +73,7 @@ sub register {
                         error_code => 'invalid_query',
                     }
                 );
-            }
-            elsif ( blessed $exception
+            } elsif ( blessed $exception
                 && ref($exception) eq 'Koha::Exceptions::REST::Public::Authentication::Required' )
             {
                 return $c->render(
@@ -95,7 +100,7 @@ sub register {
 
             my $message = "$method $path: unhandled exception $type\<\<$exception_string\>\>";
 
-            $c->app->log->error( "$message" );
+            $c->app->log->error("$message");
 
             $c->render(
                 status => 500,
