@@ -33,10 +33,16 @@ It will replace characters that are not valid for HTML IDs with an underscore (_
 
 =cut
 
+=head2 filter
+
+Missing POD for filter.
+
+=cut
+
 sub filter {
     my ( $self, $text ) = @_;
 
-    return $text =~ s/[^a-zA-Z0-9-]+/_/gr
+    return $text =~ s/[^a-zA-Z0-9-]+/_/gr;
 }
 
 1;
