@@ -24,18 +24,18 @@ use Modern::Perl;
 
 use CGI qw ( -utf8 );
 use DateTime::TimeZone;
-use File::Slurp qw( read_file );
-use IPC::Cmd qw(can_run);
-use List::MoreUtils qw( any );
+use File::Slurp               qw( read_file );
+use IPC::Cmd                  qw(can_run);
+use List::MoreUtils           qw( any );
 use Module::Load::Conditional qw( can_load );
-use Config qw( %Config );
+use Config                    qw( %Config );
 use Search::Elasticsearch;
 use Try::Tiny qw( catch try );
 use YAML::XS;
 use Encode;
 
 use C4::Output qw( output_html_with_http_headers );
-use C4::Auth qw( get_template_and_user get_user_subpermissions );
+use C4::Auth   qw( get_template_and_user get_user_subpermissions );
 use C4::Context;
 use C4::Installer;
 use C4::Installer::PerlModules;
@@ -61,15 +61,15 @@ use Koha::Filter::MARC::ViewPolicy;
 
 use C4::Members::Statistics;
 
-my $query = CGI->new;
+my $query  = CGI->new;
 my $params = $query->Vars();
 
 my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
     {
-        template_name   => "about.tt",
-        query           => $query,
-        type            => "intranet",
-        flagsrequired   => { catalogue => 1 },
+        template_name => "about.tt",
+        query         => $query,
+        type          => "intranet",
+        flagsrequired => { catalogue => 1 },
     }
 );
 
@@ -93,20 +93,21 @@ my %versions = C4::Context::get_versions();
 
 if ( $tab eq 'about' ) {
 
-    my $config_timezone = C4::Context->config('timezone') // '';
-    my $config_invalid  = !DateTime::TimeZone->is_valid_name( $config_timezone );
-    my $env_timezone    = $ENV{TZ} // '';
-    my $env_invalid     = !DateTime::TimeZone->is_valid_name( $env_timezone );
+    my $config_timezone        = C4::Context->config('timezone') // '';
+    my $config_invalid         = !DateTime::TimeZone->is_valid_name($config_timezone);
+    my $env_timezone           = $ENV{TZ} // '';
+    my $env_invalid            = !DateTime::TimeZone->is_valid_name($env_timezone);
     my $actual_bad_tz_fallback = 0;
 
-    if ( $config_timezone ne '' &&
-        $config_invalid ) {
+    if (   $config_timezone ne ''
+        && $config_invalid )
+    {
         # Bad config
         $actual_bad_tz_fallback = 1;
-    }
-    elsif ( $config_timezone eq '' &&
-            $env_timezone    ne '' &&
-            $env_invalid ) {
+    } elsif ( $config_timezone eq ''
+        && $env_timezone ne ''
+        && $env_invalid )
+    {
         # No config, but bad ENV{TZ}
         $actual_bad_tz_fallback = 1;
     }
@@ -120,31 +121,13 @@ if ( $tab eq 'about' ) {
         environment_invalid    => $env_invalid
     };
 
-    { # Logger checks
-        my $log4perl_config = C4::Context->config("log4perl_conf");
-        my @log4perl_errors;
-        if ( ! $log4perl_config ) {
-            push @log4perl_errors, 'missing_config_entry'
-        }
-        else {
-            my @lines = read_file($log4perl_config) or push @log4perl_errors, 'cannot_read_config_file';
-            for my $line ( @lines ) {
-                next unless $line =~ m|log4perl.appender.\w+.filename=(.*)|;
-                push @log4perl_errors, 'logfile_not_writable' unless -w $1;
-            }
-        }
-        eval {Koha::Logger->get};
-        push @log4perl_errors, 'cannot_init_module' and warn $@ if $@;
-        $template->param( log4perl_errors => @log4perl_errors );
-    }
-
     $template->param(
-        time_zone              => $time_zone,
-        current_date_and_time  => output_pref({ dt => dt_from_string(), dateformat => 'iso' })
+        time_zone             => $time_zone,
+        current_date_and_time => output_pref( { dt => dt_from_string(), dateformat => 'iso' } )
     );
 
     my $perl_path = $^X;
-    if ($^O ne 'VMS') {
+    if ( $^O ne 'VMS' ) {
         $perl_path .= $Config{_exe} unless $perl_path =~ m/$Config{_exe}$/i;
     }
 
@@ -156,21 +139,22 @@ if ( $tab eq 'about' ) {
     if ( C4::Context->psgi_env ) {
         $template->param(
             is_psgi => 1,
-            psgi_server => ($ENV{ PLACK_ENV }) ? "Plack ($ENV{PLACK_ENV})" :
-                        ($ENV{ MOD_PERL })  ? "mod_perl ($ENV{MOD_PERL})" :
-                                                'Unknown'
+            psgi_server => ( $ENV{PLACK_ENV} ) ? "Plack ($ENV{PLACK_ENV})"
+            : ( $ENV{MOD_PERL} ) ? "mod_perl ($ENV{MOD_PERL})"
+            :                      'Unknown'
         );
     }
 
     # Memcached configuration
-    my $memcached_servers   = $ENV{MEMCACHED_SERVERS} || C4::Context->config('memcached_servers');
+    my $memcached_servers   = $ENV{MEMCACHED_SERVERS}   || C4::Context->config('memcached_servers');
     my $memcached_namespace = $ENV{MEMCACHED_NAMESPACE} || C4::Context->config('memcached_namespace') // 'koha';
 
-    my $cache = Koha::Caches->get_instance;
-    my $effective_caching_method = ref($cache->cache);
+    my $cache                    = Koha::Caches->get_instance;
+    my $effective_caching_method = ref( $cache->cache );
+
     # Memcached may have been running when plack has been initialized but could have been stopped since
     # FIXME What are the consequences of that??
-    my $is_memcached_still_active = $cache->set_in_cache('test_for_about_page', "just a simple value");
+    my $is_memcached_still_active = $cache->set_in_cache( 'test_for_about_page', "just a simple value" );
 
     my $where_is_memcached_config = 'nowhere';
     if ( $ENV{MEMCACHED_SERVERS} and C4::Context->config('memcached_servers') ) {
@@ -185,26 +169,26 @@ if ( $tab eq 'about' ) {
     elasticsearch_check($template);
 
     $template->param(
-        effective_caching_method => $effective_caching_method,
-        memcached_servers   => $memcached_servers,
-        memcached_namespace => $memcached_namespace,
+        effective_caching_method  => $effective_caching_method,
+        memcached_servers         => $memcached_servers,
+        memcached_namespace       => $memcached_namespace,
         is_memcached_still_active => $is_memcached_still_active,
         where_is_memcached_config => $where_is_memcached_config,
-        perlPath      => $perl_path,
-        zebraVersion  => $zebraVersion,
+        perlPath                  => $perl_path,
+        zebraVersion              => $zebraVersion,
         errZebraConnection        => $errZebraConnection,
-        kohaVersion   => $versions{'kohaVersion'},
-        osVersion     => $versions{'osVersion'},
-        perlVersion   => $versions{'perlVersion'},
-        perlIncPath   => [ map { perlinc => $_ }, @INC ],
-        mysqlVersion  => $versions{'mysqlVersion'},
-        apacheVersion => $versions{'apacheVersion'},
-        memcached_running   => Koha::Caches->get_instance->memcached_cache,
+        kohaVersion               => $versions{'kohaVersion'},
+        osVersion                 => $versions{'osVersion'},
+        perlVersion               => $versions{'perlVersion'},
+        perlIncPath               => [ map { perlinc => $_ }, @INC ],
+        mysqlVersion              => $versions{'mysqlVersion'},
+        apacheVersion             => $versions{'apacheVersion'},
+        memcached_running         => Koha::Caches->get_instance->memcached_cache,
     );
 
 }
 
-if($tab eq 'sysinfo') {
+if ( $tab eq 'sysinfo' ) {
 
     # Additional system information for warnings
 
@@ -215,33 +199,31 @@ if($tab eq 'sysinfo') {
             unless ( $prefStatisticsFields eq C4::Members::Statistics->get_fields() );
     }
 
-    my $prefAutoCreateAuthorities = C4::Context->preference('AutoCreateAuthorities');
+    my $prefAutoCreateAuthorities            = C4::Context->preference('AutoCreateAuthorities');
     my $prefRequireChoosingExistingAuthority = C4::Context->preference('RequireChoosingExistingAuthority');
-    my $warnPrefRequireChoosingExistingAuthority = ( !$prefAutoCreateAuthorities && ( !$prefRequireChoosingExistingAuthority) );
+    my $warnPrefRequireChoosingExistingAuthority =
+        ( !$prefAutoCreateAuthorities && ( !$prefRequireChoosingExistingAuthority ) );
 
-    my $prefEasyAnalyticalRecords  = C4::Context->preference('EasyAnalyticalRecords');
-    my $prefUseControlNumber  = C4::Context->preference('UseControlNumber');
-    my $warnPrefEasyAnalyticalRecords  = ( $prefEasyAnalyticalRecords  && $prefUseControlNumber );
+    my $prefEasyAnalyticalRecords     = C4::Context->preference('EasyAnalyticalRecords');
+    my $prefUseControlNumber          = C4::Context->preference('UseControlNumber');
+    my $warnPrefEasyAnalyticalRecords = ( $prefEasyAnalyticalRecords && $prefUseControlNumber );
 
-    my $AnonymousPatron = C4::Context->preference('AnonymousPatron');
-    my $warnPrefAnonymousPatronOPACPrivacy = (
-        C4::Context->preference('OPACPrivacy')
-            and not $AnonymousPatron
-    );
-    my $warnPrefAnonymousPatronAnonSuggestions = (
-        C4::Context->preference('AnonSuggestions')
-            and not $AnonymousPatron
-    );
+    my $AnonymousPatron                    = C4::Context->preference('AnonymousPatron');
+    my $warnPrefAnonymousPatronOPACPrivacy = ( C4::Context->preference('OPACPrivacy') and not $AnonymousPatron );
+    my $warnPrefAnonymousPatronAnonSuggestions =
+        ( C4::Context->preference('AnonSuggestions') and not $AnonymousPatron );
 
-    my $anonymous_patron = Koha::Patrons->find( $AnonymousPatron );
-    my $warnPrefAnonymousPatronAnonSuggestions_PatronDoesNotExist = ( $AnonymousPatron && C4::Context->preference('AnonSuggestions') && not $anonymous_patron );
+    my $anonymous_patron = Koha::Patrons->find($AnonymousPatron);
+    my $warnPrefAnonymousPatronAnonSuggestions_PatronDoesNotExist =
+        ( $AnonymousPatron && C4::Context->preference('AnonSuggestions') && not $anonymous_patron );
 
-    my $warnPrefAnonymousPatronOPACPrivacy_PatronDoesNotExist = ( not $anonymous_patron and Koha::Patrons->search({ privacy => 2 })->count );
+    my $warnPrefAnonymousPatronOPACPrivacy_PatronDoesNotExist =
+        ( not $anonymous_patron and Koha::Patrons->search( { privacy => 2 } )->count );
 
-    my $warnPrefKohaAdminEmailAddress = !Koha::Email->is_valid(C4::Context->preference('KohaAdminEmailAddress'));
+    my $warnPrefKohaAdminEmailAddress = !Koha::Email->is_valid( C4::Context->preference('KohaAdminEmailAddress') );
 
-    my $c = Koha::Items->filter_by_visible_in_opac->count;
-    my @warnings = C4::Context->dbh->selectrow_array('SHOW WARNINGS');
+    my $c                       = Koha::Items->filter_by_visible_in_opac->count;
+    my @warnings                = C4::Context->dbh->selectrow_array('SHOW WARNINGS');
     my $warnPrefOpacHiddenItems = $warnings[2];
 
     my $invalid_yesno = Koha::Config::SysPrefs->search(
@@ -252,9 +234,9 @@ if($tab eq 'sysinfo') {
     );
     $template->param( invalid_yesno => $invalid_yesno );
 
-    my $warnIsRootUser   = (! $loggedinuser);
+    my $warnIsRootUser = ( !$loggedinuser );
 
-    my $warnNoActiveCurrency = (! defined Koha::Acquisition::Currencies->get_active);
+    my $warnNoActiveCurrency = ( !defined Koha::Acquisition::Currencies->get_active );
 
     my @xml_config_warnings;
 
@@ -271,58 +253,45 @@ if($tab eq 'sysinfo') {
     }
 
     my $authorityserver = C4::Context->zebraconfig('authorityserver');
-    if( (   C4::Context->config('zebra_auth_index_mode')
-        and C4::Context->config('zebra_auth_index_mode') eq 'dom' )
+    if (   ( C4::Context->config('zebra_auth_index_mode') and C4::Context->config('zebra_auth_index_mode') eq 'dom' )
         && ( $authorityserver->{config} !~ /zebra-authorities-dom.cfg/ ) )
     {
-        push @xml_config_warnings, {
-            error => 'zebra_auth_index_mode_mismatch_warn'
-        };
+        push @xml_config_warnings, { error => 'zebra_auth_index_mode_mismatch_warn' };
     }
 
-    if ( ! defined C4::Context->config('log4perl_conf') ) {
-        push @xml_config_warnings, {
-            error => 'log4perl_entry_missing'
-        }
-    }
+    log4perl_check( $template, \@xml_config_warnings );
 
-    if ( ! defined C4::Context->config('lockdir') ) {
-        push @xml_config_warnings, {
-            error => 'lockdir_entry_missing'
-        }
-    }
-    else {
+    if ( !defined C4::Context->config('lockdir') ) {
+        push @xml_config_warnings, { error => 'lockdir_entry_missing' };
+    } else {
         unless ( -w C4::Context->config('lockdir') ) {
             push @xml_config_warnings, {
                 error   => 'lockdir_not_writable',
                 lockdir => C4::Context->config('lockdir')
-            }
+            };
         }
     }
 
-    if ( ! defined C4::Context->config('upload_path') ) {
+    if ( !defined C4::Context->config('upload_path') ) {
         if ( Koha::Config::SysPrefs->find('OPACBaseURL')->value ) {
+
             # OPACBaseURL seems to be set
-            push @xml_config_warnings, {
-                error => 'uploadpath_entry_missing'
-            }
+            push @xml_config_warnings, { error => 'uploadpath_entry_missing' };
         } else {
-            push @xml_config_warnings, {
-                error => 'uploadpath_and_opacbaseurl_entry_missing'
-            }
+            push @xml_config_warnings, { error => 'uploadpath_and_opacbaseurl_entry_missing' };
         }
     }
 
-    if ( ! C4::Context->config('tmp_path') ) {
+    if ( !C4::Context->config('tmp_path') ) {
         my $temporary_directory = C4::Context::temporary_directory;
         push @xml_config_warnings, {
             error             => 'tmp_path_missing',
             effective_tmp_dir => $temporary_directory,
-        }
+        };
     }
 
     my $encryption_key = C4::Context->config('encryption_key');
-    if ( !$encryption_key || $encryption_key eq '__ENCRYPTION_KEY__') {
+    if ( !$encryption_key || $encryption_key eq '__ENCRYPTION_KEY__' ) {
         push @xml_config_warnings, { error => 'encryption_key_missing' };
     }
 
@@ -339,10 +308,9 @@ if($tab eq 'sysinfo') {
     if ( C4::Context->preference('ILLModule') ) {
         my $warnILLConfiguration = 0;
         my $ill_config_from_file = C4::Context->config("interlibrary_loans");
-        my $ill_config = Koha::ILL::Request::Config->new;
+        my $ill_config           = Koha::ILL::Request::Config->new;
 
-        my $available_ill_backends =
-        ( scalar @{ $ill_config->available_backends } > 0 );
+        my $available_ill_backends = ( scalar @{ $ill_config->available_backends } > 0 );
 
         # Check backends
         if ( !$available_ill_backends ) {
@@ -367,13 +335,14 @@ if($tab eq 'sysinfo') {
         }
 
         if ( !C4::Context->preference('ILLPartnerCode') ) {
+
             # partner code not defined
             $template->param( ill_partner_code_not_defined => 1 );
             $warnILLConfiguration = 1;
         }
 
-
         if ( !$ill_config_from_file->{branch} ) {
+
             # branch not defined
             $template->param( ill_branch_not_defined => 1 );
             $warnILLConfiguration = 1;
@@ -396,35 +365,37 @@ if($tab eq 'sysinfo') {
             XSLTResultsDisplay
         );
         my @warnXSLT;
-        for my $p ( @xslt_prefs ) {
-            my $xsl_filename = C4::XSLT::get_xsl_filename( $p );
+
+        for my $p (@xslt_prefs) {
+            my $xsl_filename = C4::XSLT::get_xsl_filename($p);
             next if -e $xsl_filename;
             push @warnXSLT,
-            {
+                {
                 syspref  => $p,
                 value    => C4::Context->preference("$p"),
                 filename => $xsl_filename
-            };
+                };
         }
 
         $template->param( warnXSLT => \@warnXSLT ) if @warnXSLT;
     }
 
-    elasticsearch_check( $template );
+    elasticsearch_check($template);
 
     if ( C4::Context->preference('RESTOAuth2ClientCredentials') ) {
+
         # Do we have the required deps?
-        unless ( can_load( modules => { 'Net::OAuth2::AuthorizationServer' => undef }) ) {
+        unless ( can_load( modules => { 'Net::OAuth2::AuthorizationServer' => undef } ) ) {
             $template->param( oauth2_missing_deps => 1 );
         }
     }
 
     # Sco Patron should not contain any other perms than circulate => self_checkout
-    if (  C4::Context->preference('WebBasedSelfCheck')
-        and C4::Context->preference('AutoSelfCheckAllowed')
-    ) {
-        my $userid = C4::Context->preference('AutoSelfCheckID');
-        my $all_permissions = C4::Auth::get_user_subpermissions( $userid );
+    if (    C4::Context->preference('WebBasedSelfCheck')
+        and C4::Context->preference('AutoSelfCheckAllowed') )
+    {
+        my $userid          = C4::Context->preference('AutoSelfCheckID');
+        my $all_permissions = C4::Auth::get_user_subpermissions($userid);
         my ( $has_self_checkout_perm, $has_other_permissions );
         while ( my ( $module, $permissions ) = each %$all_permissions ) {
             if ( $module eq 'self_check' ) {
@@ -440,14 +411,14 @@ if($tab eq 'sysinfo') {
             }
         }
         $template->param(
-            AutoSelfCheckPatronDoesNotHaveSelfCheckPerm => not ( $has_self_checkout_perm ),
-            AutoSelfCheckPatronHasTooManyPerm => $has_other_permissions,
+            AutoSelfCheckPatronDoesNotHaveSelfCheckPerm => not($has_self_checkout_perm),
+            AutoSelfCheckPatronHasTooManyPerm           => $has_other_permissions,
         );
     }
 
     if ( C4::Context->preference('PatronSelfRegistration') ) {
         $template->param( warnPrefPatronSelfRegistrationDefaultCategory => 1 )
-            unless  Koha::Patron::Categories->find(C4::Context->preference('PatronSelfRegistrationDefaultCategory'));
+            unless Koha::Patron::Categories->find( C4::Context->preference('PatronSelfRegistrationDefaultCategory') );
     }
 
     # Test YAML system preferences
@@ -466,8 +437,8 @@ if($tab eq 'sysinfo') {
     );
     my @bad_yaml_prefs;
     foreach my $syspref (@yaml_prefs) {
-        my $yaml = C4::Context->preference( $syspref );
-        if ( $yaml ) {
+        my $yaml = C4::Context->preference($syspref);
+        if ($yaml) {
             eval { YAML::XS::Load( Encode::encode_utf8("$yaml\n\n") ); };
             if ($@) {
                 push @bad_yaml_prefs, $syspref;
@@ -477,7 +448,7 @@ if($tab eq 'sysinfo') {
     $template->param( 'bad_yaml_prefs' => \@bad_yaml_prefs ) if @bad_yaml_prefs;
 
     {
-        my $dbh       = C4::Context->dbh;
+        my $dbh     = C4::Context->dbh;
         my $patrons = $dbh->selectall_arrayref(
             q|select b.borrowernumber from borrowers b join deletedborrowers db on b.borrowernumber=db.borrowernumber|,
             { Slice => {} }
@@ -518,7 +489,8 @@ if($tab eq 'sysinfo') {
     # Circ rule warnings
     {
         my $dbh   = C4::Context->dbh;
-        my $units = Koha::CirculationRules->search({ rule_name => 'lengthunit', rule_value => { -not_in => ['days', 'hours'] } });
+        my $units = Koha::CirculationRules->search(
+            { rule_name => 'lengthunit', rule_value => { -not_in => [ 'days', 'hours' ] } } );
 
         if ( $units->count ) {
             $template->param(
@@ -530,27 +502,31 @@ if($tab eq 'sysinfo') {
 
     # Guarantor relationships warnings
     {
-        my $dbh   = C4::Context->dbh;
-        my ($bad_relationships_count) = $dbh->selectall_arrayref(q{
+        my $dbh = C4::Context->dbh;
+        my ($bad_relationships_count) = $dbh->selectall_arrayref(
+            q{
             SELECT COUNT(*)
             FROM (
                 SELECT relationship FROM borrower_relationships WHERE relationship='_bad_data'
                 UNION ALL
                 SELECT relationship FROM borrowers WHERE relationship='_bad_data') a
-        });
+        }
+        );
 
         $bad_relationships_count = $bad_relationships_count->[0]->[0];
 
-        my $existing_relationships = $dbh->selectall_arrayref(q{
+        my $existing_relationships = $dbh->selectall_arrayref(
+            q{
             SELECT DISTINCT(relationship)
             FROM (
                 SELECT relationship FROM borrower_relationships WHERE relationship IS NOT NULL
                 UNION ALL
                 SELECT relationship FROM borrowers WHERE relationship IS NOT NULL) a
-        });
+        }
+        );
 
         my %valid_relationships = map { $_ => 1 } split( /,|\|/, C4::Context->preference('borrowerRelationship') );
-        $valid_relationships{ _bad_data } = 1; # we handle this case in another way
+        $valid_relationships{_bad_data} = 1;    # we handle this case in another way
 
         my $wrong_relationships = [ grep { !$valid_relationships{ $_->[0] } } @{$existing_relationships} ];
         if ( @$wrong_relationships or $bad_relationships_count ) {
@@ -559,10 +535,8 @@ if($tab eq 'sysinfo') {
                 warnRelationships => 1,
             );
 
-            if ( $wrong_relationships ) {
-                $template->param(
-                    wrong_relationships => $wrong_relationships
-                );
+            if ($wrong_relationships) {
+                $template->param( wrong_relationships => $wrong_relationships );
             }
             if ($bad_relationships_count) {
                 $template->param(
@@ -575,16 +549,16 @@ if($tab eq 'sysinfo') {
     {
         # Test 'bcrypt_settings' config for Pseudonymization
         $template->param( config_bcrypt_settings_no_set => 1 )
-        if C4::Context->preference('Pseudonymization')
-        and not C4::Context->config('bcrypt_settings');
+            if C4::Context->preference('Pseudonymization')
+            and not C4::Context->config('bcrypt_settings');
     }
 
     {
         my @frameworkcodes = Koha::BiblioFrameworks->search->get_column('frameworkcode');
         my @hidden_biblionumbers;
-        push @frameworkcodes, ""; # it's not in the biblio_frameworks table!
+        push @frameworkcodes, "";    # it's not in the biblio_frameworks table!
         my $no_FA_framework = 1;
-        for my $frameworkcode ( @frameworkcodes ) {
+        for my $frameworkcode (@frameworkcodes) {
             $no_FA_framework = 0 if $frameworkcode eq 'FA';
             my $shouldhidemarc_opac = Koha::Filter::MARC::ViewPolicy->should_hide_marc(
                 {
@@ -593,7 +567,7 @@ if($tab eq 'sysinfo') {
                 }
             );
             push @hidden_biblionumbers, { frameworkcode => $frameworkcode, interface => 'opac' }
-            if $shouldhidemarc_opac->{biblionumber};
+                if $shouldhidemarc_opac->{biblionumber};
 
             my $shouldhidemarc_intranet = Koha::Filter::MARC::ViewPolicy->should_hide_marc(
                 {
@@ -602,10 +576,10 @@ if($tab eq 'sysinfo') {
                 }
             );
             push @hidden_biblionumbers, { frameworkcode => $frameworkcode, interface => 'intranet' }
-            if $shouldhidemarc_intranet->{biblionumber};
+                if $shouldhidemarc_intranet->{biblionumber};
         }
         $template->param( warnHiddenBiblionumbers => \@hidden_biblionumbers );
-        $template->param( warnFastCataloging => $no_FA_framework );
+        $template->param( warnFastCataloging      => $no_FA_framework );
     }
 
     job_notification_method_check($template);
@@ -629,21 +603,22 @@ if($tab eq 'sysinfo') {
     }
 
     $template->param(
-        prefRequireChoosingExistingAuthority => $prefRequireChoosingExistingAuthority,
-        prefAutoCreateAuthorities => $prefAutoCreateAuthorities,
-        warnPrefRequireChoosingExistingAuthority => $warnPrefRequireChoosingExistingAuthority,
-        warnPrefEasyAnalyticalRecords  => $warnPrefEasyAnalyticalRecords,
-        warnPrefAnonymousPatronOPACPrivacy        => $warnPrefAnonymousPatronOPACPrivacy,
-        warnPrefAnonymousPatronAnonSuggestions    => $warnPrefAnonymousPatronAnonSuggestions,
-        warnPrefAnonymousPatronOPACPrivacy_PatronDoesNotExist     => $warnPrefAnonymousPatronOPACPrivacy_PatronDoesNotExist,
-        warnPrefAnonymousPatronAnonSuggestions_PatronDoesNotExist => $warnPrefAnonymousPatronAnonSuggestions_PatronDoesNotExist,
+        prefRequireChoosingExistingAuthority                  => $prefRequireChoosingExistingAuthority,
+        prefAutoCreateAuthorities                             => $prefAutoCreateAuthorities,
+        warnPrefRequireChoosingExistingAuthority              => $warnPrefRequireChoosingExistingAuthority,
+        warnPrefEasyAnalyticalRecords                         => $warnPrefEasyAnalyticalRecords,
+        warnPrefAnonymousPatronOPACPrivacy                    => $warnPrefAnonymousPatronOPACPrivacy,
+        warnPrefAnonymousPatronAnonSuggestions                => $warnPrefAnonymousPatronAnonSuggestions,
+        warnPrefAnonymousPatronOPACPrivacy_PatronDoesNotExist => $warnPrefAnonymousPatronOPACPrivacy_PatronDoesNotExist,
+        warnPrefAnonymousPatronAnonSuggestions_PatronDoesNotExist =>
+            $warnPrefAnonymousPatronAnonSuggestions_PatronDoesNotExist,
         warnPrefKohaAdminEmailAddress => $warnPrefKohaAdminEmailAddress,
-        warnPrefOpacHiddenItems => $warnPrefOpacHiddenItems,
-        warnIsRootUser => $warnIsRootUser,
-        warnNoActiveCurrency => $warnNoActiveCurrency,
-        warnNoTemplateCaching => ( C4::Context->config('template_cache_dir') ? 0 : 1 ),
-        xml_config_warnings => \@xml_config_warnings,
-        warnStatisticsFieldsError => $warnStatisticsFieldsError,
+        warnPrefOpacHiddenItems       => $warnPrefOpacHiddenItems,
+        warnIsRootUser                => $warnIsRootUser,
+        warnNoActiveCurrency          => $warnNoActiveCurrency,
+        warnNoTemplateCaching         => ( C4::Context->config('template_cache_dir') ? 0 : 1 ),
+        xml_config_warnings           => \@xml_config_warnings,
+        warnStatisticsFieldsError     => $warnStatisticsFieldsError,
     );
 }
 
@@ -656,19 +631,19 @@ if ( $tab eq 'perl' ) {
 
     my @pm_types = qw(missing_pm upgrade_pm current_pm);
 
-    foreach my $pm_type(@pm_types) {
+    foreach my $pm_type (@pm_types) {
         my $modules = $perl_modules->get_attr($pm_type);
         foreach (@$modules) {
-            my ($module, $stats) = each %$_;
+            my ( $module, $stats ) = each %$_;
             push(
                 @components,
                 {
-                    name    => $module,
-                    version => $stats->{'cur_ver'},
-                    missing => ($pm_type eq 'missing_pm' ? 1 : 0),
-                    upgrade => ($pm_type eq 'upgrade_pm' ? 1 : 0),
-                    current => ($pm_type eq 'current_pm' ? 1 : 0),
-                    require => $stats->{'required'},
+                    name       => $module,
+                    version    => $stats->{'cur_ver'},
+                    missing    => ( $pm_type eq 'missing_pm' ? 1 : 0 ),
+                    upgrade    => ( $pm_type eq 'upgrade_pm' ? 1 : 0 ),
+                    current    => ( $pm_type eq 'current_pm' ? 1 : 0 ),
+                    require    => $stats->{'required'},
                     reqversion => $stats->{'min_ver'},
                     maxversion => $stats->{'max_ver'},
                     excversion => $stats->{'exc_ver'}
@@ -677,24 +652,27 @@ if ( $tab eq 'perl' ) {
         }
     }
 
-    @components = sort {$a->{'name'} cmp $b->{'name'}} @components;
+    @components = sort { $a->{'name'} cmp $b->{'name'} } @components;
 
-    my $counter=0;
-    my $row = [];
-    my $table = [];
+    my $counter = 0;
+    my $row     = [];
+    my $table   = [];
     foreach (@components) {
-        push (@$row, $_);
-        unless (++$counter % 4) {
-            push (@$table, {row => $row});
+        push( @$row, $_ );
+        unless ( ++$counter % 4 ) {
+            push( @$table, { row => $row } );
             $row = [];
         }
     }
+
     # Processing the last line (if there are any modules left)
-    if (scalar(@$row) > 0) {
+    if ( scalar(@$row) > 0 ) {
+
         # Extending $row to the table size
         $$row[3] = '';
+
         # Pushing the last line
-        push (@$table, {row => $row});
+        push( @$table, { row => $row } );
     }
     ## ## $table
 
@@ -709,30 +687,30 @@ if ( $tab eq 'team' ) {
 
     ## Release teams
     my $teams =
-    -e "$docdir" . "/teams.yaml"
-    ? YAML::XS::LoadFile( "$docdir" . "/teams.yaml" )
-    : {};
-    my $dev_team = (sort {$b <=> $a} (keys %{$teams->{team}}))[0];
-    my $short_version = substr($versions{'kohaVersion'},0,5);
-    my $minor = substr($versions{'kohaVersion'},3,2);
+        -e "$docdir" . "/teams.yaml"
+        ? YAML::XS::LoadFile( "$docdir" . "/teams.yaml" )
+        : {};
+    my $dev_team            = ( sort { $b <=> $a } ( keys %{ $teams->{team} } ) )[0];
+    my $short_version       = substr( $versions{'kohaVersion'}, 0, 5 );
+    my $minor               = substr( $versions{'kohaVersion'}, 3, 2 );
     my $development_version = ( $minor eq '05' || $minor eq '11' ) ? 0 : 1;
     my $codename;
-    $template->param( short_version => $short_version );
+    $template->param( short_version       => $short_version );
     $template->param( development_version => $development_version );
 
     ## Contributors
     my $contributors =
-    -e "$docdir" . "/contributors.yaml"
-    ? YAML::XS::LoadFile( "$docdir" . "/contributors.yaml" )
-    : {};
+        -e "$docdir" . "/contributors.yaml"
+        ? YAML::XS::LoadFile( "$docdir" . "/contributors.yaml" )
+        : {};
     delete $contributors->{_others_};
-    for my $version ( sort { $a <=> $b } keys %{$teams->{team}} ) {
+    for my $version ( sort { $a <=> $b } keys %{ $teams->{team} } ) {
         for my $role ( keys %{ $teams->{team}->{$version} } ) {
-            my $detail = $teams->{team}->{$version}->{$role};
+            my $detail          = $teams->{team}->{$version}->{$role};
             my $normalized_role = "$role";
             $normalized_role =~ s/s$//;
-            if ( ref( $detail ) eq 'ARRAY' ) {
-                for my $contributor ( @{ $detail } ) {
+            if ( ref($detail) eq 'ARRAY' ) {
+                for my $contributor ( @{$detail} ) {
 
                     my $localized_role = $normalized_role;
                     if ( my $subversion = $contributor->{version} ) {
@@ -743,25 +721,25 @@ if ( $tab eq 'team' ) {
                     }
 
                     my $name = $contributor->{name};
+
                     # Add role to contributors
                     push @{ $contributors->{$name}->{roles}->{$localized_role} },
-                    $version;
+                        $version;
+
                     # Add openhub to teams
                     if ( exists( $contributors->{$name}->{openhub} ) ) {
                         $contributor->{openhub} = $contributors->{$name}->{openhub};
                     }
                 }
-            }
-            elsif ( $role eq 'release_date' ) {
-                $teams->{team}->{$version}->{$role} = DateTime->from_epoch( epoch => $teams->{team}->{$version}->{$role} );
-            }
-            elsif ( $role eq 'codename' ) {
+            } elsif ( $role eq 'release_date' ) {
+                $teams->{team}->{$version}->{$role} =
+                    DateTime->from_epoch( epoch => $teams->{team}->{$version}->{$role} );
+            } elsif ( $role eq 'codename' ) {
                 if ( $version == $short_version ) {
                     $codename = $detail;
                 }
                 next;
-            }
-            else {
+            } else {
                 if ( my $subversion = $detail->{version} ) {
                     $normalized_role .= ':' . $subversion;
                 }
@@ -770,36 +748,36 @@ if ( $tab eq 'team' ) {
                 }
 
                 my $name = $detail->{name};
+
                 # Add role to contributors
                 push @{ $contributors->{$name}->{roles}->{$normalized_role} },
-                $version;
+                    $version;
+
                 # Add openhub to teams
                 if ( exists( $contributors->{$name}->{openhub} ) ) {
                     $detail->{openhub} =
-                    $contributors->{$name}->{openhub};
+                        $contributors->{$name}->{openhub};
                 }
             }
         }
     }
 
     ## Create last name ordered array of people from contributors
-    my @people = map {
-        { name => $_, ( $contributors->{$_} ? %{ $contributors->{$_} } : () ) }
-    } sort {
-    my ($alast) = $a =~ /(\S+)$/;
-    my ($blast) = $b =~ /(\S+)$/;
-    my $cmp = lc($alast||"") cmp lc($blast||"");
-    return $cmp if $cmp;
+    my @people = map { { name => $_, ( $contributors->{$_} ? %{ $contributors->{$_} } : () ) } } sort {
+        my ($alast) = $a =~ /(\S+)$/;
+        my ($blast) = $b =~ /(\S+)$/;
+        my $cmp     = lc( $alast || "" ) cmp lc( $blast || "" );
+        return $cmp if $cmp;
 
-    my ($a2last) = $a =~ /(\S+)\s\S+$/;
-    my ($b2last) = $b =~ /(\S+)\s\S+$/;
-    lc($a2last||"") cmp lc($b2last||"");
+        my ($a2last) = $a =~ /(\S+)\s\S+$/;
+        my ($b2last) = $b =~ /(\S+)\s\S+$/;
+        lc( $a2last || "" ) cmp lc( $b2last || "" );
     } keys %$contributors;
 
-    $template->param( kohaCodename  => $codename);
-    $template->param( contributors => \@people );
+    $template->param( kohaCodename     => $codename );
+    $template->param( contributors     => \@people );
     $template->param( maintenance_team => $teams->{team}->{$dev_team} );
-    $template->param( release_team => $teams->{team}->{$short_version} );
+    $template->param( release_team     => $teams->{team}->{$short_version} );
 
 }
 if ( $tab eq 'history' ) {
@@ -815,12 +793,12 @@ if ( $tab eq 'history' ) {
         my @lines = <$file>;
         close($file);
 
-        shift @lines; #remove header row
+        shift @lines;    #remove header row
 
         foreach (@lines) {
             my ( $epoch, $date, $desc, $tag ) = split(/\t/);
-            if(!$desc && $date=~ /(?<=\d{4})\s+/) {
-                ($date, $desc)= ($`, $');
+            if ( !$desc && $date =~ /(?<=\d{4})\s+/ ) {
+                ( $date, $desc ) = ( $`, $' );
             }
             push(
                 @rows2,
@@ -832,9 +810,10 @@ if ( $tab eq 'history' ) {
         }
 
         my $table2 = [];
+
         #foreach my $row2 (@rows2) {
-        foreach  (@rows2) {
-            push (@$row2, $_);
+        foreach (@rows2) {
+            push( @$row2,   $_ );
             push( @$table2, { row2 => $row2 } );
             $row2 = [];
         }
@@ -845,6 +824,36 @@ if ( $tab eq 'history' ) {
     }
 }
 
+sub log4perl_check {
+    my ( $template, $xml_config_warnings ) = @_;
+
+    if ( !defined C4::Context->config('log4perl_conf') ) {
+        push @$xml_config_warnings, { error => 'log4perl_entry_missing' };
+    }
+
+    my $log4perl_config = C4::Context->config("log4perl_conf");
+    my @log4perl_errors;
+    if ( !$log4perl_config ) {
+        push @log4perl_errors, 'missing_config_entry';
+    } else {
+        my @lines = read_file($log4perl_config) or push @log4perl_errors, 'cannot_read_config_file';
+        for my $line (@lines) {
+            next unless $line =~ m|log4perl\.appender\.\w+\.filename=(.*)|;
+            my $file = $1;
+            if ( $file =~ /sip\.log$/ ) {
+                push @log4perl_errors, 'sip_log_still_found';
+            } elsif ( !-w $file ) {
+                push @log4perl_errors, 'logfile_not_writable';
+
+                #NOTE: An unwritable logfile blocks plack.psgi. So you won't reach this script. (BZ 39155)
+            }
+        }
+    }
+    eval { Koha::Logger->get };
+    push @log4perl_errors, 'cannot_init_module' and warn $@ if $@;
+    $template->param( log4perl_errors => @log4perl_errors );
+}
+
 sub elasticsearch_check {
     my $template = shift;
 
@@ -930,16 +939,16 @@ sub job_notification_method_check {
 
         # BackgroundJob - test connection to message broker
         my $conn = Koha::BackgroundJob->connect;
-        if (! $conn) {
+        if ( !$conn ) {
             $template->param( warnConnectBroker => 1 );
         }
     }
-  }
+}
 
 if ( $tab eq 'database' ) {
     use Koha::Database::Auditor;
     my $db_auditor = Koha::Database::Auditor->new();
-    my $db_audit = $db_auditor->run;
+    my $db_audit   = $db_auditor->run;
     $template->param( db_audit => $db_audit );
 }
 output_html_with_http_headers $query, $cookie, $template->output;
