@@ -32,35 +32,36 @@ the OR operator will be applied.
 
 use Modern::Perl;
 
-use CGI qw ( -utf8 );
-use C4::Auth qw( get_template_and_user );
-use C4::Output qw( output_html_with_http_headers );
+use CGI           qw ( -utf8 );
+use C4::Auth      qw( get_template_and_user );
+use C4::Output    qw( output_html_with_http_headers );
 use C4::OAI::Sets qw( GetOAISet GetOAISetMappings ModOAISetMappings );
 
-
 my $input = CGI->new;
-my ($template, $loggedinuser, $cookie, $flags) = get_template_and_user( {
-    template_name   => 'admin/oai_set_mappings.tt',
-    query           => $input,
-    type            => 'intranet',
-    flagsrequired   => { 'parameters' => 'manage_oai_sets' },
-} );
+my ( $template, $loggedinuser, $cookie, $flags ) = get_template_and_user(
+    {
+        template_name => 'admin/oai_set_mappings.tt',
+        query         => $input,
+        type          => 'intranet',
+        flagsrequired => { 'parameters' => 'manage_oai_sets' },
+    }
+);
 
 my $id = $input->param('id');
 my $op = $input->param('op');
 
-if($op && $op eq "cud-save") {
-    my @marcfields = $input->multi_param('marcfield');
+if ( $op && $op eq "cud-save" ) {
+    my @marcfields    = $input->multi_param('marcfield');
     my @marcsubfields = $input->multi_param('marcsubfield');
-    my @operators = $input->multi_param('operator');
-    my @marcvalues = $input->multi_param('marcvalue');
+    my @operators     = $input->multi_param('operator');
+    my @marcvalues    = $input->multi_param('marcvalue');
     my @ruleoperators = $input->multi_param('rule_operator');
-    my @ruleorders = $input->multi_param('rule_order');
+    my @ruleorders    = $input->multi_param('rule_order');
 
     my @mappings;
     my $i = 0;
-    while($i < @marcfields and $i < @marcsubfields and $i < @marcvalues) {
-        if($marcfields[$i] ne '' and $marcsubfields[$i] ne '' ) {
+    while ( $i < @marcfields and $i < @marcsubfields and $i < @marcvalues ) {
+        if ( $marcfields[$i] ne '' and $marcsubfields[$i] ne '' ) {
             push @mappings, {
                 marcfield     => $marcfields[$i],
                 marcsubfield  => $marcsubfields[$i],
@@ -73,17 +74,17 @@ if($op && $op eq "cud-save") {
         $i++;
     }
     $mappings[0]{'rule_operator'} = undef if (@mappings);
-    ModOAISetMappings($id, \@mappings);
-    $template->param(mappings_saved => 1);
+    ModOAISetMappings( $id, \@mappings );
+    $template->param( mappings_saved => 1 );
 }
 
-my $set = GetOAISet($id);
+my $set      = GetOAISet($id);
 my $mappings = GetOAISetMappings($id);
 
 $template->param(
-    id => $id,
-    setName => $set->{'name'},
-    setSpec => $set->{'spec'},
+    id       => $id,
+    setName  => $set->{'name'},
+    setSpec  => $set->{'spec'},
     mappings => $mappings,
 );
 
