@@ -19,10 +19,10 @@
 
 use Modern::Perl;
 
-use CGI qw ( -utf8 );
+use CGI    qw ( -utf8 );
 use Encode qw( encode );
 
-use C4::Auth qw( get_template_and_user );
+use C4::Auth   qw( get_template_and_user );
 use C4::Output qw( output_html_with_http_headers );
 use C4::Record;
 use C4::Ris qw( marc2ris );
@@ -33,32 +33,32 @@ use Koha::Biblios;
 use utf8;
 my $query = CGI->new;
 
-my ( $template, $borrowernumber, $cookie ) = get_template_and_user (
+my ( $template, $borrowernumber, $cookie ) = get_template_and_user(
     {
-        template_name   => "basket/downloadcart.tt",
-        query           => $query,
-        type            => "intranet",
-        flagsrequired   => { catalogue => 1 },
+        template_name => "basket/downloadcart.tt",
+        query         => $query,
+        type          => "intranet",
+        flagsrequired => { catalogue => 1 },
     }
 );
 
 my $bib_list = $query->param('bib_list');
-my $format  = $query->param('format');
-my $dbh     = C4::Context->dbh;
+my $format   = $query->param('format');
+my $dbh      = C4::Context->dbh;
 
-if ($bib_list && $format) {
+if ( $bib_list && $format ) {
 
     my @bibs = split( /\//, $bib_list );
 
-    my $marcflavour         = C4::Context->preference('marcflavour');
+    my $marcflavour = C4::Context->preference('marcflavour');
     my $output;
 
-    # CSV   
-    if ($format =~ /^\d+$/) {
+    # CSV
+    if ( $format =~ /^\d+$/ ) {
 
-        $output = marc2csv(\@bibs, $format);
-    
-    # Other formats
+        $output = marc2csv( \@bibs, $format );
+
+        # Other formats
     } else {
 
         foreach my $biblionumber (@bibs) {
@@ -67,31 +67,31 @@ if ($bib_list && $format) {
             my $record = $biblio->metadata_record( { embed_items => 1 } );
             next unless $record;
 
-            if ($format eq 'iso2709') {
+            if ( $format eq 'iso2709' ) {
+
                 #NOTE: If we don't explicitly UTF-8 encode the output,
                 #the browser will guess the encoding, and it won't always choose UTF-8.
-                $output .= encode("UTF-8", $record->as_usmarc()) // q{};
-            }
-            elsif ($format eq 'ris') {
+                $output .= encode( "UTF-8", $record->as_usmarc() ) // q{};
+            } elsif ( $format eq 'ris' ) {
                 $output .= marc2ris($record);
-            }
-            elsif ($format eq 'bibtex') {
-                $output .= marc2bibtex($record, $biblionumber);
+            } elsif ( $format eq 'bibtex' ) {
+                $output .= marc2bibtex( $record, $biblionumber );
             }
         }
     }
 
     # If it was a CSV export we change the format after the export so the file extension is fine
-    $format = "csv" if ($format =~ m/^\d+$/);
+    $format = "csv" if ( $format =~ m/^\d+$/ );
 
     print $query->header(
-	-type => 'application/octet-stream',
-	-'Content-Transfer-Encoding' => 'binary',
-	-attachment=>"cart.$format");
+        -type                        => 'application/octet-stream',
+        -'Content-Transfer-Encoding' => 'binary',
+        -attachment                  => "cart.$format"
+    );
     print $output;
 
-} else { 
-    $template->param(csv_profiles => Koha::CsvProfiles->search({ type => 'marc', used_for => 'export_records' }));
-    $template->param(bib_list => $bib_list); 
+} else {
+    $template->param( csv_profiles => Koha::CsvProfiles->search( { type => 'marc', used_for => 'export_records' } ) );
+    $template->param( bib_list     => $bib_list );
     output_html_with_http_headers $query, $cookie, $template->output;
 }
