@@ -50,6 +50,7 @@ use MARC::File::XML;
 use MIME::Base64 qw( decode_base64url encode_base64url );
 use Storable     qw( freeze thaw );
 use URI::Escape  qw( uri_escape_utf8 );
+use Try::Tiny    qw( catch try );
 
 our $dbh = C4::Context->dbh;
 
@@ -529,7 +530,8 @@ if ( $op eq "cud-additem" ) {
     my $item = Koha::Items->find($itemnumber);
     my $deleted;
     if ($item) {
-        $deleted = $item->safe_delete;
+        my $delete_serial_issues = $input->param('delete-serial-issues');
+        $deleted = $item->safe_delete( { delete_serial_issues => $delete_serial_issues } );
     } else {
         $deleted = Koha::Result::Boolean->new(0)->add_message( { message => 'item_not_found' } );
     }
@@ -641,7 +643,23 @@ if ( $op eq "cud-additem" ) {
         if ( $newitemlost && $newitemlost ge '1' && !$olditemlost ) {
             LostItem( $item->itemnumber, 'additem' );
         }
-        $item->store;
+        try {
+            $item->store;
+        } catch {
+            push @errors, $_->error;
+        }
+    }
+
+    if ( $input->param('edit-serial-issue') ) {
+        my $serialid = $item->serial_item->serialid;
+        my $serial   = Koha::Serials->find($serialid);
+
+        my $redirect = "/cgi-bin/koha/serials/serials-edit.pl?serialid=$serialid";
+        if ($serial) {
+            $redirect .= "&subscriptionid=" . $serial->subscriptionid;
+        }
+        print $input->redirect($redirect);
+        exit;
     }
 
     $nextop = "cud-additem";
