@@ -21,39 +21,38 @@
 
 use Modern::Perl;
 
-use CGI qw ( -utf8 );
-use C4::Auth qw( get_template_and_user );
+use CGI        qw ( -utf8 );
+use C4::Auth   qw( get_template_and_user );
 use C4::Output qw( output_html_with_http_headers );
 use C4::Biblio qw( ModBiblio PrepHostMarcField );
 use C4::Context;
 use Koha::Biblios;
 
-
 my $query = CGI->new;
 
-my ($template, $loggedinuser, $cookie) = get_template_and_user(
+my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
     {
-        template_name   => "cataloguing/linkitem.tt",
-        query           => $query,
-        type            => "intranet",
-        flagsrequired   => { editcatalogue => 'edit_catalogue' },
+        template_name => "cataloguing/linkitem.tt",
+        query         => $query,
+        type          => "intranet",
+        flagsrequired => { editcatalogue => 'edit_catalogue' },
     }
 );
 
 my $biblionumber = $query->param('biblionumber');
 my $barcode      = $query->param('barcode');
 my $op           = $query->param('op') || q{};
-my $biblio = Koha::Biblios->find($biblionumber);
-my $record = $biblio->metadata->record;
-my $marcflavour = C4::Context->preference("marcflavour");
-$marcflavour ||="MARC21";
-if ($marcflavour eq 'MARC21') {
-    $template->param(bibliotitle => $record->subfield('245','a'));
-} elsif ($marcflavour eq 'UNIMARC') {
-    $template->param(bibliotitle => $record->subfield('200','a'));
+my $biblio       = Koha::Biblios->find($biblionumber);
+my $record       = $biblio->metadata->record;
+my $marcflavour  = C4::Context->preference("marcflavour");
+$marcflavour ||= "MARC21";
+if ( $marcflavour eq 'MARC21' ) {
+    $template->param( bibliotitle => $record->subfield( '245', 'a' ) );
+} elsif ( $marcflavour eq 'UNIMARC' ) {
+    $template->param( bibliotitle => $record->subfield( '200', 'a' ) );
 }
 
-$template->param(biblionumber => $biblionumber);
+$template->param( biblionumber => $biblionumber );
 
 if ( $op eq 'cud-linkitem' && $barcode && $biblionumber ) {
 
@@ -66,8 +65,7 @@ if ( $op eq 'cud-linkitem' && $barcode && $biblionumber ) {
         my $modresult = ModBiblio( $record, $biblionumber, '' );
         if ($modresult) {
             $template->param( success => 1 );
-        }
-        else {
+        } else {
             $template->param(
                 error            => 1,
                 errornomodbiblio => 1
@@ -76,8 +74,7 @@ if ( $op eq 'cud-linkitem' && $barcode && $biblionumber ) {
         $template->param(
             hostitemnumber => $item->itemnumber,
         );
-    }
-    else {
+    } else {
         $template->param(
             error                 => 1,
             errornohostitemnumber => 1,
@@ -85,15 +82,13 @@ if ( $op eq 'cud-linkitem' && $barcode && $biblionumber ) {
     }
 
     $template->param(
-        barcode        => $barcode,
+        barcode => $barcode,
     );
 
-}
-else {
+} else {
     $template->param( missingparameter => 1 );
     if ( !$barcode )      { $template->param( missingbarcode      => 1 ); }
     if ( !$biblionumber ) { $template->param( missingbiblionumber => 1 ); }
 }
 
-
 output_html_with_http_headers $query, $cookie, $template->output;
