@@ -39,11 +39,11 @@ use C4::Members;
 use C4::Biblio   qw( TransformMarcToKoha );
 use C4::Search   qw( new_record_from_zebra );
 use C4::Reserves qw( ModReserveAffect );
-use C4::Log      qw( logaction );
 use Koha::Holds;
 use C4::Context;
 use CGI::Session;
 use Koha::AuthorisedValues;
+use Koha::BackgroundJob::BatchUpdateBiblioHoldsQueue;
 use Koha::Checkouts::ReturnClaims;
 use Koha::CsvProfiles;
 use Koha::Patrons;
@@ -326,9 +326,6 @@ if ($patron) {
 # STEP 3 : ISSUING
 #
 #
-my $message;
-my @message;
-
 if ( @$barcodes && $op eq 'cud-checkout' ) {
     my $checkout_infos;
     for my $barcode (@$barcodes) {
@@ -379,6 +376,8 @@ if ( @$barcodes && $op eq 'cud-checkout' ) {
             my ( $stats_return, $stats_messages, $stats_iteminformation, $stats_borrower ) =
                 AddReturn( $item->barcode, C4::Context->userenv->{'branch'}, undef, undef, 1 );
 
+            # No rebuild of holds queue here as the item hasn't really moved, just a stat checkout
+
             $template->param(
                 STATS     => 1,
                 CHECKEDIN => $stats_return,
@@ -564,34 +563,6 @@ if ( @$barcodes && $op eq 'cud-checkout' ) {
                     }
                 );
                 $template_params->{issue} = $issue;
-
-                my $borrower       = $patron;
-                my $borrowernumber = $patron->borrowernumber;
-                my $user           = C4::Context->userenv->{number};
-                my $branchcode     = C4::Context->userenv->{branch};
-                $message = "Restriction overridden temporarily";
-                @message = ("Restriction overridden temporarily");
-
-                if ($issueconfirmed) {
-                    my $infos = (
-                        {
-                            message        => \@message,
-                            borrowernumber => $borrowernumber,
-                            barcode        => $barcode,
-                            manager_id     => $user,
-                            branchcode     => $branchcode,
-                        }
-                    );
-
-                    my $json_infos = JSON->new->utf8->pretty->encode($infos);
-                    $json_infos =~ s/"/'/g;
-
-                    logaction(
-                        "CIRCULATION", "ISSUE",
-                        $borrower->{'borrowernumber'},
-                        $json_infos,
-                    ) if C4::Context->preference("IssueLog");
-                }
                 $session->clear('auto_renew');
                 $inprocess = 1;
             }
@@ -739,7 +710,7 @@ if ($patron) {
             join       => 'manager',
             '+select'  => [ 'manager.surname', 'manager.firstname' ],
             '+as'      => [ 'manager_surname', 'manager_firstname' ],
-            'order_by' => { -desc => 'me.message_type' },
+            'order_by' => [ 'me.message_type', { -desc => 'me.message_date' }, { -desc => 'me.message_id' } ],
         }
     );
     $template->param( patron_messages => $patron_messages );
@@ -810,7 +781,6 @@ $template->param(
     stickyduedate             => $stickyduedate,
     duedatespec               => $duedatespec,
     restoreduedatespec        => $restoreduedatespec,
-    message                   => $message,
     totaldue                  => sprintf( '%.2f', $balance ),                         # FIXME not used in template?
     inprocess                 => $inprocess,
     $view                     => 1,
