@@ -1,6 +1,5 @@
 #!/usr/bin/perl
 
-
 # Copyright 2012 Koha
 #
 # This file is part of Koha.
@@ -21,14 +20,14 @@
 use Modern::Perl;
 
 use C4::Context;
-use C4::Output qw( output_html_with_http_headers );
-use CGI qw ( -utf8 );
-use C4::Auth qw( get_session get_template_and_user );
+use C4::Output      qw( output_html_with_http_headers );
+use CGI             qw ( -utf8 );
+use C4::Auth        qw( get_session get_template_and_user );
 use C4::Circulation qw( TransferSlip );
 
-my $input = CGI->new;
+my $input     = CGI->new;
 my $sessionID = $input->cookie("CGISESSID");
-my $session = get_session($sessionID);
+my $session   = get_session($sessionID);
 
 my $itemnumber = $input->param('transferitem');
 my $barcode    = $input->param('barcode');
@@ -36,28 +35,27 @@ my $branchcode = $input->param('branchcode');
 
 my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
     {
-        template_name   => "circ/printslip.tt",
-        query           => $input,
-        type            => "intranet",
-        flagsrequired   => { circulate => "circulate_remaining_permissions" },
+        template_name => "circ/printslip.tt",
+        query         => $input,
+        type          => "intranet",
+        flagsrequired => { circulate => "circulate_remaining_permissions" },
     }
 );
 
-
 my $userenv = C4::Context->userenv;
 my ( $slip, $is_html, $style );
-if ( my $letter = TransferSlip ($session->param('branch') || $userenv->{branch}, $itemnumber, $barcode, $branchcode) ) {
+if ( my $letter = TransferSlip( $session->param('branch') || $userenv->{branch}, $itemnumber, $barcode, $branchcode ) )
+{
     $slip    = $letter->{content};
     $is_html = $letter->{is_html};
     $style   = $letter->{style};
-}
-else {
+} else {
     $slip = "Item not found";
 }
 $template->param(
-    slip => $slip,
-    plain => !$is_html,
-    caller => 'cud-transfer',
+    slip       => $slip,
+    plain      => !$is_html,
+    caller     => 'cud-transfer',
     stylesheet => C4::Context->preference("SlipCSS"),
     style      => $style,
     id         => 'transfer_slip',
