@@ -3,26 +3,30 @@ use Modern::Perl;
 return {
     bug_number  => "28772",
     description => "Store hashed API key secrets",
-    up => sub {
+    up          => sub {
         my ($args) = @_;
-        my ($dbh) = @$args{qw(dbh)};
+        my ($dbh)  = @$args{qw(dbh)};
 
         use Koha::AuthUtils qw(hash_password);
 
-        my $sth = $dbh->prepare(q{
+        my $sth = $dbh->prepare(
+            q{
             SELECT client_id, secret
             FROM api_keys
-        });
+        }
+        );
         $sth->execute;
-        my $results = $sth->fetchall_arrayref({});
+        my $results = $sth->fetchall_arrayref( {} );
 
-        $sth = $dbh->prepare(q{
+        $sth = $dbh->prepare(
+            q{
             UPDATE api_keys
             SET
                 secret = ?
             WHERE
                 client_id = ?
-        });
+        }
+        );
 
         foreach my $api_key (@$results) {
             unless ( $api_key->{secret} =~ m/^\$2a\$08\$/ ) {
@@ -31,4 +35,4 @@ return {
             }
         }
     },
-}
+    }
