@@ -1,14 +1,16 @@
 use Modern::Perl;
 
 return {
-    bug_number => "29778",
+    bug_number  => "29778",
     description => "Delete orphan additional contents",
-    up => sub {
+    up          => sub {
         my ($args) = @_;
-        my ($dbh, $out) = @$args{qw(dbh out)};
+        my ( $dbh, $out ) = @$args{qw(dbh out)};
+
         # Run this only if 230600041 has not been run before
-        if ( column_exists('additional_contents', 'lang') ) {
-            $dbh->do(q{
+        if ( column_exists( 'additional_contents', 'lang' ) ) {
+            $dbh->do(
+                q{
                 DELETE FROM additional_contents
                 WHERE code NOT IN (
                     SELECT code FROM (
@@ -17,7 +19,8 @@ return {
                         WHERE lang = "default"
                     ) as tmp
                 );
-            });
+            }
+            );
         }
     },
-}
+    }
