@@ -1,16 +1,18 @@
 use Modern::Perl;
 
 return {
-    bug_number => "30852",
+    bug_number  => "30852",
     description => "Add index to article_requests.debit_id",
-    up => sub {
+    up          => sub {
         my ($args) = @_;
-        my ($dbh, $out) = @$args{qw(dbh out)};
+        my ( $dbh, $out ) = @$args{qw(dbh out)};
         unless ( index_exists( 'article_requests', 'debit_id' ) ) {
-            $dbh->do(q{
+            $dbh->do(
+                q{
                 ALTER TABLE `article_requests`
                 ADD KEY `debit_id` (`debit_id`)
-            });
+            }
+            );
         }
     },
 };
