@@ -20,8 +20,8 @@
 use Modern::Perl;
 use C4::Context;
 use C4::InstallAuth qw( checkauth get_template_and_user );
-use CGI qw ( -utf8 );
-use C4::Output qw( output_html_with_http_headers );
+use CGI             qw ( -utf8 );
+use C4::Output      qw( output_html_with_http_headers );
 use Koha::Patrons;
 use Koha::Libraries;
 use Koha::Database;
@@ -39,11 +39,10 @@ unless ( C4::Context->preference('Version') ) {
     exit;
 }
 
-my ( $user, $cookie, $sessionID, $flags ) =
-  C4::InstallAuth::checkauth( $input, 0, undef, 'intranet' );
+my ( $user, $cookie, $sessionID, $flags ) = C4::InstallAuth::checkauth( $input, 0, undef, 'intranet' );
 die "Not logged in"
-  unless $user
-  ; # Should not happen, we should be redirect if the user is not logged in. But do not trust authentication...
+    unless
+    $user;   # Should not happen, we should be redirect if the user is not logged in. But do not trust authentication...
 
 my $step = $input->param('step') || 1;
 my $op   = $input->param('op')   || '';
@@ -62,8 +61,7 @@ if ( $step == 1 ) {
         my $branchcode = $input->param('branchcode');
         $branchcode = uc($branchcode);
 
-        $branchcode =~ s|\s||g
-          ; # Use a regular expression to check the value of the inputted branchcode
+        $branchcode =~ s|\s||g;    # Use a regular expression to check the value of the inputted branchcode
 
         my $library = Koha::Library->new(
             {
@@ -75,8 +73,7 @@ if ( $step == 1 ) {
         eval { $library->store; };
         unless ($@) {
             push @messages, { code => 'success_on_insert_library' };
-        }
-        else {
+        } else {
             push @messages, { code => 'error_on_insert_library' };
         }
     }
@@ -86,7 +83,7 @@ if ( $step == 1 ) {
 if ( $step == 2 ) {
     if ( $op eq "cud-add_validate_category" ) {
 
-        my $searchfield = $input->param('description') // q||;
+        my $searchfield  = $input->param('description') // q||;
         my $categorycode = $input->param('categorycode');
         my $category;
         $template_params->{categorycode} = $categorycode;
@@ -97,7 +94,7 @@ if ( $step == 2 ) {
         my $category_type         = $input->param('category_type');
         my $default_privacy       = $input->param('default_privacy');
         my $enrolmentperiod       = $input->param('enrolmentperiod');
-        my $enrolmentperioddate = $input->param('enrolmentperioddate') || undef;
+        my $enrolmentperioddate   = $input->param('enrolmentperioddate') || undef;
 
         #Adds a new patron category to the database
         $category = Koha::Patron::Category->new(
@@ -116,8 +113,7 @@ if ( $step == 2 ) {
 
         unless ($@) {
             push @messages, { code => 'success_on_insert_category' };
-        }
-        else {
+        } else {
             push @messages, { code => 'error_on_insert_category' };
         }
     }
@@ -128,42 +124,37 @@ if ( $step == 3 ) {
     if ( $op eq 'cud-add_validate_patron' ) {
 
         #Create a patron
-        my $firstpassword  = $input->param('password')  || '';
-        my $secondpassword = $input->param('password2') || '';
-        my $cardnumber     = $input->param('cardnumber');
-        my $userid         = $input->param('userid');
-        my $categorycode = $input->param('categorycode_entry');
-        my $patron_category =
-          Koha::Patron::Categories->find( $categorycode );
-
-        my ( $is_valid, $passworderror ) =
-          Koha::AuthUtils::is_password_valid( $firstpassword,
-            $patron_category );
+        my $firstpassword   = $input->param('password')  || '';
+        my $secondpassword  = $input->param('password2') || '';
+        my $cardnumber      = $input->param('cardnumber');
+        my $userid          = $input->param('userid');
+        my $categorycode    = $input->param('categorycode_entry');
+        my $patron_category = Koha::Patron::Categories->find($categorycode);
 
+        my ( $is_valid, $passworderror ) = Koha::AuthUtils::is_password_valid(
+            $firstpassword,
+            $patron_category
+        );
 
         my $is_cardnumber_valid = Koha::Policy::Patrons::Cardnumber->is_valid($cardnumber);
-        unless ( $is_cardnumber_valid ) {
+        unless ($is_cardnumber_valid) {
             for my $m ( @{ $is_cardnumber_valid->messages } ) {
                 my $message = $m->message;
                 if ( $message eq 'already_exists' ) {
                     push @messages, { code => 'ERROR_cardnumber_already_exists' };
-                }
-                elsif ( $message eq 'invalid_length' ) {
+                } elsif ( $message eq 'invalid_length' ) {
                     push @messages, { code => 'ERROR_cardnumber_length' };
                 }
             }
-        }
-        elsif ( $firstpassword ne $secondpassword ) {
+        } elsif ( $firstpassword ne $secondpassword ) {
 
             push @messages, { code => 'ERROR_password_mismatch' };
-        }
-        elsif ( $passworderror) {
-                push @messages, { code => 'ERROR_password_too_short'} if $passworderror eq 'too_short';
-                push @messages, { code => 'ERROR_password_too_weak'} if $passworderror eq 'too_weak';
-                push @messages, { code => 'ERROR_password_has_whitespaces'} if $passworderror eq 'has_whitespaces';
+        } elsif ($passworderror) {
+            push @messages, { code => 'ERROR_password_too_short' }       if $passworderror eq 'too_short';
+            push @messages, { code => 'ERROR_password_too_weak' }        if $passworderror eq 'too_weak';
+            push @messages, { code => 'ERROR_password_has_whitespaces' } if $passworderror eq 'has_whitespaces';
 
-        }
-        else {
+        } else {
             my $patron_data = {
                 surname      => scalar $input->param('surname'),
                 firstname    => scalar $input->param('firstname'),
@@ -174,22 +165,21 @@ if ( $step == 3 ) {
                 privacy      => "default",
                 address      => "",
                 city         => "",
-                flags        => 1,    # Will be superlibrarian
+                flags        => 1,                                    # Will be superlibrarian
             };
 
             $patron_data->{dateexpiry} =
-              $patron_category->get_expiry_date( $patron_data->{dateenrolled} );
+                $patron_category->get_expiry_date( $patron_data->{dateenrolled} );
 
             eval {
                 my $patron = Koha::Patron->new($patron_data)->store;
-                $patron->set_password({ password =>  $firstpassword });
+                $patron->set_password( { password => $firstpassword } );
             };
 
             #Error handling checking if the patron was created successfully
             unless ($@) {
                 push @messages, { code => 'success_on_insert_patron' };
-            }
-            else {
+            } else {
                 warn $@;
                 push @messages, { code => 'error_on_insert_patron' };
             }
@@ -214,8 +204,7 @@ if ( $step == 4 ) {
 
         unless ($@) {
             push @messages, { code => 'success_on_insert_itemtype' };
-        }
-        else {
+        } else {
             push @messages, { code => 'error_on_insert_itemtype' };
         }
     }
@@ -229,27 +218,27 @@ if ( $step == 5 ) {
         #If no libraries exist then set the $branch value to *
         my $branch = $input->param('branch') || '*';
 
-        my $type            = $input->param('type');
-        my $branchcode      = $input->param('branch');
-        my $categorycode    = $input->param('categorycode');
-        my $itemtype        = $input->param('itemtype');
-        my $maxissueqty     = $input->param('maxissueqty');
-        my $issuelength     = $input->param('issuelength') || 0;
-        my $lengthunit      = $input->param('lengthunit');
-        my $renewalsallowed = $input->param('renewalsallowed');
-        my $renewalperiod   = $input->param('renewalperiod');
-        my $reservesallowed = $input->param('reservesallowed');
-        my $holds_per_day   = $input->param('holds_per_day');
+        my $type             = $input->param('type');
+        my $branchcode       = $input->param('branch');
+        my $categorycode     = $input->param('categorycode');
+        my $itemtype         = $input->param('itemtype');
+        my $maxissueqty      = $input->param('maxissueqty');
+        my $issuelength      = $input->param('issuelength') || 0;
+        my $lengthunit       = $input->param('lengthunit');
+        my $renewalsallowed  = $input->param('renewalsallowed');
+        my $renewalperiod    = $input->param('renewalperiod');
+        my $reservesallowed  = $input->param('reservesallowed');
+        my $holds_per_day    = $input->param('holds_per_day');
         my $holds_per_record = $input->param('holds_per_record');
-        my $onshelfholds    = $input->param('onshelfholds') || 0;
+        my $onshelfholds     = $input->param('onshelfholds') || 0;
         $maxissueqty =~ s/\s//g;
         $maxissueqty = undef if $maxissueqty !~ /^\d+/;
 
         my $params = {
-            branchcode      => $branchcode,
-            categorycode    => $categorycode,
-            itemtype        => $itemtype,
-            rules => {
+            branchcode   => $branchcode,
+            categorycode => $categorycode,
+            itemtype     => $itemtype,
+            rules        => {
                 renewalsallowed                  => $renewalsallowed,
                 renewalperiod                    => $renewalperiod,
                 issuelength                      => $issuelength,
@@ -288,12 +277,10 @@ if ( $step == 5 ) {
                 recall_overdue_fine              => undef,
                 recall_shelf_time                => undef,
                 holds_pickup_period              => undef,
-              }
+            }
         };
 
-        eval {
-            Koha::CirculationRules->set_rules($params);
-        };
+        eval { Koha::CirculationRules->set_rules($params); };
 
         if ($@) {
             warn $@;
@@ -307,7 +294,7 @@ if ( $step == 5 ) {
 }
 
 my $libraries = Koha::Libraries->search( {}, { order_by => ['branchcode'] }, );
-$template_params->{libraries}   = $libraries;
+$template_params->{libraries} = $libraries;
 
 if ( $step > 5 ) {
     $template_params->{all_done} = 1;    # If step 5 is complete, we are done!
@@ -318,9 +305,9 @@ if ( $step > 5 ) {
 my ( $template, $loggedinuser );
 ( $template, $loggedinuser, $cookie ) = C4::InstallAuth::get_template_and_user(
     {
-        template_name   => "onboarding/onboardingstep${step}.tt",
-        query           => $input,
-        type            => "intranet",
+        template_name => "onboarding/onboardingstep${step}.tt",
+        query         => $input,
+        type          => "intranet",
     }
 );
 
