@@ -36,24 +36,43 @@ function LoadIssuesTable() {
     $("#issues-table").show();
     $("#issues-table-actions").show();
     var msg_loading = __("Loading... you may continue scanning.");
+    let renew_column = table_settings_issues_table.columns.find(
+        c => c.columnname == "renew"
+    );
+    let checkin_column = table_settings_issues_table.columns.find(
+        c => c.columnname == "checkin"
+    );
+
     if (!AllowCirculate) {
-        table_settings_issues_table.columns.find(
-            c => c.columnname == "renew"
-        ).is_hidden = 42;
-        table_settings_issues_table.columns.find(
-            c => c.columnname == "checkin"
-        ).is_hidden = 1;
+        renew_column.is_hidden = 1;
+        renew_column.force_visibility = 1;
+    } else {
+        renew_column.is_hidden = 0;
+        checkin_column.is_hidden = 0;
     }
+    renew_column.force_visibility = 1;
+    checkin_column.force_visibility = 1;
+
+    let claims_returned_column = table_settings_issues_table.columns.find(
+        c => c.columnname == "claims_returned"
+    );
     if (!ClaimReturnedLostValue) {
-        table_settings_issues_table.columns.find(
-            c => c.columnname == "claims_returned"
-        ).is_hidden = 1;
+        claims_returned_column.is_hidden = 1;
+    } else {
+        claims_returned_column.is_hidden = 0;
     }
+    claims_returned_column.force_visibility = 1;
+
+    let export_column = table_settings_issues_table.columns.find(
+        c => c.columnname == "export"
+    );
     if (!exports_enabled) {
-        table_settings_issues_table.columns.find(
-            c => c.columnname == "export"
-        ).is_hidden = 1;
+        export_column.is_hidden = 1;
+    } else {
+        export_column.is_hidden = 0;
     }
+    export_column.force_visibility = 1;
+
     issuesTable = $("#issues-table").kohaTable(
         {
             language: {
@@ -245,16 +264,19 @@ function LoadIssuesTable() {
                         return title;
                     },
                     type: "anti-the",
+                    orderData: [1, 4],
                 },
                 {
                     data: function (oObj) {
                         return oObj.recordtype_description.escapeHtml();
                     },
+                    orderData: [1, 5],
                 },
                 {
                     data: function (oObj) {
                         return oObj.itemtype_description.escapeHtml();
                     },
+                    orderData: [1, 6],
                 },
                 {
                     data: function (oObj) {
@@ -262,11 +284,13 @@ function LoadIssuesTable() {
                             ? oObj.collection.escapeHtml()
                             : "";
                     },
+                    orderData: [1, 7],
                 },
                 {
                     data: function (oObj) {
                         return oObj.location ? oObj.location.escapeHtml() : "";
                     },
+                    orderData: [1, 8],
                 },
                 {
                     data: function (oObj) {
@@ -274,13 +298,14 @@ function LoadIssuesTable() {
                             ? oObj.homebranch.escapeHtml()
                             : "";
                     },
+                    orderData: [1, 9],
                 },
                 {
                     data: "issuedate",
                     visible: false,
                 },
                 {
-                    orderData: 10, // Sort on hidden unformatted issuedate column
+                    orderData: [1, 10], // Sort on hidden unformatted issuedate column
                     data: function (oObj) {
                         return $datetime(oObj.issuedate, {
                             no_tz_adjust: true,
@@ -293,6 +318,7 @@ function LoadIssuesTable() {
                             ? oObj.branchname.escapeHtml()
                             : "";
                     },
+                    orderData: [1, 12],
                 },
                 {
                     data: function (oObj) {
@@ -300,6 +326,7 @@ function LoadIssuesTable() {
                             ? oObj.itemcallnumber.escapeHtml()
                             : "";
                     },
+                    orderData: [1, 13],
                 },
                 {
                     data: function (oObj) {
@@ -307,6 +334,7 @@ function LoadIssuesTable() {
                             ? oObj.copynumber.escapeHtml()
                             : "";
                     },
+                    orderData: [1, 14],
                 },
                 {
                     data: function (oObj) {
@@ -317,6 +345,7 @@ function LoadIssuesTable() {
                             "<span>"
                         );
                     },
+                    orderData: [1, 15],
                     className: "nowrap",
                 },
                 {
@@ -328,6 +357,7 @@ function LoadIssuesTable() {
                             "<span>"
                         );
                     },
+                    orderData: [1, 16],
                     className: "nowrap",
                 },
                 {
@@ -339,6 +369,7 @@ function LoadIssuesTable() {
                             "<span>"
                         );
                     },
+                    orderData: [1, 17],
                     className: "nowrap",
                 },
                 {
@@ -653,6 +684,7 @@ function LoadIssuesTable() {
                 ),
             },
             bKohaAjaxSVC: true,
+            bKohaColumnsUseNames: true,
             rowGroup: {
                 dataSrc: "issued_today",
                 startRender: function (rows, group) {
@@ -702,6 +734,16 @@ function LoadIssuesTable() {
             collision: "none",
         });
     }
+
+    // Disable rowGroup when sorting on due date
+    $("#issues-table").on("order.dt", function () {
+        var order = issuesTable.api().order();
+        if (order[0][0] === 3) {
+            issuesTable.api().rowGroup().disable();
+        } else {
+            issuesTable.api().rowGroup().enable();
+        }
+    });
 }
 
 var loadIssuesTableDelayTimeoutId;
@@ -1014,8 +1056,7 @@ $(document).ready(function () {
                         }
                         refresh_table = false;
                     }
-
-                    $(id).replaceWith(content);
+                    $(id).parent().empty().append(content);
                 },
                 error => {
                     console.warn("Something wrong happened: %s".format(error));
