@@ -1,10 +1,8 @@
 #!/usr/bin/perl
 
-
 #written 11/1/2000 by chris@katipo.oc.nz
 #script to display borrowers account details
 
-
 # Copyright 2000-2002 Katipo Communications
 #
 # This file is part of Koha.
@@ -25,9 +23,9 @@
 use Modern::Perl;
 use URI::Escape qw( uri_unescape );
 
-use C4::Auth qw( get_template_and_user );
+use C4::Auth   qw( get_template_and_user );
 use C4::Output qw( output_and_exit_if_error output_and_exit output_html_with_http_headers );
-use CGI qw ( -utf8 );
+use CGI        qw ( -utf8 );
 use C4::Members;
 use C4::Accounts;
 use C4::Letters;
@@ -37,16 +35,17 @@ use Koha::Patron::Categories;
 use Koha::Items;
 use Koha::Token;
 
-my $input=CGI->new;
+my $input = CGI->new;
 
-
-my ($template, $loggedinuser, $cookie) = get_template_and_user(
+my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
     {
-        template_name   => "members/boraccount.tt",
-        query           => $input,
-        type            => "intranet",
-        flagsrequired   => { borrowers     => 'edit_borrowers',
-                             updatecharges => 'remaining_permissions'},
+        template_name => "members/boraccount.tt",
+        query         => $input,
+        type          => "intranet",
+        flagsrequired => {
+            borrowers     => 'edit_borrowers',
+            updatecharges => 'remaining_permissions'
+        },
     }
 );
 
@@ -57,48 +56,54 @@ my $change_given   = $input->param('change_given');
 my $op             = $input->param('op') || '';
 my @renew_results  = $input->multi_param('renew_result');
 
-my $logged_in_user = Koha::Patrons->find( $loggedinuser );
-my $library_id = C4::Context->userenv->{'branch'};
-my $patron = Koha::Patrons->find( $borrowernumber );
-unless ( $patron ) {
+my $logged_in_user = Koha::Patrons->find($loggedinuser);
+my $library_id     = C4::Context->userenv->{'branch'};
+my $patron         = Koha::Patrons->find($borrowernumber);
+unless ($patron) {
     print $input->redirect("/cgi-bin/koha/circ/circulation.pl?borrowernumber=$borrowernumber");
     exit;
 }
 
-output_and_exit_if_error( $input, $cookie, $template, { module => 'members', logged_in_user => $logged_in_user, current_patron => $patron } );
+output_and_exit_if_error(
+    $input, $cookie, $template,
+    { module => 'members', logged_in_user => $logged_in_user, current_patron => $patron }
+);
 
 my $registerid = $input->param('registerid');
 
 if ( $op eq 'cud-void' ) {
-    output_and_exit_if_error($input, $cookie, $template, { check => 'csrf_token' });
+    output_and_exit_if_error( $input, $cookie, $template, { check => 'csrf_token' } );
     my $payment_id = scalar $input->param('accountlines_id');
-    my $payment    = Koha::Account::Lines->find( $payment_id );
+    my $payment    = Koha::Account::Lines->find($payment_id);
+    my $note       = scalar $input->param('void_note');
     $payment->void(
         {
             branch    => $library_id,
             staff_id  => $logged_in_user->id,
             interface => 'intranet',
+            note      => $note
         }
     );
 }
 
 if ( $op eq 'cud-payout' ) {
-    output_and_exit_if_error($input, $cookie, $template, { check => 'csrf_token' });
+    output_and_exit_if_error( $input, $cookie, $template, { check => 'csrf_token' } );
     my $payment_id  = scalar $input->param('accountlines_id');
     my $payment     = Koha::Account::Lines->find($payment_id);
     my $amount      = scalar $input->param('amount');
     my $payout_type = scalar $input->param('payout_type');
+    my $note        = scalar $input->param('payout_note');
     if ( $payment_id eq "" ) {
         $schema->txn_do(
             sub {
                 $patron->account->payout_amount(
-                     {
+                    {
                         payout_type   => $payout_type,
                         branch        => $library_id,
                         staff_id      => $logged_in_user->id,
                         cash_register => $registerid,
                         interface     => 'intranet',
-                        amount        => $amount
+                        amount        => $amount,
                     }
                 );
             }
@@ -114,7 +119,8 @@ if ( $op eq 'cud-payout' ) {
                         staff_id      => $logged_in_user->id,
                         cash_register => $registerid,
                         interface     => 'intranet',
-                        amount        => $amount
+                        amount        => $amount,
+                        note          => $note
                     }
                 );
             }
@@ -123,11 +129,13 @@ if ( $op eq 'cud-payout' ) {
 }
 
 if ( $op eq 'cud-refund' ) {
-    output_and_exit_if_error($input, $cookie, $template, { check => 'csrf_token' });
+    output_and_exit_if_error( $input, $cookie, $template, { check => 'csrf_token' } );
     my $charge_id   = scalar $input->param('accountlines_id');
     my $charge      = Koha::Account::Lines->find($charge_id);
     my $amount      = scalar $input->param('amount');
     my $refund_type = scalar $input->param('refund_type');
+    my $note        = scalar $input->param('refund_note');
+
     $schema->txn_do(
         sub {
 
@@ -137,7 +145,8 @@ if ( $op eq 'cud-refund' ) {
                     branch         => $library_id,
                     staff_id       => $logged_in_user->id,
                     interface      => 'intranet',
-                    amount         => $amount
+                    amount         => $amount,
+                    note           => $note
                 }
             );
             unless ( $refund_type eq 'AC' ) {
@@ -148,7 +157,8 @@ if ( $op eq 'cud-refund' ) {
                         staff_id      => $logged_in_user->id,
                         cash_register => $registerid,
                         interface     => 'intranet',
-                        amount        => $amount
+                        amount        => $amount,
+                        note          => $note
                     }
                 );
             }
@@ -157,10 +167,12 @@ if ( $op eq 'cud-refund' ) {
 }
 
 if ( $op eq 'cud-discount' ) {
-    output_and_exit_if_error($input, $cookie, $template, { check => 'csrf_token' });
-    my $charge_id        = scalar $input->param('accountlines_id');
-    my $charge           = Koha::Account::Lines->find($charge_id);
-    my $amount           = scalar $input->param('amount');
+    output_and_exit_if_error( $input, $cookie, $template, { check => 'csrf_token' } );
+    my $charge_id = scalar $input->param('accountlines_id');
+    my $charge    = Koha::Account::Lines->find($charge_id);
+    my $amount    = scalar $input->param('amount');
+    my $note      = scalar $input->param('apply_discount_note');
+
     $schema->txn_do(
         sub {
 
@@ -170,7 +182,8 @@ if ( $op eq 'cud-discount' ) {
                     branch         => $library_id,
                     staff_id       => $logged_in_user->id,
                     interface      => 'intranet',
-                    amount         => $amount
+                    amount         => $amount,
+                    note           => $note,
                 }
             );
         }
@@ -179,14 +192,13 @@ if ( $op eq 'cud-discount' ) {
 
 my $receipt_sent = 0;
 if ( $op eq 'cud-send_receipt' ) {
-    my $credit_id = scalar $input->param('accountlines_id');
-    my $credit    = Koha::Account::Lines->find($credit_id);
-    my @credit_offsets =
-      $credit->credit_offsets( { type => 'APPLY' } )->as_list;
+    my $credit_id      = scalar $input->param('accountlines_id');
+    my $credit         = Koha::Account::Lines->find($credit_id);
+    my @credit_offsets = $credit->credit_offsets( { type => 'APPLY' } )->as_list;
     if (
         my $letter = C4::Letters::GetPreparedLetter(
-            module      => 'circulation',
-            letter_code => uc( "ACCOUNT_" . $credit->credit_type_code ),
+            module                 => 'circulation',
+            letter_code            => uc( "ACCOUNT_" . $credit->credit_type_code ),
             message_transport_type => 'email',
             lang                   => $patron->lang,
             tables                 => {
@@ -198,7 +210,7 @@ if ( $op eq 'cud-send_receipt' ) {
                 offsets => \@credit_offsets,
             },
         )
-      )
+        )
     {
         my $message_id = C4::Letters::EnqueueLetter(
             {
@@ -209,12 +221,33 @@ if ( $op eq 'cud-send_receipt' ) {
         );
         C4::Letters::SendQueuedMessages( { message_id => $message_id } ) if $message_id;
         $receipt_sent = $message_id ? 1 : -1;
-    }
-    else {
+    } else {
         $receipt_sent = -1;
     }
 }
 
+if ( $op eq 'cud-edit_note' ) {
+
+    output_and_exit_if_error( $input, $cookie, $template, { check => 'csrf_token' } );
+
+    my $payment_id = scalar $input->param('accountlines_id');
+    my $note       = scalar $input->param('edited_note');
+
+    my $payment = Koha::Account::Lines->find($payment_id);
+
+    $schema->txn_do(
+        sub {
+            # Update the note and date in the account line
+            $payment->set(
+                {
+                    date => \'NOW()',
+                    note => $note
+                }
+            )->store();
+        }
+    );
+}
+
 #get account details
 my $total = $patron->account->balance;
 
@@ -224,15 +257,15 @@ my $accountlines = Koha::Account::Lines->search(
 );
 
 my $totalcredit;
-if($total <= 0){
-        $totalcredit = 1;
+if ( $total <= 0 ) {
+    $totalcredit = 1;
 }
 
 # Populate an arrayref with everything we need to display any
 # renew errors that occurred based on what we were passed
 my $renew_results_display = [];
-foreach my $renew_result(@renew_results) {
-    my ($itemnumber, $success, $info) = split(/,/, $renew_result);
+foreach my $renew_result (@renew_results) {
+    my ( $itemnumber, $success, $info ) = split( /,/, $renew_result );
     my $item = Koha::Items->find($itemnumber);
     if ($success) {
         $info = uri_unescape($info);
@@ -245,15 +278,15 @@ foreach my $renew_result(@renew_results) {
 }
 
 $template->param(
-    patron              => $patron,
-    finesview           => 1,
-    total               => sprintf("%.2f",$total),
-    totalcredit         => $totalcredit,
-    accounts            => $accountlines,
-    payment_id          => $payment_id,
-    change_given        => $change_given,
-    renew_results       => $renew_results_display,
-    receipt_sent        => $receipt_sent,
+    patron        => $patron,
+    finesview     => 1,
+    total         => sprintf( "%.2f", $total ),
+    totalcredit   => $totalcredit,
+    accounts      => $accountlines,
+    payment_id    => $payment_id,
+    change_given  => $change_given,
+    renew_results => $renew_results_display,
+    receipt_sent  => $receipt_sent,
 );
 
 output_html_with_http_headers $input, $cookie, $template->output;
