@@ -25,15 +25,15 @@ use Koha::Script;
 use Koha::ILL::Requests;
 
 # Command line option values
-my $get_help = 0;
-my $statuses = "";
-my $status_alias = "";
-my $status_to = "";
+my $get_help        = 0;
+my $statuses        = "";
+my $status_alias    = "";
+my $status_to       = "";
 my $status_alias_to = "";
-my $backend = "";
-my $dry_run = 0;
-my $delay = 0;
-my $debug = 0;
+my $backend         = "";
+my $dry_run         = 0;
+my $delay           = 0;
+my $debug           = 0;
 
 my $options = GetOptions(
     'h|help'            => \$get_help,
@@ -52,17 +52,17 @@ if ($get_help) {
     exit 1;
 }
 
-if (!$backend) {
+if ( !$backend ) {
     print "No backend specified\n";
     exit 0;
 }
 
 # First check we can proceed
-my $cfg = Koha::ILL::Request::Config->new;
-my $backends = $cfg->available_backends;
-my $has_branch = $cfg->has_branch;
+my $cfg                = Koha::ILL::Request::Config->new;
+my $backends           = $cfg->available_backends;
+my $has_branch         = $cfg->has_branch;
 my $backends_available = ( scalar @{$backends} > 0 );
-if (!$has_branch || $backends_available == 0) {
+if ( !$has_branch || $backends_available == 0 ) {
     print "Unable to proceed:\n";
     print "Branch configured: $has_branch\n";
     print "Backends available: $backends_available\n";
@@ -70,24 +70,22 @@ if (!$has_branch || $backends_available == 0) {
 }
 
 # Get all required requests
-my @statuses_arr = split(/:/, $statuses);
-my @status_alias_arr = split(/:/, $status_alias);
+my @statuses_arr     = split( /:/, $statuses );
+my @status_alias_arr = split( /:/, $status_alias );
 
-my $where = {
-    backend => $backend
-};
+my $where = { backend => $backend };
 
-if (scalar @statuses_arr > 0) {
-    my @or = grep(!/null/, @statuses_arr);
-    if (scalar @or < scalar @statuses_arr) {
+if ( scalar @statuses_arr > 0 ) {
+    my @or = grep( !/null/, @statuses_arr );
+    if ( scalar @or < scalar @statuses_arr ) {
         push @or, undef;
     }
     $where->{status} = \@or;
 }
 
-if (scalar @status_alias_arr > 0) {
-    my @or = grep(!/null/, @status_alias_arr);
-    if (scalar @or < scalar @status_alias_arr) {
+if ( scalar @status_alias_arr > 0 ) {
+    my @or = grep( !/null/, @status_alias_arr );
+    if ( scalar @or < scalar @status_alias_arr ) {
         push @or, undef;
     }
     $where->{status_alias} = \@or;
@@ -98,7 +96,7 @@ debug_msg($where);
 
 my $requests = Koha::ILL::Requests->search($where);
 
-debug_msg("Processing " . $requests->count . " requests");
+debug_msg( "Processing " . $requests->count . " requests" );
 
 # Create an options hashref to pass to processors
 my $options_to_pass = {
@@ -112,9 +110,10 @@ my $options_to_pass = {
 # The progress log
 my $output = [];
 
-while (my $request = $requests->next) {
-    debug_msg("- Request ID " . $request->illrequest_id);
+while ( my $request = $requests->next ) {
+    debug_msg( "- Request ID " . $request->illrequest_id );
     my $update = $request->backend_get_update($options_to_pass);
+
     # The log for this request
     my $update_log = {
         request_id     => $request->illrequest_id,
@@ -122,6 +121,7 @@ while (my $request = $requests->next) {
         processors_run => []
     };
     if ($update) {
+
         # Currently we make an assumption, this may need revisiting
         # if we need to extend the functionality:
         #
@@ -135,9 +135,11 @@ while (my $request = $requests->next) {
         #
         # Attach any request processors
         $request->attach_processors($update);
+
         # Attach any processors from this request's backend
         $request->_backend->attach_processors($update);
         my $processor_results = $update->run_processors($options_to_pass);
+
         # Update our progress log
         $update_log->{processors_run} = $processor_results;
     }
@@ -147,35 +149,35 @@ while (my $request = $requests->next) {
 print_summary($output);
 
 sub print_summary {
-    my ( $log ) = @_;
+    my ($log) = @_;
 
-    my $timestamp = POSIX::strftime("%d/%m/%Y %H:%M:%S\n", localtime);
+    my $timestamp = POSIX::strftime( "%d/%m/%Y %H:%M:%S\n", localtime );
     print "Run details:\n";
-    foreach my $entry(@{$log}) {
-        my @processors_run = @{$entry->{processors_run}};
+    foreach my $entry ( @{$log} ) {
+        my @processors_run = @{ $entry->{processors_run} };
         print "Request ID: " . $entry->{request_id} . "\n";
         print "  Processing by: " . $entry->{processed_by} . "\n";
         print "  Number of processors run: " . scalar @processors_run . "\n";
-        if (scalar @processors_run > 0) {
+        if ( scalar @processors_run > 0 ) {
             print "  Processor details:\n";
-            foreach my $processor(@processors_run) {
+            foreach my $processor (@processors_run) {
                 print "    Processor name: " . $processor->{name} . "\n";
-                print "    Success messages: " . join(", ", @{$processor->{result}->{success}}) . "\n";
-                print "    Error messages: " . join(", ", @{$processor->{result}->{error}}) . "\n";
+                print "    Success messages: " . join( ", ", @{ $processor->{result}->{success} } ) . "\n";
+                print "    Error messages: " . join( ", ", @{ $processor->{result}->{error} } ) . "\n";
             }
         }
     }
-    print "Job completed at $timestamp\n====================================\n\n"
+    print "Job completed at $timestamp\n====================================\n\n";
 }
 
 sub debug_msg {
-    my ( $msg ) = @_;
+    my ($msg) = @_;
 
-    if (!$debug) {
+    if ( !$debug ) {
         return;
     }
 
-    if (ref $msg eq 'HASH') {
+    if ( ref $msg eq 'HASH' ) {
         use Data::Dumper;
         $msg = Dumper $msg;
     }
