@@ -15,12 +15,11 @@
 # You should have received a copy of the GNU General Public License
 # along with Koha; if not, see <http://www.gnu.org/licenses>.
 
-
 use Modern::Perl;
 use CGI qw ( -utf8 );
 use Try::Tiny;
 use C4::Members;
-use C4::Auth qw( get_template_and_user );
+use C4::Auth   qw( get_template_and_user );
 use C4::Output qw( output_html_with_http_headers );
 
 use Koha::DateUtils qw( dt_from_string );
@@ -32,13 +31,13 @@ use Koha::Patrons;
 my $input = CGI->new;
 my ( $template, $borrowernumber, $cookie ) = get_template_and_user(
     {
-        template_name   => "opac-curbside-pickups.tt",
-        query           => $input,
-        type            => "opac",
+        template_name => "opac-curbside-pickups.tt",
+        query         => $input,
+        type          => "opac",
     }
 );
 
-unless( C4::Context->preference('CurbsidePickup') ) {
+unless ( C4::Context->preference('CurbsidePickup') ) {
     print $input->redirect("/cgi-bin/koha/errors/404.pl");
     exit;
 }
@@ -46,7 +45,7 @@ unless( C4::Context->preference('CurbsidePickup') ) {
 my $op = $input->param('op') || 'list';
 
 my $logged_in_patron = Koha::Patrons->find($borrowernumber);
-my $branchcode = $input->param('pickup_branch');
+my $branchcode       = $input->param('pickup_branch');
 my @messages;
 
 if ( $op eq 'cud-create-pickup' ) {
@@ -66,8 +65,8 @@ if ( $op eq 'cud-create-pickup' ) {
     } catch {
         if ( $_->isa('Koha::Exceptions::CurbsidePickup::NotEnabled') ) {
             push @messages, {
-                type   => 'error',
-                code   => 'not_enabled',
+                type => 'error',
+                code => 'not_enabled',
             };
         } elsif ( $_->isa('Koha::Exceptions::CurbsidePickup::LibraryIsClosed') ) {
             push @messages, {
@@ -77,8 +76,8 @@ if ( $op eq 'cud-create-pickup' ) {
             };
         } elsif ( $_->isa('Koha::Exceptions::CurbsidePickup::NoWaitingHolds') ) {
             push @messages, {
-                type   => 'error',
-                code   => 'no_waiting_holds',
+                type => 'error',
+                code => 'no_waiting_holds',
             };
         } elsif ( $_->isa('Koha::Exceptions::CurbsidePickup::TooManyPickups') ) {
             push @messages, {
@@ -88,40 +87,36 @@ if ( $op eq 'cud-create-pickup' ) {
             };
         } elsif ( $_->isa('Koha::Exceptions::CurbsidePickup::NoMatchingSlots') ) {
             push @messages, {
-                type   => 'error',
-                code   => 'no_matching_slots',
+                type => 'error',
+                code => 'no_matching_slots',
             };
         } elsif ( $_->isa('Koha::Exceptions::CurbsidePickup::NoMorePickupsAvailable') ) {
             push @messages, {
-                type   => 'error',
-                code   => 'no_more_pickups_available',
+                type => 'error',
+                code => 'no_more_pickups_available',
             };
         } else {
             warn $_;
             push @messages, {
-                type   => 'error',
-                code   => 'something_wrong_happened',
+                type => 'error',
+                code => 'something_wrong_happened',
             };
         }
     }
-}
-elsif ( $op eq 'cud-cancel-pickup' ) {
+} elsif ( $op eq 'cud-cancel-pickup' ) {
     my $id              = $input->param('pickup_id');
-    my $curbside_pickup = Koha::CurbsidePickups->search(
-        { borrowernumber => $borrowernumber } )->find($id);
+    my $curbside_pickup = Koha::CurbsidePickups->search( { borrowernumber => $borrowernumber } )->find($id);
     $curbside_pickup->delete
-      if $curbside_pickup
-      && !$curbside_pickup->delivered_datetime;
-}
-elsif ( $op eq 'cud-arrival-alert' ) {
+        if $curbside_pickup
+        && !$curbside_pickup->delivered_datetime;
+} elsif ( $op eq 'cud-arrival-alert' ) {
     my $id              = $input->param('pickup_id');
-    my $curbside_pickup = Koha::CurbsidePickups->search(
-        { borrowernumber => $borrowernumber } )->find($id);
+    my $curbside_pickup = Koha::CurbsidePickups->search( { borrowernumber => $borrowernumber } )->find($id);
     $curbside_pickup->mark_patron_has_arrived if $curbside_pickup;
     push @messages, {
         type => 'message',
         code => 'library_notified',
-    }
+    };
 }
 
 $template->param(
@@ -146,4 +141,4 @@ $template->param(
 );
 
 output_html_with_http_headers $input, $cookie, $template->output, undef,
-  { force_no_caching => 1 };
+    { force_no_caching => 1 };
