@@ -148,7 +148,7 @@ my $confirm_required = 0;
 my $return_only      = 0;
 
 my $batch_checkouts_allowed;
-if ( $patron ) {
+if ($patron) {
     my @batch_category_codes = split ',', C4::Context->preference('SCOBatchCheckoutsValidCategories');
     my $categorycode         = $patron->categorycode;
     if ( $categorycode && grep { $_ eq $categorycode } @batch_category_codes ) {
@@ -281,7 +281,13 @@ if ( $patron && $op eq "cud-returnbook" && $allowselfcheckreturns ) {
                     )->count;
                 }
 
-                my $new_issue = AddIssue( $patron, $barcode );
+                my $new_issue = AddIssue(
+                    $patron, $barcode, undef, undef, undef, undef,
+                    {
+                        confirmations => [ grep { /^[A-Z_]+$/ } keys %{$needconfirm} ],
+                        forced        => [ keys %{$impossible} ]
+                    }
+                );
                 $template->param( issued => 1, new_issue => $new_issue );
                 push @newissueslist, $barcode unless ( grep /^$barcode$/, @newissueslist );
 
