@@ -50,12 +50,12 @@ my $logged_in_user = Koha::Patrons->find($loggedinuser) or die "Not logged in";
 
 my $library_id = C4::Context->userenv->{'branch'};
 my $registerid = $input->param('registerid');
-my $op     = $input->param('op') || '';
+my $op         = $input->param('op') || '';
 
-my $invoice_types =
-  Koha::Account::DebitTypes->search_with_library_limits(
+my $invoice_types = Koha::Account::DebitTypes->search_with_library_limits(
     { can_be_sold => 1, archived => 0 },
-    {}, $library_id );
+    {}, $library_id
+);
 $template->param( invoice_types => $invoice_types );
 
 if ( $op eq 'cud-pay' ) {
@@ -80,7 +80,7 @@ if ( $op eq 'cud-pay' ) {
 
         $template->param(
             payment_id => $payment->accountlines_id,
-            collected  => scalar $input->param('collected'),
+            tendered   => scalar $input->param('tendered'),
             change     => scalar $input->param('change')
         );
     }
@@ -89,7 +89,7 @@ if ( $op eq 'cud-pay' ) {
 if ( $op eq 'cud-send' ) {
     my $payment_id = $input->param('payment_id');
     my $change     = $input->param('change');
-    my $collected  = $input->param('collected');
+    my $tendered   = $input->param('tendered');
     my $toaddr     = $input->param('toaddr');
 
     # Create our letter from the template
@@ -102,8 +102,8 @@ if ( $op eq 'cud-send' ) {
             credits => $payment_id,
         },
         substitute => {
-            collected => $collected,
-            change    => $change
+            tendered => $tendered,
+            change   => $change
         }
     );
 
@@ -112,8 +112,8 @@ if ( $op eq 'cud-send' ) {
         {
             letter                 => $letter,
             message_transport_type => 'email',
-            from_address => C4::Context->preference('KohaAdminEmailAddress'),
-            to_address   => $toaddr,
+            from_address           => C4::Context->preference('KohaAdminEmailAddress'),
+            to_address             => $toaddr,
         }
     );
 
@@ -123,7 +123,7 @@ if ( $op eq 'cud-send' ) {
     # Set variables for template to allow printing still
     $template->param(
         payment_id => $payment_id,
-        collected  => $collected,
+        tendered   => $tendered,
         change     => $change
     );
 }
