@@ -102,7 +102,7 @@ if ( !$registers->count ) {
     $template->param( trange_t => $end, );
 
     my $op = $input->param('op') // '';
-    if ( $op eq 'cashup' ) {
+    if ( $op eq 'cud-cashup' ) {
         if ( $logged_in_user->has_permission( { cash_management => 'cashup' } ) ) {
             $cash_register->add_cashup(
                 {
@@ -110,6 +110,10 @@ if ( !$registers->count ) {
                     amount     => $cash_register->outstanding_accountlines->total
                 }
             );
+
+            # Redirect to prevent duplicate submissions (POST/REDIRECT/GET pattern)
+            print $input->redirect( "/cgi-bin/koha/pos/register.pl?registerid=" . $registerid );
+            exit;
         } else {
             $template->param( error_cashup_permission => 1 );
         }
