@@ -489,7 +489,7 @@ describe("Additional Fields operations", () => {
         let license_additional_fields = get_licenses_additional_fields();
         let av_cats = get_av_cats();
 
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: license_additional_fields,
             statusCode: 200,
         });
@@ -551,7 +551,7 @@ describe("Additional Fields operations", () => {
             statusCode: 200,
             body: vendors,
         });
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: [],
             statusCode: 200,
         }).as("empty-additional-fields");
@@ -562,7 +562,7 @@ describe("Additional Fields operations", () => {
         cy.wait("@get-empty-license");
         cy.get("#licenses_show #additional_fields").should("not.exist");
 
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: license_additional_fields,
             statusCode: 200,
         }).as("existing-additional-fields");
@@ -657,7 +657,7 @@ describe("Additional Fields operations", () => {
             statusCode: 200,
             body: vendors,
         });
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: [],
             statusCode: 200,
         }).as("empty-additional-fields");
@@ -666,7 +666,7 @@ describe("Additional Fields operations", () => {
         cy.visit("/cgi-bin/koha/erm/licenses/add");
         cy.get("#licenses_add form #additional_fields").should("not.exist");
 
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: license_additional_fields,
             statusCode: 200,
         }).as("existing-additional-fields");
@@ -785,7 +785,7 @@ describe("Additional Fields operations", () => {
             body: vendors,
         });
 
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: license_additional_fields,
             statusCode: 200,
         }).as("existing-additional-fields");
@@ -882,7 +882,7 @@ describe("Additional Fields operations", () => {
         let agreement_additional_fields = get_agreements_additional_fields();
         let av_cats = get_av_cats();
 
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: agreement_additional_fields,
             statusCode: 200,
         });
@@ -944,7 +944,7 @@ describe("Additional Fields operations", () => {
             statusCode: 200,
             body: vendors,
         });
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: [],
             statusCode: 200,
         }).as("empty-additional-fields");
@@ -955,7 +955,7 @@ describe("Additional Fields operations", () => {
         cy.wait("@get-empty-agreement");
         cy.get("#agreements_show #additional_fields").should("not.exist");
 
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: agreement_additional_fields,
             statusCode: 200,
         }).as("existing-additional-fields");
@@ -1050,7 +1050,7 @@ describe("Additional Fields operations", () => {
             statusCode: 200,
             body: vendors,
         });
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: [],
             statusCode: 200,
         }).as("empty-additional-fields");
@@ -1059,7 +1059,7 @@ describe("Additional Fields operations", () => {
         cy.visit("/cgi-bin/koha/erm/agreements/add");
         cy.get("#agreements_add form #additional_fields").should("not.exist");
 
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: agreement_additional_fields,
             statusCode: 200,
         }).as("existing-additional-fields");
@@ -1178,7 +1178,7 @@ describe("Additional Fields operations", () => {
             body: vendors,
         });
 
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: agreement_additional_fields,
             statusCode: 200,
         }).as("existing-additional-fields");
@@ -1278,7 +1278,7 @@ describe("Additional Fields operations", () => {
             get_packages_additional_fields();
         let av_cats = get_av_cats();
 
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: eholdings_package_additional_fields,
             statusCode: 200,
         });
@@ -1347,7 +1347,7 @@ describe("Additional Fields operations", () => {
             statusCode: 200,
             body: vendors,
         });
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: [],
             statusCode: 200,
         }).as("empty-additional-fields");
@@ -1358,7 +1358,7 @@ describe("Additional Fields operations", () => {
         cy.wait("@get-empty-eholdings-package");
         cy.get("#packages_list #additional_fields").should("not.exist");
 
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: eholdings_package_additional_fields,
             statusCode: 200,
         }).as("existing-additional-fields");
@@ -1456,7 +1456,7 @@ describe("Additional Fields operations", () => {
             statusCode: 200,
             body: vendors,
         });
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: [],
             statusCode: 200,
         }).as("empty-additional-fields");
@@ -1465,7 +1465,7 @@ describe("Additional Fields operations", () => {
         cy.visit("/cgi-bin/koha/erm/eholdings/local/packages/add");
         cy.get("#packages_add form #additional_fields").should("not.exist");
 
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: eholdings_package_additional_fields,
             statusCode: 200,
         }).as("existing-additional-fields");
@@ -1587,7 +1587,7 @@ describe("Additional Fields operations", () => {
             body: vendors,
         });
 
-        cy.intercept("GET", "/api/v1/extended_attribute_types*", {
+        cy.intercept("GET", "/api/v1/erm/extended_attribute_types*", {
             body: eholdings_package_additional_fields,
             statusCode: 200,
         }).as("existing-additional-fields");
