@@ -26,21 +26,21 @@ use CGI qw(:standard -utf8);
 
 # Koha modules used
 use C4::Context;
-use C4::Output qw( output_html_with_http_headers );
-use C4::Auth qw( get_template_and_user );
-use C4::Auth qw( get_template_and_user );
-use C4::ImportBatch qw( GetImportBiblios );
+use C4::Output          qw( output_html_with_http_headers );
+use C4::Auth            qw( get_template_and_user );
+use C4::Auth            qw( get_template_and_user );
+use C4::ImportBatch     qw( GetImportBiblios );
 use C4::AuthoritiesMarc qw( GetAuthority );
 
 use Koha::Biblios;
 use Koha::Import::Records;
 
 # Input params
-my $input        = CGI->new;
+my $input    = CGI->new;
 my $recordid = $input->param('id');
-my $importid     = $input->param('importid');
-my $batchid      = $input->param('batchid');
-my $type      = $input->param('type');
+my $importid = $input->param('importid');
+my $batchid  = $input->param('batchid');
+my $type     = $input->param('type');
 
 if ( not $recordid or not $importid ) {
     print $input->redirect("/cgi-bin/koha/errors/404.pl");
@@ -48,35 +48,37 @@ if ( not $recordid or not $importid ) {
 }
 
 # Init vars
-my ($record, $recordImportid, $recordTitle, $importTitle, $formatted1, $formatted2, $errorFormatted1, $errorFormatted2);
+my (
+    $record, $recordImportid, $recordTitle, $importTitle, $formatted1, $formatted2, $errorFormatted1,
+    $errorFormatted2
+);
 
 # Prepare template
 my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
     {
-        template_name   => "tools/showdiffmarc.tt",
-        query           => $input,
-        type            => "intranet",
-        flagsrequired   => { tools => 'manage_staged_marc' },
+        template_name => "tools/showdiffmarc.tt",
+        query         => $input,
+        type          => "intranet",
+        flagsrequired => { tools => 'manage_staged_marc' },
     }
 );
 
 if ( $type eq 'biblio' ) {
-    my $biblio = Koha::Biblios->find( $recordid );
-    $record = $biblio->metadata_record( { embed_items => 1 } );
+    my $biblio = Koha::Biblios->find($recordid);
+    $record      = $biblio->metadata_record( { embed_items => 1 } );
     $recordTitle = $biblio->title;
+} elsif ( $type eq 'auth' ) {
+    $record      = GetAuthority($recordid);
+    $recordTitle = "Authority number " . $recordid;    #FIXME we should get the main heading
 }
-elsif ( $type eq 'auth' ) {
-    $record = GetAuthority( $recordid );
-    $recordTitle = "Authority number " . $recordid; #FIXME we should get the main heading
-}
-if( $record ) {
+if ($record) {
     $formatted1 = $record->as_formatted;
 } else {
     $errorFormatted1 = 1;
 }
 
-if( $importid ) {
-    my $import_record = Koha::Import::Records->find($importid);
+if ($importid) {
+    my $import_record  = Koha::Import::Records->find($importid);
     my $recordImportid = $import_record->get_marc_record();
     $formatted2 = $recordImportid->as_formatted;
     my $biblio = GetImportBiblios($importid);
